@@ -1,9 +1,9 @@
 /** @file
-*
-*  Copyright (c) 2011-2015, ARM Limited. All rights reserved.
-*
-*  SPDX-License-Identifier: BSD-2-Clause-Patent
-*
+
+  Copyright (c) 2011 - 2020, Arm Limited. All rights reserved.<BR>
+
+  SPDX-License-Identifier: BSD-2-Clause-Patent
+
 **/
 
 #ifndef _PREPI_H_
@@ -21,9 +21,7 @@
 #include <Library/SerialPortLib.h>
 #include <Library/ArmPlatformLib.h>
 
-#define SerialPrint(txt)  SerialPortWrite (txt, AsciiStrLen(txt)+1);
-
-extern UINT64 mSystemMemoryEnd;
+extern UINT64  mSystemMemoryEnd;
 
 RETURN_STATUS
 EFIAPI
@@ -33,16 +31,16 @@ TimerConstructor (
 
 VOID
 PrePiMain (
-  IN  UINTN                     UefiMemoryBase,
-  IN  UINTN                     StacksBase,
-  IN  UINT64                    StartTimeStamp
+  IN  UINTN   UefiMemoryBase,
+  IN  UINTN   StacksBase,
+  IN  UINT64  StartTimeStamp
   );
 
 EFI_STATUS
 EFIAPI
 MemoryPeim (
-  IN EFI_PHYSICAL_ADDRESS       UefiMemoryBase,
-  IN UINT64                     UefiMemorySize
+  IN EFI_PHYSICAL_ADDRESS  UefiMemoryBase,
+  IN UINT64                UefiMemorySize
   );
 
 EFI_STATUS
@@ -53,14 +51,14 @@ PlatformPeim (
 
 VOID
 PrimaryMain (
-  IN  UINTN                     UefiMemoryBase,
-  IN  UINTN                     StacksBase,
-  IN  UINT64                    StartTimeStamp
+  IN  UINTN   UefiMemoryBase,
+  IN  UINTN   StacksBase,
+  IN  UINT64  StartTimeStamp
   );
 
 VOID
 SecondaryMain (
-  IN  UINTN                     MpId
+  IN  UINTN  MpId
   );
 
 // Either implemented by PrePiLib or by MemoryInitPei
