@@ -4,13 +4,7 @@
   This file is stand alone self consistent set of definitions.
 
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -50,7 +44,7 @@
 #ifndef TRUE
 //
 // BugBug: UEFI specification claims 1 and 0. We are concerned about the
-//  complier portability so we did it this way.
+//  compiler portability so we did it this way.
 //
 #define TRUE  ((BOOLEAN)(1==1))
 #endif
@@ -63,6 +57,16 @@
 #define NULL  ((VOID *) 0)
 #endif
 
+#ifdef __CC_ARM
+  //
+  // Older RVCT ARM compilers don't fully support #pragma pack and require __packed
+  // as a prefix for the structure.
+  //
+  #define PACKED  __packed
+#else
+  #define PACKED
+#endif
+
 //
 //  Support for variable length argument lists using the ANSI standard.
 //
@@ -157,7 +161,7 @@ typedef struct {
 
 ///
 ///  _CR - returns a pointer to the structure
-///      from one of it's elements.
+///      from one of its elements.
 ///
 #define _CR(Record, TYPE, Field)  ((TYPE *) ((CHAR8 *) (Record) - (CHAR8 *) &(((TYPE *) 0)->Field)))
 
