@@ -1,15 +1,9 @@
 /** @file
   SSL/TLS Configuration Library Wrapper Implementation over OpenSSL.
 
-Copyright (c) 2016 - 2017, Intel Corporation. All rights reserved.<BR>
+Copyright (c) 2016 - 2018, Intel Corporation. All rights reserved.<BR>
 (C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -19,15 +13,15 @@ typedef struct {
   //
   // IANA/IETF defined Cipher Suite ID
   //
-  UINT16                          IanaCipher;
+  UINT16         IanaCipher;
   //
   // OpenSSL-used Cipher Suite String
   //
-  CONST CHAR8                     *OpensslCipher;
+  CONST CHAR8    *OpensslCipher;
   //
   // Length of OpensslCipher
   //
-  UINTN                           OpensslCipherLength;
+  UINTN          OpensslCipherLength;
 } TLS_CIPHER_MAPPING;
 
 //
@@ -44,30 +38,30 @@ typedef struct {
 //
 // Keep the table uniquely sorted by the IanaCipher field, in increasing order.
 //
-STATIC CONST TLS_CIPHER_MAPPING TlsCipherMappingTable[] = {
-  MAP ( 0x0001, "NULL-MD5" ),                       /// TLS_RSA_WITH_NULL_MD5
-  MAP ( 0x0002, "NULL-SHA" ),                       /// TLS_RSA_WITH_NULL_SHA
-  MAP ( 0x0004, "RC4-MD5" ),                        /// TLS_RSA_WITH_RC4_128_MD5
-  MAP ( 0x0005, "RC4-SHA" ),                        /// TLS_RSA_WITH_RC4_128_SHA
-  MAP ( 0x000A, "DES-CBC3-SHA" ),                   /// TLS_RSA_WITH_3DES_EDE_CBC_SHA, mandatory TLS 1.1
-  MAP ( 0x0016, "DHE-RSA-DES-CBC3-SHA" ),           /// TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA
-  MAP ( 0x002F, "AES128-SHA" ),                     /// TLS_RSA_WITH_AES_128_CBC_SHA, mandatory TLS 1.2
-  MAP ( 0x0030, "DH-DSS-AES128-SHA" ),              /// TLS_DH_DSS_WITH_AES_128_CBC_SHA
-  MAP ( 0x0031, "DH-RSA-AES128-SHA" ),              /// TLS_DH_RSA_WITH_AES_128_CBC_SHA
-  MAP ( 0x0033, "DHE-RSA-AES128-SHA" ),             /// TLS_DHE_RSA_WITH_AES_128_CBC_SHA
-  MAP ( 0x0035, "AES256-SHA" ),                     /// TLS_RSA_WITH_AES_256_CBC_SHA
-  MAP ( 0x0036, "DH-DSS-AES256-SHA" ),              /// TLS_DH_DSS_WITH_AES_256_CBC_SHA
-  MAP ( 0x0037, "DH-RSA-AES256-SHA" ),              /// TLS_DH_RSA_WITH_AES_256_CBC_SHA
-  MAP ( 0x0039, "DHE-RSA-AES256-SHA" ),             /// TLS_DHE_RSA_WITH_AES_256_CBC_SHA
-  MAP ( 0x003B, "NULL-SHA256" ),                    /// TLS_RSA_WITH_NULL_SHA256
-  MAP ( 0x003C, "AES128-SHA256" ),                  /// TLS_RSA_WITH_AES_128_CBC_SHA256
-  MAP ( 0x003D, "AES256-SHA256" ),                  /// TLS_RSA_WITH_AES_256_CBC_SHA256
-  MAP ( 0x003E, "DH-DSS-AES128-SHA256" ),           /// TLS_DH_DSS_WITH_AES_128_CBC_SHA256
-  MAP ( 0x003F, "DH-RSA-AES128-SHA256" ),           /// TLS_DH_RSA_WITH_AES_128_CBC_SHA256
-  MAP ( 0x0067, "DHE-RSA-AES128-SHA256" ),          /// TLS_DHE_RSA_WITH_AES_128_CBC_SHA256
-  MAP ( 0x0068, "DH-DSS-AES256-SHA256" ),           /// TLS_DH_DSS_WITH_AES_256_CBC_SHA256
-  MAP ( 0x0069, "DH-RSA-AES256-SHA256" ),           /// TLS_DH_RSA_WITH_AES_256_CBC_SHA256
-  MAP ( 0x006B, "DHE-RSA-AES256-SHA256" ),          /// TLS_DHE_RSA_WITH_AES_256_CBC_SHA256
+STATIC CONST TLS_CIPHER_MAPPING  TlsCipherMappingTable[] = {
+  MAP (0x0001, "NULL-MD5"),                         /// TLS_RSA_WITH_NULL_MD5
+  MAP (0x0002, "NULL-SHA"),                         /// TLS_RSA_WITH_NULL_SHA
+  MAP (0x0004, "RC4-MD5"),                          /// TLS_RSA_WITH_RC4_128_MD5
+  MAP (0x0005, "RC4-SHA"),                          /// TLS_RSA_WITH_RC4_128_SHA
+  MAP (0x000A, "DES-CBC3-SHA"),                     /// TLS_RSA_WITH_3DES_EDE_CBC_SHA, mandatory TLS 1.1
+  MAP (0x0016, "DHE-RSA-DES-CBC3-SHA"),             /// TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA
+  MAP (0x002F, "AES128-SHA"),                       /// TLS_RSA_WITH_AES_128_CBC_SHA, mandatory TLS 1.2
+  MAP (0x0030, "DH-DSS-AES128-SHA"),                /// TLS_DH_DSS_WITH_AES_128_CBC_SHA
+  MAP (0x0031, "DH-RSA-AES128-SHA"),                /// TLS_DH_RSA_WITH_AES_128_CBC_SHA
+  MAP (0x0033, "DHE-RSA-AES128-SHA"),               /// TLS_DHE_RSA_WITH_AES_128_CBC_SHA
+  MAP (0x0035, "AES256-SHA"),                       /// TLS_RSA_WITH_AES_256_CBC_SHA
+  MAP (0x0036, "DH-DSS-AES256-SHA"),                /// TLS_DH_DSS_WITH_AES_256_CBC_SHA
+  MAP (0x0037, "DH-RSA-AES256-SHA"),                /// TLS_DH_RSA_WITH_AES_256_CBC_SHA
+  MAP (0x0039, "DHE-RSA-AES256-SHA"),               /// TLS_DHE_RSA_WITH_AES_256_CBC_SHA
+  MAP (0x003B, "NULL-SHA256"),                      /// TLS_RSA_WITH_NULL_SHA256
+  MAP (0x003C, "AES128-SHA256"),                    /// TLS_RSA_WITH_AES_128_CBC_SHA256
+  MAP (0x003D, "AES256-SHA256"),                    /// TLS_RSA_WITH_AES_256_CBC_SHA256
+  MAP (0x003E, "DH-DSS-AES128-SHA256"),             /// TLS_DH_DSS_WITH_AES_128_CBC_SHA256
+  MAP (0x003F, "DH-RSA-AES128-SHA256"),             /// TLS_DH_RSA_WITH_AES_128_CBC_SHA256
+  MAP (0x0067, "DHE-RSA-AES128-SHA256"),            /// TLS_DHE_RSA_WITH_AES_128_CBC_SHA256
+  MAP (0x0068, "DH-DSS-AES256-SHA256"),             /// TLS_DH_DSS_WITH_AES_256_CBC_SHA256
+  MAP (0x0069, "DH-RSA-AES256-SHA256"),             /// TLS_DH_RSA_WITH_AES_256_CBC_SHA256
+  MAP (0x006B, "DHE-RSA-AES256-SHA256"),            /// TLS_DHE_RSA_WITH_AES_256_CBC_SHA256
 };
 
 /**
@@ -82,12 +76,12 @@ STATIC CONST TLS_CIPHER_MAPPING TlsCipherMappingTable[] = {
 STATIC
 CONST TLS_CIPHER_MAPPING *
 TlsGetCipherMapping (
-  IN     UINT16                   CipherId
+  IN     UINT16  CipherId
   )
 {
-  INTN                      Left;
-  INTN                      Right;
-  INTN                      Middle;
+  INTN  Left;
+  INTN  Right;
+  INTN  Middle;
 
   //
   // Binary Search Cipher Mapping Table for IANA-OpenSSL Cipher Translation
@@ -108,7 +102,7 @@ TlsGetCipherMapping (
     if (CipherId < TlsCipherMappingTable[Middle].IanaCipher) {
       Right = Middle - 1;
     } else {
-      Left  = Middle + 1;
+      Left = Middle + 1;
     }
   }
 
@@ -135,16 +129,16 @@ TlsGetCipherMapping (
 EFI_STATUS
 EFIAPI
 TlsSetVersion (
-  IN     VOID                     *Tls,
-  IN     UINT8                    MajorVer,
-  IN     UINT8                    MinorVer
+  IN     VOID   *Tls,
+  IN     UINT8  MajorVer,
+  IN     UINT8  MinorVer
   )
 {
   TLS_CONNECTION  *TlsConn;
   UINT16          ProtoVersion;
 
   TlsConn = (TLS_CONNECTION *)Tls;
-  if (TlsConn == NULL || TlsConn->Ssl == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -154,35 +148,35 @@ TlsSetVersion (
   // Bound TLS method to the particular specified version.
   //
   switch (ProtoVersion) {
-  case TLS1_VERSION:
-    //
-    // TLS 1.0
-    //
-    SSL_set_min_proto_version (TlsConn->Ssl, TLS1_VERSION);
-    SSL_set_max_proto_version (TlsConn->Ssl, TLS1_VERSION);
-    break;
-  case TLS1_1_VERSION:
-    //
-    // TLS 1.1
-    //
-    SSL_set_min_proto_version (TlsConn->Ssl, TLS1_1_VERSION);
-    SSL_set_max_proto_version (TlsConn->Ssl, TLS1_1_VERSION);
-    break;
-  case TLS1_2_VERSION:
-    //
-    // TLS 1.2
-    //
-    SSL_set_min_proto_version (TlsConn->Ssl, TLS1_2_VERSION);
-    SSL_set_max_proto_version (TlsConn->Ssl, TLS1_2_VERSION);
-    break;
-  default:
-    //
-    // Unsupported Protocol Version
-    //
-    return EFI_UNSUPPORTED;
+    case TLS1_VERSION:
+      //
+      // TLS 1.0
+      //
+      SSL_set_min_proto_version (TlsConn->Ssl, TLS1_VERSION);
+      SSL_set_max_proto_version (TlsConn->Ssl, TLS1_VERSION);
+      break;
+    case TLS1_1_VERSION:
+      //
+      // TLS 1.1
+      //
+      SSL_set_min_proto_version (TlsConn->Ssl, TLS1_1_VERSION);
+      SSL_set_max_proto_version (TlsConn->Ssl, TLS1_1_VERSION);
+      break;
+    case TLS1_2_VERSION:
+      //
+      // TLS 1.2
+      //
+      SSL_set_min_proto_version (TlsConn->Ssl, TLS1_2_VERSION);
+      SSL_set_max_proto_version (TlsConn->Ssl, TLS1_2_VERSION);
+      break;
+    default:
+      //
+      // Unsupported Protocol Version
+      //
+      return EFI_UNSUPPORTED;
   }
 
-  return EFI_SUCCESS;;
+  return EFI_SUCCESS;
 }
 
 /**
@@ -201,14 +195,14 @@ TlsSetVersion (
 EFI_STATUS
 EFIAPI
 TlsSetConnectionEnd (
-  IN     VOID                     *Tls,
-  IN     BOOLEAN                  IsServer
+  IN     VOID     *Tls,
+  IN     BOOLEAN  IsServer
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
-  if (TlsConn == NULL || TlsConn->Ssl == NULL) {
+  TlsConn = (TLS_CONNECTION *)Tls;
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -222,7 +216,7 @@ TlsSetConnectionEnd (
     // Set TLS to work in Server mode.
     // It is unsupported for UEFI version currently.
     //
-    //SSL_set_accept_state (TlsConn->Ssl);
+    // SSL_set_accept_state (TlsConn->Ssl);
     return EFI_UNSUPPORTED;
   }
 
@@ -250,24 +244,24 @@ TlsSetConnectionEnd (
 EFI_STATUS
 EFIAPI
 TlsSetCipherList (
-  IN     VOID                     *Tls,
-  IN     UINT16                   *CipherId,
-  IN     UINTN                    CipherNum
+  IN     VOID    *Tls,
+  IN     UINT16  *CipherId,
+  IN     UINTN   CipherNum
   )
 {
-  TLS_CONNECTION           *TlsConn;
-  EFI_STATUS               Status;
-  CONST TLS_CIPHER_MAPPING **MappedCipher;
-  UINTN                    MappedCipherBytes;
-  UINTN                    MappedCipherCount;
-  UINTN                    CipherStringSize;
-  UINTN                    Index;
-  CONST TLS_CIPHER_MAPPING *Mapping;
-  CHAR8                    *CipherString;
-  CHAR8                    *CipherStringPosition;
+  TLS_CONNECTION            *TlsConn;
+  EFI_STATUS                Status;
+  CONST TLS_CIPHER_MAPPING  **MappedCipher;
+  UINTN                     MappedCipherBytes;
+  UINTN                     MappedCipherCount;
+  UINTN                     CipherStringSize;
+  UINTN                     Index;
+  CONST TLS_CIPHER_MAPPING  *Mapping;
+  CHAR8                     *CipherString;
+  CHAR8                     *CipherStringPosition;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || CipherId == NULL) {
+  TlsConn = (TLS_CONNECTION *)Tls;
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (CipherId == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -275,11 +269,15 @@ TlsSetCipherList (
   // Allocate the MappedCipher array for recording the mappings that we find
   // for the input IANA identifiers in CipherId.
   //
-  Status = SafeUintnMult (CipherNum, sizeof (*MappedCipher),
-             &MappedCipherBytes);
+  Status = SafeUintnMult (
+             CipherNum,
+             sizeof (*MappedCipher),
+             &MappedCipherBytes
+             );
   if (EFI_ERROR (Status)) {
     return EFI_OUT_OF_RESOURCES;
   }
+
   MappedCipher = AllocatePool (MappedCipherBytes);
   if (MappedCipher == NULL) {
     return EFI_OUT_OF_RESOURCES;
@@ -290,15 +288,20 @@ TlsSetCipherList (
   // CipherString.
   //
   MappedCipherCount = 0;
-  CipherStringSize = 0;
+  CipherStringSize  = 0;
   for (Index = 0; Index < CipherNum; Index++) {
     //
     // Look up the IANA-to-OpenSSL mapping.
     //
     Mapping = TlsGetCipherMapping (CipherId[Index]);
     if (Mapping == NULL) {
-      DEBUG ((DEBUG_VERBOSE, "%a:%a: skipping CipherId=0x%04x\n",
-        gEfiCallerBaseName, __FUNCTION__, CipherId[Index]));
+      DEBUG ((
+        DEBUG_VERBOSE,
+        "%a:%a: skipping CipherId=0x%04x\n",
+        gEfiCallerBaseName,
+        __FUNCTION__,
+        CipherId[Index]
+        ));
       //
       // Skipping the cipher is valid because CipherId is an ordered
       // preference list of ciphers, thus we can filter it as long as we
@@ -306,6 +309,7 @@ TlsSetCipherList (
       //
       continue;
     }
+
     //
     // Accumulate Mapping->OpensslCipherLength into CipherStringSize. If this
     // is not the first successful mapping, account for a colon (":") prefix
@@ -318,12 +322,17 @@ TlsSetCipherList (
         goto FreeMappedCipher;
       }
     }
-    Status = SafeUintnAdd (CipherStringSize, Mapping->OpensslCipherLength,
-               &CipherStringSize);
+
+    Status = SafeUintnAdd (
+               CipherStringSize,
+               Mapping->OpensslCipherLength,
+               &CipherStringSize
+               );
     if (EFI_ERROR (Status)) {
       Status = EFI_OUT_OF_RESOURCES;
       goto FreeMappedCipher;
     }
+
     //
     // Record the mapping.
     //
@@ -335,16 +344,22 @@ TlsSetCipherList (
   // terminating NUL character in CipherStringSize; allocate CipherString.
   //
   if (MappedCipherCount == 0) {
-    DEBUG ((DEBUG_ERROR, "%a:%a: no CipherId could be mapped\n",
-      gEfiCallerBaseName, __FUNCTION__));
+    DEBUG ((
+      DEBUG_ERROR,
+      "%a:%a: no CipherId could be mapped\n",
+      gEfiCallerBaseName,
+      __FUNCTION__
+      ));
     Status = EFI_UNSUPPORTED;
     goto FreeMappedCipher;
   }
+
   Status = SafeUintnAdd (CipherStringSize, 1, &CipherStringSize);
   if (EFI_ERROR (Status)) {
     Status = EFI_OUT_OF_RESOURCES;
     goto FreeMappedCipher;
   }
+
   CipherString = AllocatePool (CipherStringSize);
   if (CipherString == NULL) {
     Status = EFI_OUT_OF_RESOURCES;
@@ -364,8 +379,12 @@ TlsSetCipherList (
     if (Index > 0) {
       *(CipherStringPosition++) = ':';
     }
-    CopyMem (CipherStringPosition, Mapping->OpensslCipher,
-      Mapping->OpensslCipherLength);
+
+    CopyMem (
+      CipherStringPosition,
+      Mapping->OpensslCipher,
+      Mapping->OpensslCipherLength
+      );
     CipherStringPosition += Mapping->OpensslCipherLength;
   }
 
@@ -381,30 +400,37 @@ TlsSetCipherList (
   // 79 non-newline characters. (MAX_DEBUG_MESSAGE_LENGTH is usually 0x100 in
   // DebugLib instances.)
   //
-  DEBUG_CODE (
-    UINTN FullLength;
-    UINTN SegmentLength;
+  DEBUG_CODE_BEGIN ();
+  UINTN  FullLength;
+  UINTN  SegmentLength;
 
-    FullLength = CipherStringSize - 1;
-    DEBUG ((DEBUG_VERBOSE, "%a:%a: CipherString={\n", gEfiCallerBaseName,
-      __FUNCTION__));
-    for (CipherStringPosition = CipherString;
-         CipherStringPosition < CipherString + FullLength;
-         CipherStringPosition += SegmentLength) {
-      SegmentLength = FullLength - (CipherStringPosition - CipherString);
-      if (SegmentLength > 79) {
-        SegmentLength = 79;
-      }
-      DEBUG ((DEBUG_VERBOSE, "%.*a\n", SegmentLength, CipherStringPosition));
+  FullLength = CipherStringSize - 1;
+  DEBUG ((
+    DEBUG_VERBOSE,
+    "%a:%a: CipherString={\n",
+    gEfiCallerBaseName,
+    __FUNCTION__
+    ));
+  for (CipherStringPosition = CipherString;
+       CipherStringPosition < CipherString + FullLength;
+       CipherStringPosition += SegmentLength)
+  {
+    SegmentLength = FullLength - (CipherStringPosition - CipherString);
+    if (SegmentLength > 79) {
+      SegmentLength = 79;
     }
-    DEBUG ((DEBUG_VERBOSE, "}\n"));
-    //
-    // Restore the pre-debug value of CipherStringPosition by skipping over the
-    // trailing NUL.
-    //
-    CipherStringPosition++;
-    ASSERT (CipherStringPosition == CipherString + CipherStringSize);
-  );
+
+    DEBUG ((DEBUG_VERBOSE, "%.*a\n", SegmentLength, CipherStringPosition));
+  }
+
+  DEBUG ((DEBUG_VERBOSE, "}\n"));
+  //
+  // Restore the pre-debug value of CipherStringPosition by skipping over the
+  // trailing NUL.
+  //
+  CipherStringPosition++;
+  ASSERT (CipherStringPosition == CipherString + CipherStringSize);
+  DEBUG_CODE_END ();
 
   //
   // Sets the ciphers for use by the Tls object.
@@ -440,7 +466,7 @@ FreeMappedCipher:
 EFI_STATUS
 EFIAPI
 TlsSetCompressionMethod (
-  IN     UINT8                    CompMethod
+  IN     UINT8  CompMethod
   )
 {
   COMP_METHOD  *Cm;
@@ -457,7 +483,7 @@ TlsSetCompressionMethod (
     //
     return EFI_SUCCESS;
   } else if (CompMethod == 1) {
-    Cm = COMP_zlib();
+    Cm = COMP_zlib ();
   } else {
     return EFI_UNSUPPORTED;
   }
@@ -486,14 +512,14 @@ TlsSetCompressionMethod (
 VOID
 EFIAPI
 TlsSetVerify (
-  IN     VOID                     *Tls,
-  IN     UINT32                   VerifyMode
+  IN     VOID    *Tls,
+  IN     UINT32  VerifyMode
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
-  if (TlsConn == NULL || TlsConn->Ssl == NULL) {
+  TlsConn = (TLS_CONNECTION *)Tls;
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL)) {
     return;
   }
 
@@ -503,6 +529,71 @@ TlsSetVerify (
   SSL_set_verify (TlsConn->Ssl, VerifyMode, NULL);
 }
 
+/**
+  Set the specified host name to be verified.
+
+  @param[in]  Tls           Pointer to the TLS object.
+  @param[in]  Flags         The setting flags during the validation.
+  @param[in]  HostName      The specified host name to be verified.
+
+  @retval  EFI_SUCCESS           The HostName setting was set successfully.
+  @retval  EFI_INVALID_PARAMETER The parameter is invalid.
+  @retval  EFI_ABORTED           Invalid HostName setting.
+
+**/
+EFI_STATUS
+EFIAPI
+TlsSetVerifyHost (
+  IN     VOID    *Tls,
+  IN     UINT32  Flags,
+  IN     CHAR8   *HostName
+  )
+{
+  TLS_CONNECTION     *TlsConn;
+  X509_VERIFY_PARAM  *VerifyParam;
+  UINTN              BinaryAddressSize;
+  UINT8              BinaryAddress[MAX (NS_INADDRSZ, NS_IN6ADDRSZ)];
+  INTN               ParamStatus;
+
+  TlsConn = (TLS_CONNECTION *)Tls;
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (HostName == NULL)) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  SSL_set_hostflags (TlsConn->Ssl, Flags);
+
+  VerifyParam = SSL_get0_param (TlsConn->Ssl);
+  ASSERT (VerifyParam != NULL);
+
+  BinaryAddressSize = 0;
+  if (inet_pton (AF_INET6, HostName, BinaryAddress) == 1) {
+    BinaryAddressSize = NS_IN6ADDRSZ;
+  } else if (inet_pton (AF_INET, HostName, BinaryAddress) == 1) {
+    BinaryAddressSize = NS_INADDRSZ;
+  }
+
+  if (BinaryAddressSize > 0) {
+    DEBUG ((
+      DEBUG_VERBOSE,
+      "%a:%a: parsed \"%a\" as an IPv%c address "
+      "literal\n",
+      gEfiCallerBaseName,
+      __FUNCTION__,
+      HostName,
+      (UINTN)((BinaryAddressSize == NS_IN6ADDRSZ) ? '6' : '4')
+      ));
+    ParamStatus = X509_VERIFY_PARAM_set1_ip (
+                    VerifyParam,
+                    BinaryAddress,
+                    BinaryAddressSize
+                    );
+  } else {
+    ParamStatus = X509_VERIFY_PARAM_set1_host (VerifyParam, HostName, 0);
+  }
+
+  return (ParamStatus == 1) ? EFI_SUCCESS : EFI_ABORTED;
+}
+
 /**
   Sets a TLS/SSL session ID to be used during TLS/SSL connect.
 
@@ -521,18 +612,18 @@ TlsSetVerify (
 EFI_STATUS
 EFIAPI
 TlsSetSessionId (
-  IN     VOID                     *Tls,
-  IN     UINT8                    *SessionId,
-  IN     UINT16                   SessionIdLen
+  IN     VOID    *Tls,
+  IN     UINT8   *SessionId,
+  IN     UINT16  SessionIdLen
   )
 {
   TLS_CONNECTION  *TlsConn;
   SSL_SESSION     *Session;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
   Session = NULL;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || SessionId == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (SessionId == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -566,9 +657,9 @@ TlsSetSessionId (
 EFI_STATUS
 EFIAPI
 TlsSetCaCertificate (
-  IN     VOID                     *Tls,
-  IN     VOID                     *Data,
-  IN     UINTN                    DataSize
+  IN     VOID   *Tls,
+  IN     VOID   *Data,
+  IN     UINTN  DataSize
   )
 {
   BIO             *BioCert;
@@ -584,10 +675,10 @@ TlsSetCaCertificate (
   Cert      = NULL;
   X509Store = NULL;
   Status    = EFI_SUCCESS;
-  TlsConn   = (TLS_CONNECTION *) Tls;
+  TlsConn   = (TLS_CONNECTION *)Tls;
   Ret       = 0;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || Data == NULL || DataSize == 0) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (Data == NULL) || (DataSize == 0)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -595,7 +686,7 @@ TlsSetCaCertificate (
   // DER-encoded binary X.509 certificate or PEM-encoded X.509 certificate.
   // Determine whether certificate is from DER encoding, if so, translate it to X509 structure.
   //
-  Cert = d2i_X509 (NULL, (const unsigned char ** )&Data, (long) DataSize);
+  Cert = d2i_X509 (NULL, (const unsigned char **)&Data, (long)DataSize);
   if (Cert == NULL) {
     //
     // Certificate is from PEM encoding.
@@ -606,7 +697,7 @@ TlsSetCaCertificate (
       goto ON_EXIT;
     }
 
-    if (BIO_write (BioCert, Data, (UINT32) DataSize) <= 0) {
+    if (BIO_write (BioCert, Data, (UINT32)DataSize) <= 0) {
       Status = EFI_ABORTED;
       goto ON_EXIT;
     }
@@ -621,8 +712,8 @@ TlsSetCaCertificate (
   SslCtx    = SSL_get_SSL_CTX (TlsConn->Ssl);
   X509Store = SSL_CTX_get_cert_store (SslCtx);
   if (X509Store == NULL) {
-      Status = EFI_ABORTED;
-      goto ON_EXIT;
+    Status = EFI_ABORTED;
+    goto ON_EXIT;
   }
 
   //
@@ -634,8 +725,9 @@ TlsSetCaCertificate (
     //
     // Ignore "already in table" errors
     //
-    if (!(ERR_GET_FUNC (ErrorCode) == X509_F_X509_STORE_ADD_CERT &&
-        ERR_GET_REASON (ErrorCode) == X509_R_CERT_ALREADY_IN_HASH_TABLE)) {
+    if (!((ERR_GET_FUNC (ErrorCode) == X509_F_X509_STORE_ADD_CERT) &&
+          (ERR_GET_REASON (ErrorCode) == X509_R_CERT_ALREADY_IN_HASH_TABLE)))
+    {
       Status = EFI_ABORTED;
       goto ON_EXIT;
     }
@@ -673,9 +765,9 @@ ON_EXIT:
 EFI_STATUS
 EFIAPI
 TlsSetHostPublicCert (
-  IN     VOID                     *Tls,
-  IN     VOID                     *Data,
-  IN     UINTN                    DataSize
+  IN     VOID   *Tls,
+  IN     VOID   *Data,
+  IN     UINTN  DataSize
   )
 {
   BIO             *BioCert;
@@ -686,9 +778,9 @@ TlsSetHostPublicCert (
   BioCert = NULL;
   Cert    = NULL;
   Status  = EFI_SUCCESS;
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || Data == NULL || DataSize == 0) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (Data == NULL) || (DataSize == 0)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -696,7 +788,7 @@ TlsSetHostPublicCert (
   // DER-encoded binary X.509 certificate or PEM-encoded X.509 certificate.
   // Determine whether certificate is from DER encoding, if so, translate it to X509 structure.
   //
-  Cert = d2i_X509 (NULL, (const unsigned char ** )&Data, (long) DataSize);
+  Cert = d2i_X509 (NULL, (const unsigned char **)&Data, (long)DataSize);
   if (Cert == NULL) {
     //
     // Certificate is from PEM encoding.
@@ -707,7 +799,7 @@ TlsSetHostPublicCert (
       goto ON_EXIT;
     }
 
-    if (BIO_write (BioCert, Data, (UINT32) DataSize) <= 0) {
+    if (BIO_write (BioCert, Data, (UINT32)DataSize) <= 0) {
       Status = EFI_ABORTED;
       goto ON_EXIT;
     }
@@ -755,9 +847,9 @@ ON_EXIT:
 EFI_STATUS
 EFIAPI
 TlsSetHostPrivateKey (
-  IN     VOID                     *Tls,
-  IN     VOID                     *Data,
-  IN     UINTN                    DataSize
+  IN     VOID   *Tls,
+  IN     VOID   *Data,
+  IN     UINTN  DataSize
   )
 {
   return EFI_UNSUPPORTED;
@@ -780,8 +872,8 @@ TlsSetHostPrivateKey (
 EFI_STATUS
 EFIAPI
 TlsSetCertRevocationList (
-  IN     VOID                     *Data,
-  IN     UINTN                    DataSize
+  IN     VOID   *Data,
+  IN     UINTN  DataSize
   )
 {
   return EFI_UNSUPPORTED;
@@ -803,12 +895,12 @@ TlsSetCertRevocationList (
 UINT16
 EFIAPI
 TlsGetVersion (
-  IN     VOID                     *Tls
+  IN     VOID  *Tls
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
   ASSERT (TlsConn != NULL);
 
@@ -831,12 +923,12 @@ TlsGetVersion (
 UINT8
 EFIAPI
 TlsGetConnectionEnd (
-  IN     VOID                     *Tls
+  IN     VOID  *Tls
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
   ASSERT (TlsConn != NULL);
 
@@ -860,17 +952,17 @@ TlsGetConnectionEnd (
 EFI_STATUS
 EFIAPI
 TlsGetCurrentCipher (
-  IN     VOID                     *Tls,
-  IN OUT UINT16                   *CipherId
+  IN     VOID    *Tls,
+  IN OUT UINT16  *CipherId
   )
 {
   TLS_CONNECTION    *TlsConn;
   CONST SSL_CIPHER  *Cipher;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
   Cipher  = NULL;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || CipherId == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (CipherId == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -903,8 +995,8 @@ TlsGetCurrentCipher (
 EFI_STATUS
 EFIAPI
 TlsGetCurrentCompressionId (
-  IN     VOID                     *Tls,
-  IN OUT UINT8                    *CompressionId
+  IN     VOID   *Tls,
+  IN OUT UINT8  *CompressionId
   )
 {
   return EFI_UNSUPPORTED;
@@ -926,12 +1018,12 @@ TlsGetCurrentCompressionId (
 UINT32
 EFIAPI
 TlsGetVerify (
-  IN     VOID                     *Tls
+  IN     VOID  *Tls
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
   ASSERT (TlsConn != NULL);
 
@@ -956,19 +1048,19 @@ TlsGetVerify (
 EFI_STATUS
 EFIAPI
 TlsGetSessionId (
-  IN     VOID                     *Tls,
-  IN OUT UINT8                    *SessionId,
-  IN OUT UINT16                   *SessionIdLen
+  IN     VOID    *Tls,
+  IN OUT UINT8   *SessionId,
+  IN OUT UINT16  *SessionIdLen
   )
 {
   TLS_CONNECTION  *TlsConn;
   SSL_SESSION     *Session;
   CONST UINT8     *SslSessionId;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
   Session = NULL;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || SessionId == NULL || SessionIdLen == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (SessionId == NULL) || (SessionIdLen == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -997,15 +1089,15 @@ TlsGetSessionId (
 VOID
 EFIAPI
 TlsGetClientRandom (
-  IN     VOID                     *Tls,
-  IN OUT UINT8                    *ClientRandom
+  IN     VOID   *Tls,
+  IN OUT UINT8  *ClientRandom
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || ClientRandom == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (ClientRandom == NULL)) {
     return;
   }
 
@@ -1026,15 +1118,15 @@ TlsGetClientRandom (
 VOID
 EFIAPI
 TlsGetServerRandom (
-  IN     VOID                     *Tls,
-  IN OUT UINT8                    *ServerRandom
+  IN     VOID   *Tls,
+  IN OUT UINT8  *ServerRandom
   )
 {
   TLS_CONNECTION  *TlsConn;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || ServerRandom == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (ServerRandom == NULL)) {
     return;
   }
 
@@ -1058,17 +1150,17 @@ TlsGetServerRandom (
 EFI_STATUS
 EFIAPI
 TlsGetKeyMaterial (
-  IN     VOID                     *Tls,
-  IN OUT UINT8                    *KeyMaterial
+  IN     VOID   *Tls,
+  IN OUT UINT8  *KeyMaterial
   )
 {
   TLS_CONNECTION  *TlsConn;
   SSL_SESSION     *Session;
 
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
   Session = NULL;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || KeyMaterial == NULL) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (KeyMaterial == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -1102,9 +1194,9 @@ TlsGetKeyMaterial (
 EFI_STATUS
 EFIAPI
 TlsGetCaCertificate (
-  IN     VOID                     *Tls,
-  OUT    VOID                     *Data,
-  IN OUT UINTN                    *DataSize
+  IN     VOID   *Tls,
+  OUT    VOID   *Data,
+  IN OUT UINTN  *DataSize
   )
 {
   return EFI_UNSUPPORTED;
@@ -1130,22 +1222,22 @@ TlsGetCaCertificate (
 EFI_STATUS
 EFIAPI
 TlsGetHostPublicCert (
-  IN     VOID                     *Tls,
-  OUT    VOID                     *Data,
-  IN OUT UINTN                    *DataSize
+  IN     VOID   *Tls,
+  OUT    VOID   *Data,
+  IN OUT UINTN  *DataSize
   )
 {
   X509            *Cert;
   TLS_CONNECTION  *TlsConn;
 
   Cert    = NULL;
-  TlsConn = (TLS_CONNECTION *) Tls;
+  TlsConn = (TLS_CONNECTION *)Tls;
 
-  if (TlsConn == NULL || TlsConn->Ssl == NULL || DataSize == NULL || (*DataSize != 0 && Data == NULL)) {
+  if ((TlsConn == NULL) || (TlsConn->Ssl == NULL) || (DataSize == NULL) || ((*DataSize != 0) && (Data == NULL))) {
     return EFI_INVALID_PARAMETER;
   }
 
-  Cert = SSL_get_certificate(TlsConn->Ssl);
+  Cert = SSL_get_certificate (TlsConn->Ssl);
   if (Cert == NULL) {
     return EFI_NOT_FOUND;
   }
@@ -1153,12 +1245,12 @@ TlsGetHostPublicCert (
   //
   // Only DER encoding is supported currently.
   //
-  if (*DataSize < (UINTN) i2d_X509 (Cert, NULL)) {
-    *DataSize = (UINTN) i2d_X509 (Cert, NULL);
+  if (*DataSize < (UINTN)i2d_X509 (Cert, NULL)) {
+    *DataSize = (UINTN)i2d_X509 (Cert, NULL);
     return EFI_BUFFER_TOO_SMALL;
   }
 
-  *DataSize = (UINTN) i2d_X509 (Cert, (unsigned char **) &Data);
+  *DataSize = (UINTN)i2d_X509 (Cert, (unsigned char **)&Data);
 
   return EFI_SUCCESS;
 }
@@ -1182,9 +1274,9 @@ TlsGetHostPublicCert (
 EFI_STATUS
 EFIAPI
 TlsGetHostPrivateKey (
-  IN     VOID                     *Tls,
-  OUT    VOID                     *Data,
-  IN OUT UINTN                    *DataSize
+  IN     VOID   *Tls,
+  OUT    VOID   *Data,
+  IN OUT UINTN  *DataSize
   )
 {
   return EFI_UNSUPPORTED;
@@ -1208,10 +1300,9 @@ TlsGetHostPrivateKey (
 EFI_STATUS
 EFIAPI
 TlsGetCertRevocationList (
-  OUT    VOID                     *Data,
-  IN OUT UINTN                    *DataSize
+  OUT    VOID   *Data,
+  IN OUT UINTN  *DataSize
   )
 {
   return EFI_UNSUPPORTED;
 }
-
