@@ -3,13 +3,7 @@
 
   Copyright (c) 2008 - 2009, Apple Inc. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -33,11 +27,10 @@
 EFI_STATUS
 EFIAPI
 FfsFindNextVolume (
-  IN UINTN                          Instance,
-  IN OUT EFI_PEI_FV_HANDLE          *VolumeHandle
+  IN UINTN                  Instance,
+  IN OUT EFI_PEI_FV_HANDLE  *VolumeHandle
   );
 
-
 /**
   This service enables discovery of additional firmware files.
 
@@ -54,12 +47,11 @@ FfsFindNextVolume (
 EFI_STATUS
 EFIAPI
 FfsFindNextFile (
-  IN EFI_FV_FILETYPE            SearchType,
-  IN EFI_PEI_FV_HANDLE          VolumeHandle,
-  IN OUT EFI_PEI_FILE_HANDLE    *FileHandle
+  IN EFI_FV_FILETYPE          SearchType,
+  IN EFI_PEI_FV_HANDLE        VolumeHandle,
+  IN OUT EFI_PEI_FILE_HANDLE  *FileHandle
   );
 
-
 /**
   This service enables discovery sections of a given type within a valid FFS file.
 
@@ -75,15 +67,14 @@ FfsFindNextFile (
 EFI_STATUS
 EFIAPI
 FfsFindSectionData (
-  IN EFI_SECTION_TYPE           SectionType,
-  IN EFI_PEI_FILE_HANDLE        FileHandle,
-  OUT VOID                      **SectionData
+  IN EFI_SECTION_TYPE     SectionType,
+  IN EFI_PEI_FILE_HANDLE  FileHandle,
+  OUT VOID                **SectionData
   );
 
-
 /**
   Find a file in the volume by name
-  
+
   @param FileName       A pointer to the name of the file to
                         find within the firmware volume.
 
@@ -101,13 +92,12 @@ FfsFindSectionData (
 **/
 EFI_STATUS
 EFIAPI
-FfsFindByName (
-  IN CONST  EFI_GUID            *FileName,
-  IN CONST  EFI_PEI_FV_HANDLE   VolumeHandle,
-  OUT       EFI_PEI_FILE_HANDLE *FileHandle
+FfsFindFileByName (
+  IN CONST  EFI_GUID             *FileName,
+  IN CONST  EFI_PEI_FV_HANDLE    VolumeHandle,
+  OUT       EFI_PEI_FILE_HANDLE  *FileHandle
   );
 
-
 /**
   Get information about the file by name.
 
@@ -117,21 +107,20 @@ FfsFindByName (
                       information.
 
   @retval EFI_SUCCESS             File information returned.
-  
+
   @retval EFI_INVALID_PARAMETER   If FileHandle does not
                                   represent a valid file.
-  
+
   @retval EFI_INVALID_PARAMETER   If FileInfo is NULL.
-  
+
 **/
 EFI_STATUS
-EFIAPI 
+EFIAPI
 FfsGetFileInfo (
-  IN CONST  EFI_PEI_FILE_HANDLE   FileHandle,
-  OUT EFI_FV_FILE_INFO            *FileInfo
+  IN CONST  EFI_PEI_FILE_HANDLE  FileHandle,
+  OUT EFI_FV_FILE_INFO           *FileInfo
   );
 
-
 /**
   Get Information about the volume by name
 
@@ -141,81 +130,75 @@ FfsGetFileInfo (
                         information.
 
   @retval EFI_SUCCESS             File information returned.
-  
+
   @retval EFI_INVALID_PARAMETER   If FileHandle does not
                                   represent a valid file.
-  
+
   @retval EFI_INVALID_PARAMETER   If FileInfo is NULL.
 
 **/
 EFI_STATUS
 EFIAPI
 FfsGetVolumeInfo (
-  IN  EFI_PEI_FV_HANDLE       VolumeHandle,
-  OUT EFI_FV_INFO             *VolumeInfo
+  IN  EFI_PEI_FV_HANDLE  VolumeHandle,
+  OUT EFI_FV_INFO        *VolumeInfo
   );
 
-
-
 /**
   Get Fv image from the FV type file, then add FV & FV2 Hob.
 
-	@param FileHandle  	        File handle of a Fv type file.
+  @param FileHandle      File handle of a Fv type file.
 
-
-  @retval EFI_NOT_FOUND  				FV image can't be found.
-  @retval EFI_SUCCESS						Successfully to process it.
+  @retval EFI_NOT_FOUND  FV image can't be found.
+  @retval EFI_SUCCESS    Successfully to process it.
 
 **/
 EFI_STATUS
 EFIAPI
 FfsProcessFvFile (
-  IN  EFI_PEI_FILE_HANDLE   FvFileHandle
+  IN  EFI_PEI_FILE_HANDLE  FvFileHandle
   );
 
-
 /**
   Search through every FV until you find a file of type FileType
 
-	@param FileType  	    File handle of a Fv type file.
-  @param Volumehandle   On succes Volume Handle of the match
-  @param FileHandle     On success File Handle of the match
-  
-  @retval EFI_NOT_FOUND  				FV image can't be found.
-  @retval EFI_SUCCESS						Successfully found FileType
+  @param FileType        File handle of a Fv type file.
+  @param Volumehandle    On success Volume Handle of the match
+  @param FileHandle      On success File Handle of the match
+
+  @retval EFI_NOT_FOUND  FV image can't be found.
+  @retval EFI_SUCCESS    Successfully found FileType
 
 **/
 EFI_STATUS
 EFIAPI
 FfsAnyFvFindFirstFile (
-  IN  EFI_FV_FILETYPE       FileType,
-  OUT EFI_PEI_FV_HANDLE     *VolumeHandle,
-  OUT EFI_PEI_FILE_HANDLE   *FileHandle
+  IN  EFI_FV_FILETYPE      FileType,
+  OUT EFI_PEI_FV_HANDLE    *VolumeHandle,
+  OUT EFI_PEI_FILE_HANDLE  *FileHandle
   );
 
-
 /**
   Get Fv image from the FV type file, then add FV & FV2 Hob.
 
-	@param FileHandle  	        File handle of a Fv type file.
+  @param FileHandle  File handle of a Fv type file.
 
 
-  @retval EFI_NOT_FOUND  				FV image can't be found.
-  @retval EFI_SUCCESS						Successfully to process it.
+  @retval EFI_NOT_FOUND  FV image can't be found.
+  @retval EFI_SUCCESS    Successfully to process it.
 
 **/
 EFI_STATUS
 EFIAPI
 FfsProcessFvFile (
-  IN  EFI_PEI_FILE_HANDLE   FvFileHandle
+  IN  EFI_PEI_FILE_HANDLE  FvFileHandle
   );
 
-
 /**
-  This service enables PEIMs to ascertain the present value of the boot mode.  
+  This service enables PEIMs to ascertain the present value of the boot mode.
 
 
-  @retval BootMode           
+  @retval BootMode
 
 **/
 EFI_BOOT_MODE
@@ -224,9 +207,8 @@ GetBootMode (
   VOID
   );
 
-
 /**
-  This service enables PEIMs to update the boot mode variable.    
+  This service enables PEIMs to update the boot mode variable.
 
   @param  BootMode              The value of the boot mode to set.
 
@@ -236,7 +218,7 @@ GetBootMode (
 EFI_STATUS
 EFIAPI
 SetBootMode (
-  IN EFI_BOOT_MODE              BootMode
+  IN EFI_BOOT_MODE  BootMode
   );
 
 /**
@@ -251,23 +233,22 @@ SetBootMode (
 VOID *
 EFIAPI
 GetHobList (
-  VOID         
+  VOID
   );
 
-
 /**
   Updates the pointer to the HOB list.
 
   @param  HobList       Hob list pointer to store
-  
+
 **/
 EFI_STATUS
 EFIAPI
 SetHobList (
-  IN  VOID      *HobList
+  IN  VOID  *HobList
   );
 
-EFI_HOB_HANDOFF_INFO_TABLE*
+EFI_HOB_HANDOFF_INFO_TABLE *
 HobConstructor (
   IN VOID   *EfiMemoryBegin,
   IN UINTN  EfiMemoryLength,
@@ -275,24 +256,6 @@ HobConstructor (
   IN VOID   *EfiFreeMemoryTop
   );
 
-/**
-  Retrieves the magic value from the PE/COFF header.
-
-  @param  Hdr             The buffer in which to return the PE32, PE32+, or TE header.
-
-  @return EFI_IMAGE_NT_OPTIONAL_HDR32_MAGIC - Image is PE32
-  @return EFI_IMAGE_NT_OPTIONAL_HDR64_MAGIC - Image is PE32+
-
-**/
-VOID
-CreateHobList (
-  IN VOID   *MemoryBegin,
-  IN UINTN  MemoryLength,
-  IN VOID   *HobBase,
-  IN VOID   *StackBase
-  );
-
-
 /**
   This service enables PEIMs to create various types of HOBs.
 
@@ -305,15 +268,14 @@ CreateHobList (
 **/
 VOID *
 CreateHob (
-  IN  UINT16    HobType,
-  IN  UINT16    HobLenght
+  IN  UINT16  HobType,
+  IN  UINT16  HobLenght
   );
 
-
 /**
   Returns the next instance of a HOB type from the starting HOB.
 
-  This function searches the first instance of a HOB type from the starting HOB pointer. 
+  This function searches the first instance of a HOB type from the starting HOB pointer.
   If there does not exist such HOB type from the starting HOB pointer, it will return NULL.
   In contrast with macro GET_NEXT_HOB(), this function does not skip the starting HOB pointer
   unconditionally: it returns HobStart back if HobStart itself meets the requirement;
@@ -329,15 +291,15 @@ CreateHob (
 VOID *
 EFIAPI
 GetNextHob (
-  IN UINT16                 Type,
-  IN CONST VOID             *HobStart
+  IN UINT16      Type,
+  IN CONST VOID  *HobStart
   );
 
 /**
   Returns the first instance of a HOB type among the whole HOB list.
 
-  This function searches the first instance of a HOB type among the whole HOB list. 
-  If there does not exist such HOB type in the HOB list, it will return NULL. 
+  This function searches the first instance of a HOB type among the whole HOB list.
+  If there does not exist such HOB type in the HOB list, it will return NULL.
 
   @param  Type          The HOB type to return.
 
@@ -347,14 +309,14 @@ GetNextHob (
 VOID *
 EFIAPI
 GetFirstHob (
-  IN UINT16                 Type
+  IN UINT16  Type
   );
 
 /**
-  This function searches the first instance of a HOB from the starting HOB pointer. 
-  Such HOB should satisfy two conditions: 
-  its HOB type is EFI_HOB_TYPE_GUID_EXTENSION and its GUID Name equals to the input Guid. 
-  If there does not exist such HOB from the starting HOB pointer, it will return NULL. 
+  This function searches the first instance of a HOB from the starting HOB pointer.
+  Such HOB should satisfy two conditions:
+  its HOB type is EFI_HOB_TYPE_GUID_EXTENSION and its GUID Name equals to the input Guid.
+  If there does not exist such HOB from the starting HOB pointer, it will return NULL.
   Caller is required to apply GET_GUID_HOB_DATA () and GET_GUID_HOB_DATA_SIZE ()
   to extract the data section and its size info respectively.
   In contrast with macro GET_NEXT_HOB(), this function does not skip the starting HOB pointer
@@ -372,12 +334,12 @@ GetFirstHob (
 VOID *
 EFIAPI
 GetNextGuidHob (
-  IN CONST EFI_GUID         *Guid,
-  IN CONST VOID             *HobStart
+  IN CONST EFI_GUID  *Guid,
+  IN CONST VOID      *HobStart
   );
 
 /**
-  This function searches the first instance of a HOB among the whole HOB list. 
+  This function searches the first instance of a HOB among the whole HOB list.
   Such HOB should satisfy two conditions:
   its HOB type is EFI_HOB_TYPE_GUID_EXTENSION and its GUID Name equals to the input Guid.
   If there does not exist such HOB from the starting HOB pointer, it will return NULL.
@@ -393,10 +355,9 @@ GetNextGuidHob (
 VOID *
 EFIAPI
 GetFirstGuidHob (
-  IN CONST EFI_GUID         *Guid
+  IN CONST EFI_GUID  *Guid
   );
 
-
 /**
   Builds a HOB for a loaded PE32 module.
 
@@ -415,10 +376,10 @@ GetFirstGuidHob (
 VOID
 EFIAPI
 BuildModuleHob (
-  IN CONST EFI_GUID         *ModuleName,
-  IN EFI_PHYSICAL_ADDRESS   MemoryAllocationModule,
-  IN UINT64                 ModuleLength,
-  IN EFI_PHYSICAL_ADDRESS   EntryPoint
+  IN CONST EFI_GUID        *ModuleName,
+  IN EFI_PHYSICAL_ADDRESS  MemoryAllocationModule,
+  IN UINT64                ModuleLength,
+  IN EFI_PHYSICAL_ADDRESS  EntryPoint
   );
 
 /**
@@ -447,8 +408,8 @@ BuildResourceDescriptorHob (
 /**
   Builds a GUID HOB with a certain data length.
 
-  This function builds a customized HOB tagged with a GUID for identification 
-  and returns the start address of GUID HOB data so that caller can fill the customized data. 
+  This function builds a customized HOB tagged with a GUID for identification
+  and returns the start address of GUID HOB data so that caller can fill the customized data.
   The HOB Header and Name field is already stripped.
   It can only be invoked during PEI phase;
   for DXE phase, it will ASSERT() since PEI HOB is read-only for DXE phase.
@@ -465,8 +426,8 @@ BuildResourceDescriptorHob (
 VOID *
 EFIAPI
 BuildGuidHob (
-  IN CONST EFI_GUID              *Guid,
-  IN UINTN                       DataLength
+  IN CONST EFI_GUID  *Guid,
+  IN UINTN           DataLength
   );
 
 /**
@@ -492,9 +453,9 @@ BuildGuidHob (
 VOID *
 EFIAPI
 BuildGuidDataHob (
-  IN CONST EFI_GUID              *Guid,
-  IN VOID                        *Data,
-  IN UINTN                       DataLength
+  IN CONST EFI_GUID  *Guid,
+  IN VOID            *Data,
+  IN UINTN           DataLength
   );
 
 /**
@@ -512,12 +473,12 @@ BuildGuidDataHob (
 VOID
 EFIAPI
 BuildFvHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length
   );
 
 /**
-  Builds a Firmware Volume HOB and a resrouce descriptor hob 
+  Builds a Firmware Volume HOB and a resource descriptor hob
 
   This function builds a Firmware Volume HOB.
   It can only be invoked during PEI phase;
@@ -530,12 +491,11 @@ BuildFvHob (
 **/
 VOID
 EFIAPI
-BuildFvHobs (  
+BuildFvHobs (
   IN EFI_PHYSICAL_ADDRESS         PhysicalStart,
   IN UINT64                       NumberOfBytes,
   IN EFI_RESOURCE_ATTRIBUTE_TYPE  *ResourceAttribute  OPTIONAL
-  ); 
-
+  );
 
 /**
   Builds a EFI_HOB_TYPE_FV2 HOB.
@@ -549,15 +509,15 @@ BuildFvHobs (
   @param  Length        The size of the Firmware Volume in bytes.
   @param  FvName       The name of the Firmware Volume.
   @param  FileName      The name of the file.
-  
+
 **/
 VOID
 EFIAPI
 BuildFv2Hob (
-  IN          EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN          UINT64                      Length,
-  IN CONST    EFI_GUID                    *FvName,
-  IN CONST    EFI_GUID                    *FileName
+  IN          EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN          UINT64                Length,
+  IN CONST    EFI_GUID              *FvName,
+  IN CONST    EFI_GUID              *FileName
   );
 
 /**
@@ -575,8 +535,8 @@ BuildFv2Hob (
 VOID
 EFIAPI
 BuildCvHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length
   );
 
 /**
@@ -594,8 +554,8 @@ BuildCvHob (
 VOID
 EFIAPI
 BuildCpuHob (
-  IN UINT8                       SizeOfMemorySpace,
-  IN UINT8                       SizeOfIoSpace
+  IN UINT8  SizeOfMemorySpace,
+  IN UINT8  SizeOfIoSpace
   );
 
 /**
@@ -613,8 +573,8 @@ BuildCpuHob (
 VOID
 EFIAPI
 BuildStackHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length
   );
 
 /**
@@ -626,11 +586,10 @@ BuildStackHob (
 **/
 VOID
 UpdateStackHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length
   );
 
-
 /**
   Builds a HOB for the BSP store.
 
@@ -647,9 +606,9 @@ UpdateStackHob (
 VOID
 EFIAPI
 BuildBspStoreHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length,
-  IN EFI_MEMORY_TYPE             MemoryType
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length,
+  IN EFI_MEMORY_TYPE       MemoryType
   );
 
 /**
@@ -668,18 +627,17 @@ BuildBspStoreHob (
 VOID
 EFIAPI
 BuildMemoryAllocationHob (
-  IN EFI_PHYSICAL_ADDRESS        BaseAddress,
-  IN UINT64                      Length,
-  IN EFI_MEMORY_TYPE             MemoryType
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINT64                Length,
+  IN EFI_MEMORY_TYPE       MemoryType
   );
 
-
 VOID
 EFIAPI
 BuildExtractSectionHob (
-  IN  EFI_GUID                                  *Guid,
-  IN  EXTRACT_GUIDED_SECTION_GET_INFO_HANDLER   SectionGetInfo,
-  IN  EXTRACT_GUIDED_SECTION_DECODE_HANDLER     SectionExtraction
+  IN  EFI_GUID                                 *Guid,
+  IN  EXTRACT_GUIDED_SECTION_GET_INFO_HANDLER  SectionGetInfo,
+  IN  EXTRACT_GUIDED_SECTION_DECODE_HANDLER    SectionExtraction
   );
 
 VOID
@@ -688,7 +646,6 @@ BuildPeCoffLoaderHob (
   VOID
   );
 
-
 /**
   Allocates one or more 4KB pages of type EfiBootServicesData.
 
@@ -702,12 +659,12 @@ BuildPeCoffLoaderHob (
   @return A pointer to the allocated buffer or NULL if allocation fails.
 
 **/
-VOID * 
+VOID *
 EFIAPI
 AllocatePages (
-  IN UINTN            Pages
+  IN UINTN  Pages
   );
-  
+
 /**
   Allocates a buffer of type EfiBootServicesData.
 
@@ -725,8 +682,7 @@ EFIAPI
 AllocatePool (
   IN UINTN  AllocationSize
   );
-  
-  
+
 /**
   Allocates one or more 4KB pages of type EfiBootServicesData at a specified alignment.
 
@@ -750,14 +706,13 @@ AllocateAlignedPages (
   IN UINTN  Alignment
   );
 
-
 EFI_STATUS
 EFIAPI
 LoadPeCoffImage (
-  IN  VOID                                      *PeCoffImage,
-  OUT EFI_PHYSICAL_ADDRESS                      *ImageAddress,
-  OUT UINT64                                    *ImageSize,
-  OUT EFI_PHYSICAL_ADDRESS                      *EntryPoint
+  IN  VOID                  *PeCoffImage,
+  OUT EFI_PHYSICAL_ADDRESS  *ImageAddress,
+  OUT UINT64                *ImageSize,
+  OUT EFI_PHYSICAL_ADDRESS  *EntryPoint
   );
 
 EFI_STATUS
@@ -770,7 +725,7 @@ LoadDxeCoreFromFfsFile (
 EFI_STATUS
 EFIAPI
 LoadDxeCoreFromFv (
-  IN UINTN  *FvInstance,   OPTIONAL
+  IN UINTN  *FvInstance    OPTIONAL,
   IN UINTN  StackSize
   );
 
@@ -780,11 +735,4 @@ DecompressFirstFv (
   VOID
   );
 
-VOID
-EFIAPI
-AddDxeCoreReportStatusCodeCallback (
-  VOID
-  );
-
-
 #endif
