@@ -2,16 +2,9 @@
   The NvmExpressPei driver is used to manage non-volatile memory subsystem
   which follows NVM Express specification at PEI phase.
 
-  Copyright (c) 2018, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2018 - 2019, Intel Corporation. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions
-  of the BSD License which accompanies this distribution.  The
-  full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -29,22 +22,22 @@
 **/
 UINT64
 NvmeCreatePrpList (
-  IN     PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private,
-  IN     EFI_PHYSICAL_ADDRESS                PhysicalAddr,
-  IN     UINTN                               Pages
+  IN     PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private,
+  IN     EFI_PHYSICAL_ADDRESS              PhysicalAddr,
+  IN     UINTN                             Pages
   )
 {
-  UINTN                   PrpEntryNo;
-  UINTN                   PrpListNo;
-  UINT64                  PrpListBase;
-  VOID                    *PrpListHost;
-  UINTN                   PrpListIndex;
-  UINTN                   PrpEntryIndex;
-  UINT64                  Remainder;
-  EFI_PHYSICAL_ADDRESS    PrpListPhyAddr;
-  UINTN                   Bytes;
-  UINT8                   *PrpEntry;
-  EFI_PHYSICAL_ADDRESS    NewPhyAddr;
+  UINTN                 PrpEntryNo;
+  UINTN                 PrpListNo;
+  UINT64                PrpListBase;
+  VOID                  *PrpListHost;
+  UINTN                 PrpListIndex;
+  UINTN                 PrpEntryIndex;
+  UINT64                Remainder;
+  EFI_PHYSICAL_ADDRESS  PrpListPhyAddr;
+  UINTN                 Bytes;
+  UINT8                 *PrpEntry;
+  EFI_PHYSICAL_ADDRESS  NewPhyAddr;
 
   //
   // The number of Prp Entry in a memory page.
@@ -54,7 +47,7 @@ NvmeCreatePrpList (
   //
   // Calculate total PrpList number.
   //
-  PrpListNo = (UINTN) DivU64x64Remainder ((UINT64)Pages, (UINT64)PrpEntryNo, &Remainder);
+  PrpListNo = (UINTN)DivU64x64Remainder ((UINT64)Pages, (UINT64)PrpEntryNo, &Remainder);
   if (Remainder != 0) {
     PrpListNo += 1;
   }
@@ -69,9 +62,10 @@ NvmeCreatePrpList (
       ));
     return 0;
   }
-  PrpListHost = (VOID *)(UINTN) NVME_PRP_BASE (Private);
 
-  Bytes = EFI_PAGES_TO_SIZE (PrpListNo);
+  PrpListHost = (VOID *)(UINTN)NVME_PRP_BASE (Private);
+
+  Bytes          = EFI_PAGES_TO_SIZE (PrpListNo);
   PrpListPhyAddr = (UINT64)(UINTN)(PrpListHost);
 
   //
@@ -82,19 +76,19 @@ NvmeCreatePrpList (
     PrpListBase = (UINTN)PrpListHost + PrpListIndex * EFI_PAGE_SIZE;
 
     for (PrpEntryIndex = 0; PrpEntryIndex < PrpEntryNo; ++PrpEntryIndex) {
-      PrpEntry = (UINT8 *)(UINTN) (PrpListBase + PrpEntryIndex * sizeof(UINT64));
+      PrpEntry = (UINT8 *)(UINTN)(PrpListBase + PrpEntryIndex * sizeof (UINT64));
       if (PrpEntryIndex != PrpEntryNo - 1) {
         //
         // Fill all PRP entries except of last one.
         //
-        CopyMem (PrpEntry, (VOID *)(UINTN) (&PhysicalAddr), sizeof (UINT64));
+        CopyMem (PrpEntry, (VOID *)(UINTN)(&PhysicalAddr), sizeof (UINT64));
         PhysicalAddr += EFI_PAGE_SIZE;
       } else {
         //
         // Fill last PRP entries with next PRP List pointer.
         //
         NewPhyAddr = (PrpListPhyAddr + (PrpListIndex + 1) * EFI_PAGE_SIZE);
-        CopyMem (PrpEntry, (VOID *)(UINTN) (&NewPhyAddr), sizeof (UINT64));
+        CopyMem (PrpEntry, (VOID *)(UINTN)(&NewPhyAddr), sizeof (UINT64));
       }
     }
   }
@@ -104,8 +98,8 @@ NvmeCreatePrpList (
   //
   PrpListBase = (UINTN)PrpListHost + PrpListIndex * EFI_PAGE_SIZE;
   for (PrpEntryIndex = 0; PrpEntryIndex < ((Remainder != 0) ? Remainder : PrpEntryNo); ++PrpEntryIndex) {
-    PrpEntry = (UINT8 *)(UINTN) (PrpListBase + PrpEntryIndex * sizeof(UINT64));
-    CopyMem (PrpEntry, (VOID *)(UINTN) (&PhysicalAddr), sizeof (UINT64));
+    PrpEntry = (UINT8 *)(UINTN)(PrpListBase + PrpEntryIndex * sizeof (UINT64));
+    CopyMem (PrpEntry, (VOID *)(UINTN)(&PhysicalAddr), sizeof (UINT64));
 
     PhysicalAddr += EFI_PAGE_SIZE;
   }
@@ -121,10 +115,10 @@ NvmeCreatePrpList (
 **/
 EFI_STATUS
 NvmeCheckCqStatus (
-  IN NVME_CQ             *Cq
+  IN NVME_CQ  *Cq
   )
 {
-  if (Cq->Sct == 0x0 && Cq->Sc == 0x0) {
+  if ((Cq->Sct == 0x0) && (Cq->Sc == 0x0)) {
     return EFI_SUCCESS;
   }
 
@@ -209,6 +203,7 @@ NvmeCheckCqStatus (
           DEBUG ((DEBUG_INFO, "Reservation Conflict\n"));
           break;
       }
+
       break;
 
     case 0x1:
@@ -271,6 +266,7 @@ NvmeCheckCqStatus (
           DEBUG ((DEBUG_INFO, "Attempted Write to Read Only Range\n"));
           break;
       }
+
       break;
 
     case 0x2:
@@ -297,6 +293,7 @@ NvmeCheckCqStatus (
           DEBUG ((DEBUG_INFO, "Access Denied\n"));
           break;
       }
+
       break;
 
     default:
@@ -339,27 +336,27 @@ NvmeCheckCqStatus (
 
 **/
 EFI_STATUS
-NvmePassThru (
-  IN     PEI_NVME_CONTROLLER_PRIVATE_DATA                  *Private,
-  IN     UINT32                                            NamespaceId,
-  IN OUT EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    *Packet
+NvmePassThruExecute (
+  IN     PEI_NVME_CONTROLLER_PRIVATE_DATA          *Private,
+  IN     UINT32                                    NamespaceId,
+  IN OUT EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  *Packet
   )
 {
-  EFI_STATUS               Status;
-  NVME_SQ                  *Sq;
-  NVME_CQ                  *Cq;
-  UINT8                    QueueId;
-  UINTN                    SqSize;
-  UINTN                    CqSize;
-  EDKII_IOMMU_OPERATION    MapOp;
-  UINTN                    MapLength;
-  EFI_PHYSICAL_ADDRESS     PhyAddr;
-  VOID                     *MapData;
-  VOID                     *MapMeta;
-  UINT32                   Bytes;
-  UINT32                   Offset;
-  UINT32                   Data32;
-  UINT64                   Timer;
+  EFI_STATUS             Status;
+  NVME_SQ                *Sq;
+  NVME_CQ                *Cq;
+  UINT8                  QueueId;
+  UINTN                  SqSize;
+  UINTN                  CqSize;
+  EDKII_IOMMU_OPERATION  MapOp;
+  UINTN                  MapLength;
+  EFI_PHYSICAL_ADDRESS   PhyAddr;
+  VOID                   *MapData;
+  VOID                   *MapMeta;
+  UINT32                 Bytes;
+  UINT32                 Offset;
+  UINT32                 Data32;
+  UINT64                 Timer;
 
   //
   // Check the data fields in Packet parameter
@@ -385,7 +382,7 @@ NvmePassThru (
     return EFI_INVALID_PARAMETER;
   }
 
-  if (Packet->QueueType != NVME_ADMIN_QUEUE && Packet->QueueType != NVME_IO_QUEUE) {
+  if ((Packet->QueueType != NVME_ADMIN_QUEUE) && (Packet->QueueType != NVME_IO_QUEUE)) {
     DEBUG ((
       DEBUG_ERROR,
       "%a, Invalid parameter: QueueId(%lx)\n",
@@ -418,9 +415,9 @@ NvmePassThru (
   }
 
   ZeroMem (Sq, sizeof (NVME_SQ));
-  Sq->Opc  = Packet->NvmeCmd->Cdw0.Opcode;
-  Sq->Fuse = Packet->NvmeCmd->Cdw0.FusedOperation;
-  Sq->Cid  = Packet->NvmeCmd->Cdw0.Cid;
+  Sq->Opc  = (UINT8)Packet->NvmeCmd->Cdw0.Opcode;
+  Sq->Fuse = (UINT8)Packet->NvmeCmd->Cdw0.FusedOperation;
+  Sq->Cid  = Private->Cid[QueueId]++;
   Sq->Nsid = Packet->NvmeCmd->Nsid;
 
   //
@@ -443,7 +440,8 @@ NvmePassThru (
   //
   if ((Sq->Opc & (BIT0 | BIT1)) != 0) {
     if (((Packet->TransferLength != 0) && (Packet->TransferBuffer == NULL)) ||
-        ((Packet->TransferLength == 0) && (Packet->TransferBuffer != NULL))) {
+        ((Packet->TransferLength == 0) && (Packet->TransferBuffer != NULL)))
+    {
       return EFI_INVALID_PARAMETER;
     }
 
@@ -452,9 +450,11 @@ NvmePassThru (
     // allocated internally by the driver.
     //
     if ((Packet->QueueType == NVME_ADMIN_QUEUE) &&
-        ((Sq->Opc == NVME_ADMIN_CRIOCQ_CMD) || (Sq->Opc == NVME_ADMIN_CRIOSQ_CMD))) {
+        ((Sq->Opc == NVME_ADMIN_CRIOCQ_CMD) || (Sq->Opc == NVME_ADMIN_CRIOSQ_CMD)))
+    {
       if ((Packet->TransferBuffer != Private->SqBuffer[NVME_IO_QUEUE]) &&
-          (Packet->TransferBuffer != Private->CqBuffer[NVME_IO_QUEUE])) {
+          (Packet->TransferBuffer != Private->CqBuffer[NVME_IO_QUEUE]))
+      {
         DEBUG ((
           DEBUG_ERROR,
           "%a: Does not support external IO queues creation request.\n",
@@ -471,13 +471,13 @@ NvmePassThru (
 
       if ((Packet->TransferLength != 0) && (Packet->TransferBuffer != NULL)) {
         MapLength = Packet->TransferLength;
-        Status = IoMmuMap (
-                   MapOp,
-                   Packet->TransferBuffer,
-                   &MapLength,
-                   &PhyAddr,
-                   &MapData
-                   );
+        Status    = IoMmuMap (
+                      MapOp,
+                      Packet->TransferBuffer,
+                      &MapLength,
+                      &PhyAddr,
+                      &MapData
+                      );
         if (EFI_ERROR (Status) || (MapLength != Packet->TransferLength)) {
           Status = EFI_OUT_OF_RESOURCES;
           DEBUG ((DEBUG_ERROR, "%a: Fail to map data buffer.\n", __FUNCTION__));
@@ -487,20 +487,21 @@ NvmePassThru (
         Sq->Prp[0] = PhyAddr;
       }
 
-      if((Packet->MetadataLength != 0) && (Packet->MetadataBuffer != NULL)) {
+      if ((Packet->MetadataLength != 0) && (Packet->MetadataBuffer != NULL)) {
         MapLength = Packet->MetadataLength;
-        Status = IoMmuMap (
-                   MapOp,
-                   Packet->MetadataBuffer,
-                   &MapLength,
-                   &PhyAddr,
-                   &MapMeta
-                   );
+        Status    = IoMmuMap (
+                      MapOp,
+                      Packet->MetadataBuffer,
+                      &MapLength,
+                      &PhyAddr,
+                      &MapMeta
+                      );
         if (EFI_ERROR (Status) || (MapLength != Packet->MetadataLength)) {
           Status = EFI_OUT_OF_RESOURCES;
           DEBUG ((DEBUG_ERROR, "%a: Fail to map meta data buffer.\n", __FUNCTION__));
           goto Exit;
         }
+
         Sq->Mptr = PhyAddr;
       }
     }
@@ -517,18 +518,17 @@ NvmePassThru (
     //
     // Create PrpList for remaining Data Buffer.
     //
-    PhyAddr = (Sq->Prp[0] + EFI_PAGE_SIZE) & ~(EFI_PAGE_SIZE - 1);
+    PhyAddr    = (Sq->Prp[0] + EFI_PAGE_SIZE) & ~(EFI_PAGE_SIZE - 1);
     Sq->Prp[1] = NvmeCreatePrpList (
                    Private,
                    PhyAddr,
-                   EFI_SIZE_TO_PAGES(Offset + Bytes) - 1
+                   EFI_SIZE_TO_PAGES (Offset + Bytes) - 1
                    );
     if (Sq->Prp[1] == 0) {
       Status = EFI_OUT_OF_RESOURCES;
       DEBUG ((DEBUG_ERROR, "%a: Create PRP list fail, Status - %r\n", __FUNCTION__, Status));
       goto Exit;
     }
-
   } else if ((Offset + Bytes) > EFI_PAGE_SIZE) {
     Sq->Prp[1] = (Sq->Prp[0] + EFI_PAGE_SIZE) & ~(EFI_PAGE_SIZE - 1);
   }
@@ -536,18 +536,23 @@ NvmePassThru (
   if (Packet->NvmeCmd->Flags & CDW10_VALID) {
     Sq->Payload.Raw.Cdw10 = Packet->NvmeCmd->Cdw10;
   }
+
   if (Packet->NvmeCmd->Flags & CDW11_VALID) {
     Sq->Payload.Raw.Cdw11 = Packet->NvmeCmd->Cdw11;
   }
+
   if (Packet->NvmeCmd->Flags & CDW12_VALID) {
     Sq->Payload.Raw.Cdw12 = Packet->NvmeCmd->Cdw12;
   }
+
   if (Packet->NvmeCmd->Flags & CDW13_VALID) {
     Sq->Payload.Raw.Cdw13 = Packet->NvmeCmd->Cdw13;
   }
+
   if (Packet->NvmeCmd->Flags & CDW14_VALID) {
     Sq->Payload.Raw.Cdw14 = Packet->NvmeCmd->Cdw14;
   }
+
   if (Packet->NvmeCmd->Flags & CDW15_VALID) {
     Sq->Payload.Raw.Cdw15 = Packet->NvmeCmd->Cdw15;
   }
@@ -559,6 +564,7 @@ NvmePassThru (
   if (Private->SqTdbl[QueueId].Sqt == SqSize) {
     Private->SqTdbl[QueueId].Sqt = 0;
   }
+
   Data32 = ReadUnaligned32 ((UINT32 *)&Private->SqTdbl[QueueId]);
   Status = NVME_SET_SQTDBL (Private, QueueId, &Data32);
   if (EFI_ERROR (Status)) {
@@ -595,6 +601,7 @@ NvmePassThru (
       //
       Status = EFI_TIMEOUT;
     }
+
     goto Exit;
   }
 
@@ -604,13 +611,13 @@ NvmePassThru (
   Private->CqHdbl[QueueId].Cqh++;
   if (Private->CqHdbl[QueueId].Cqh == CqSize) {
     Private->CqHdbl[QueueId].Cqh = 0;
-    Private->Pt[QueueId] ^= 1;
+    Private->Pt[QueueId]        ^= 1;
   }
 
   //
   // Copy the Respose Queue entry for this command to the callers response buffer
   //
-  CopyMem (Packet->NvmeCompletion, Cq, sizeof (EDKII_PEI_NVM_EXPRESS_COMPLETION));
+  CopyMem (Packet->NvmeCompletion, Cq, sizeof (EFI_NVM_EXPRESS_COMPLETION));
 
   //
   // Check the NVMe cmd execution result
@@ -629,3 +636,206 @@ Exit:
 
   return Status;
 }
+
+/**
+  Gets the device path information of the underlying NVM Express host controller.
+
+  @param[in]  This                 The PPI instance pointer.
+  @param[out] DevicePathLength     The length of the device path in bytes specified
+                                   by DevicePath.
+  @param[out] DevicePath           The device path of the underlying NVM Express
+                                   host controller.
+                                   This field re-uses EFI Device Path Protocol as
+                                   defined by Section 10.2 EFI Device Path Protocol
+                                   of UEFI 2.7 Specification.
+
+  @retval EFI_SUCCESS              The operation succeeds.
+  @retval EFI_INVALID_PARAMETER    DevicePathLength or DevicePath is NULL.
+  @retval EFI_OUT_OF_RESOURCES     The operation fails due to lack of resources.
+
+**/
+EFI_STATUS
+EFIAPI
+NvmePassThruGetDevicePath (
+  IN  EDKII_PEI_NVM_EXPRESS_PASS_THRU_PPI  *This,
+  OUT UINTN                                *DevicePathLength,
+  OUT EFI_DEVICE_PATH_PROTOCOL             **DevicePath
+  )
+{
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+
+  if ((This == NULL) || (DevicePathLength == NULL) || (DevicePath == NULL)) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_NVME_PASSTHRU (This);
+
+  *DevicePathLength = Private->DevicePathLength;
+  *DevicePath       = AllocateCopyPool (Private->DevicePathLength, Private->DevicePath);
+  if (*DevicePath == NULL) {
+    *DevicePathLength = 0;
+    return EFI_OUT_OF_RESOURCES;
+  }
+
+  return EFI_SUCCESS;
+}
+
+/**
+  Used to retrieve the next namespace ID for this NVM Express controller.
+
+  If on input the value pointed to by NamespaceId is 0xFFFFFFFF, then the first
+  valid namespace ID defined on the NVM Express controller is returned in the
+  location pointed to by NamespaceId and a status of EFI_SUCCESS is returned.
+
+  If on input the value pointed to by NamespaceId is an invalid namespace ID
+  other than 0xFFFFFFFF, then EFI_INVALID_PARAMETER is returned.
+
+  If on input the value pointed to by NamespaceId is a valid namespace ID, then
+  the next valid namespace ID on the NVM Express controller is returned in the
+  location pointed to by NamespaceId, and EFI_SUCCESS is returned.
+
+  If the value pointed to by NamespaceId is the namespace ID of the last
+  namespace on the NVM Express controller, then EFI_NOT_FOUND is returned.
+
+  @param[in]     This              The PPI instance pointer.
+  @param[in,out] NamespaceId       On input, a pointer to a legal NamespaceId
+                                   for an NVM Express namespace present on the
+                                   NVM Express controller. On output, a pointer
+                                   to the next NamespaceId of an NVM Express
+                                   namespace on an NVM Express controller. An
+                                   input value of 0xFFFFFFFF retrieves the
+                                   first NamespaceId for an NVM Express
+                                   namespace present on an NVM Express
+                                   controller.
+
+  @retval EFI_SUCCESS            The Namespace ID of the next Namespace was
+                                 returned.
+  @retval EFI_NOT_FOUND          There are no more namespaces defined on this
+                                 controller.
+  @retval EFI_INVALID_PARAMETER  NamespaceId is an invalid value other than
+                                 0xFFFFFFFF.
+
+**/
+EFI_STATUS
+EFIAPI
+NvmePassThruGetNextNameSpace (
+  IN     EDKII_PEI_NVM_EXPRESS_PASS_THRU_PPI  *This,
+  IN OUT UINT32                               *NamespaceId
+  )
+{
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+  UINT32                            DeviceIndex;
+  EFI_STATUS                        Status;
+
+  if ((This == NULL) || (NamespaceId == NULL)) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_NVME_PASSTHRU (This);
+
+  Status = EFI_NOT_FOUND;
+
+  //
+  // If active namespace number is 0, then valid namespace ID is unavailable
+  //
+  if (Private->ActiveNamespaceNum == 0) {
+    return EFI_NOT_FOUND;
+  }
+
+  //
+  // If the NamespaceId input value is 0xFFFFFFFF, then get the first valid namespace ID
+  //
+  if (*NamespaceId == 0xFFFFFFFF) {
+    //
+    // Start with the first namespace ID
+    //
+    *NamespaceId = Private->NamespaceInfo[0].NamespaceId;
+    Status       = EFI_SUCCESS;
+  } else {
+    if (*NamespaceId > Private->ControllerData->Nn) {
+      return EFI_INVALID_PARAMETER;
+    }
+
+    if ((*NamespaceId + 1) > Private->ControllerData->Nn) {
+      return EFI_NOT_FOUND;
+    }
+
+    for (DeviceIndex = 0; DeviceIndex < Private->ActiveNamespaceNum; DeviceIndex++) {
+      if (*NamespaceId == Private->NamespaceInfo[DeviceIndex].NamespaceId) {
+        if ((DeviceIndex + 1) < Private->ActiveNamespaceNum) {
+          *NamespaceId = Private->NamespaceInfo[DeviceIndex + 1].NamespaceId;
+          Status       = EFI_SUCCESS;
+        }
+
+        break;
+      }
+    }
+  }
+
+  return Status;
+}
+
+/**
+  Sends an NVM Express Command Packet to an NVM Express controller or namespace. This function only
+  supports blocking execution of the command.
+
+  @param[in]  This                 The PPI instance pointer.
+  @param[in] NamespaceId           Is a 32 bit Namespace ID to which the Nvm Express command packet will
+                                   be sent.
+                                   A Value of 0 denotes the NVM Express controller, a Value of all 0FFh in
+                                   the namespace ID specifies that the command packet should be sent to all
+                                   valid namespaces.
+  @param[in,out] Packet            A pointer to the EDKII PEI NVM Express PassThru Command Packet to send
+                                   to the NVMe namespace specified by NamespaceId.
+
+  @retval EFI_SUCCESS              The EDKII PEI NVM Express Command Packet was sent by the host.
+                                   TransferLength bytes were transferred to, or from DataBuffer.
+  @retval EFI_NOT_READY            The EDKII PEI NVM Express Command Packet could not be sent because
+                                   the controller is not ready. The caller may retry again later.
+  @retval EFI_DEVICE_ERROR         A device error occurred while attempting to send the EDKII PEI NVM
+                                   Express Command Packet.
+  @retval EFI_INVALID_PARAMETER    Namespace, or the contents of EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET
+                                   are invalid.
+                                   The EDKII PEI NVM Express Command Packet was not sent, so no
+                                   additional status information is available.
+  @retval EFI_UNSUPPORTED          The command described by the EDKII PEI NVM Express Command Packet
+                                   is not supported by the host adapter.
+                                   The EDKII PEI NVM Express Command Packet was not sent, so no
+                                   additional status information is available.
+  @retval EFI_TIMEOUT              A timeout occurred while waiting for the EDKII PEI NVM Express Command
+                                   Packet to execute.
+
+**/
+EFI_STATUS
+EFIAPI
+NvmePassThru (
+  IN     EDKII_PEI_NVM_EXPRESS_PASS_THRU_PPI       *This,
+  IN     UINT32                                    NamespaceId,
+  IN OUT EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  *Packet
+  )
+{
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+  EFI_STATUS                        Status;
+
+  if ((This == NULL) || (Packet == NULL)) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_NVME_PASSTHRU (This);
+  //
+  // Check NamespaceId is valid or not.
+  //
+  if ((NamespaceId > Private->ControllerData->Nn) &&
+      (NamespaceId != (UINT32)-1))
+  {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  Status = NvmePassThruExecute (
+             Private,
+             NamespaceId,
+             Packet
+             );
+
+  return Status;
+}
