@@ -2,21 +2,13 @@
 
   Routine procedures for memory allocate/free.
 
-Copyright (c) 2013, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+Copyright (c) 2013 - 2018, Intel Corporation. All rights reserved.<BR>
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
-
 #include "Xhci.h"
 
-
 /**
   Allocate a block of memory to be used by the buffer pool.
 
@@ -28,17 +20,17 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 **/
 USBHC_MEM_BLOCK *
 UsbHcAllocMemBlock (
-  IN  USBHC_MEM_POOL      *Pool,
-  IN  UINTN               Pages
+  IN  USBHC_MEM_POOL  *Pool,
+  IN  UINTN           Pages
   )
 {
-  USBHC_MEM_BLOCK         *Block;
-  EFI_PCI_IO_PROTOCOL     *PciIo;
-  VOID                    *BufHost;
-  VOID                    *Mapping;
-  EFI_PHYSICAL_ADDRESS    MappedAddr;
-  UINTN                   Bytes;
-  EFI_STATUS              Status;
+  USBHC_MEM_BLOCK       *Block;
+  EFI_PCI_IO_PROTOCOL   *PciIo;
+  VOID                  *BufHost;
+  VOID                  *Mapping;
+  EFI_PHYSICAL_ADDRESS  MappedAddr;
+  UINTN                 Bytes;
+  EFI_STATUS            Status;
 
   PciIo = Pool->PciIo;
 
@@ -53,9 +45,9 @@ UsbHcAllocMemBlock (
   //
   ASSERT (USBHC_MEM_UNIT * 8 <= EFI_PAGE_SIZE);
 
-  Block->BufLen   = EFI_PAGES_TO_SIZE (Pages);
-  Block->BitsLen  = Block->BufLen / (USBHC_MEM_UNIT * 8);
-  Block->Bits     = AllocateZeroPool (Block->BitsLen);
+  Block->BufLen  = EFI_PAGES_TO_SIZE (Pages);
+  Block->BitsLen = Block->BufLen / (USBHC_MEM_UNIT * 8);
+  Block->Bits    = AllocateZeroPool (Block->BitsLen);
 
   if (Block->Bits == NULL) {
     gBS->FreePool (Block);
@@ -79,7 +71,7 @@ UsbHcAllocMemBlock (
     goto FREE_BITARRAY;
   }
 
-  Bytes = EFI_PAGES_TO_SIZE (Pages);
+  Bytes  = EFI_PAGES_TO_SIZE (Pages);
   Status = PciIo->Map (
                     PciIo,
                     EfiPciIoOperationBusMasterCommonBuffer,
@@ -93,9 +85,9 @@ UsbHcAllocMemBlock (
     goto FREE_BUFFER;
   }
 
-  Block->BufHost  = BufHost;
-  Block->Buf      = (UINT8 *) ((UINTN) MappedAddr);
-  Block->Mapping  = Mapping;
+  Block->BufHost = BufHost;
+  Block->Buf     = (UINT8 *)((UINTN)MappedAddr);
+  Block->Mapping = Mapping;
 
   return Block;
 
@@ -108,7 +100,6 @@ FREE_BITARRAY:
   return NULL;
 }
 
-
 /**
   Free the memory block from the memory pool.
 
@@ -118,11 +109,11 @@ FREE_BITARRAY:
 **/
 VOID
 UsbHcFreeMemBlock (
-  IN USBHC_MEM_POOL       *Pool,
-  IN USBHC_MEM_BLOCK      *Block
+  IN USBHC_MEM_POOL   *Pool,
+  IN USBHC_MEM_BLOCK  *Block
   )
 {
-  EFI_PCI_IO_PROTOCOL     *PciIo;
+  EFI_PCI_IO_PROTOCOL  *PciIo;
 
   ASSERT ((Pool != NULL) && (Block != NULL));
 
@@ -138,7 +129,6 @@ UsbHcFreeMemBlock (
   gBS->FreePool (Block);
 }
 
-
 /**
   Alloc some memory from the block.
 
@@ -151,22 +141,22 @@ UsbHcFreeMemBlock (
 **/
 VOID *
 UsbHcAllocMemFromBlock (
-  IN  USBHC_MEM_BLOCK     *Block,
-  IN  UINTN               Units
+  IN  USBHC_MEM_BLOCK  *Block,
+  IN  UINTN            Units
   )
 {
-  UINTN                   Byte;
-  UINT8                   Bit;
-  UINTN                   StartByte;
-  UINT8                   StartBit;
-  UINTN                   Available;
-  UINTN                   Count;
+  UINTN  Byte;
+  UINT8  Bit;
+  UINTN  StartByte;
+  UINT8  StartBit;
+  UINTN  Available;
+  UINTN  Count;
 
   ASSERT ((Block != 0) && (Units != 0));
 
-  StartByte  = 0;
-  StartBit   = 0;
-  Available  = 0;
+  StartByte = 0;
+  StartBit  = 0;
+  Available = 0;
 
   for (Byte = 0, Bit = 0; Byte < Block->BitsLen;) {
     //
@@ -182,13 +172,12 @@ UsbHcAllocMemFromBlock (
       }
 
       NEXT_BIT (Byte, Bit);
-
     } else {
       NEXT_BIT (Byte, Bit);
 
-      Available  = 0;
-      StartByte  = Byte;
-      StartBit   = Bit;
+      Available = 0;
+      StartByte = Byte;
+      StartBit  = Bit;
     }
   }
 
@@ -199,13 +188,13 @@ UsbHcAllocMemFromBlock (
   //
   // Mark the memory as allocated
   //
-  Byte  = StartByte;
-  Bit   = StartBit;
+  Byte = StartByte;
+  Bit  = StartBit;
 
   for (Count = 0; Count < Units; Count++) {
     ASSERT (!USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
 
-    Block->Bits[Byte] = (UINT8) (Block->Bits[Byte] | USB_HC_BIT (Bit));
+    Block->Bits[Byte] = (UINT8)(Block->Bits[Byte] | USB_HC_BIT (Bit));
     NEXT_BIT (Byte, Bit);
   }
 
@@ -224,16 +213,16 @@ UsbHcAllocMemFromBlock (
 **/
 EFI_PHYSICAL_ADDRESS
 UsbHcGetPciAddrForHostAddr (
-  IN USBHC_MEM_POOL       *Pool,
-  IN VOID                 *Mem,
-  IN UINTN                Size
+  IN USBHC_MEM_POOL  *Pool,
+  IN VOID            *Mem,
+  IN UINTN           Size
   )
 {
-  USBHC_MEM_BLOCK         *Head;
-  USBHC_MEM_BLOCK         *Block;
-  UINTN                   AllocSize;
-  EFI_PHYSICAL_ADDRESS    PhyAddr;
-  UINTN                   Offset;
+  USBHC_MEM_BLOCK       *Head;
+  USBHC_MEM_BLOCK       *Block;
+  UINTN                 AllocSize;
+  EFI_PHYSICAL_ADDRESS  PhyAddr;
+  UINTN                 Offset;
 
   Head      = Pool->Head;
   AllocSize = USBHC_MEM_ROUND (Size);
@@ -247,7 +236,7 @@ UsbHcGetPciAddrForHostAddr (
     // scan the memory block list for the memory block that
     // completely contains the allocated memory.
     //
-    if ((Block->BufHost <= (UINT8 *) Mem) && (((UINT8 *) Mem + AllocSize) <= (Block->BufHost + Block->BufLen))) {
+    if ((Block->BufHost <= (UINT8 *)Mem) && (((UINT8 *)Mem + AllocSize) <= (Block->BufHost + Block->BufLen))) {
       break;
     }
   }
@@ -256,8 +245,8 @@ UsbHcGetPciAddrForHostAddr (
   //
   // calculate the pci memory address for host memory address.
   //
-  Offset = (UINT8 *)Mem - Block->BufHost;
-  PhyAddr = (EFI_PHYSICAL_ADDRESS)(UINTN) (Block->Buf + Offset);
+  Offset  = (UINT8 *)Mem - Block->BufHost;
+  PhyAddr = (EFI_PHYSICAL_ADDRESS)(UINTN)(Block->Buf + Offset);
   return PhyAddr;
 }
 
@@ -273,16 +262,16 @@ UsbHcGetPciAddrForHostAddr (
 **/
 EFI_PHYSICAL_ADDRESS
 UsbHcGetHostAddrForPciAddr (
-  IN USBHC_MEM_POOL       *Pool,
-  IN VOID                 *Mem,
-  IN UINTN                Size
+  IN USBHC_MEM_POOL  *Pool,
+  IN VOID            *Mem,
+  IN UINTN           Size
   )
 {
-  USBHC_MEM_BLOCK         *Head;
-  USBHC_MEM_BLOCK         *Block;
-  UINTN                   AllocSize;
-  EFI_PHYSICAL_ADDRESS    HostAddr;
-  UINTN                   Offset;
+  USBHC_MEM_BLOCK       *Head;
+  USBHC_MEM_BLOCK       *Block;
+  UINTN                 AllocSize;
+  EFI_PHYSICAL_ADDRESS  HostAddr;
+  UINTN                 Offset;
 
   Head      = Pool->Head;
   AllocSize = USBHC_MEM_ROUND (Size);
@@ -296,7 +285,7 @@ UsbHcGetHostAddrForPciAddr (
     // scan the memory block list for the memory block that
     // completely contains the allocated memory.
     //
-    if ((Block->Buf <= (UINT8 *) Mem) && (((UINT8 *) Mem + AllocSize) <= (Block->Buf + Block->BufLen))) {
+    if ((Block->Buf <= (UINT8 *)Mem) && (((UINT8 *)Mem + AllocSize) <= (Block->Buf + Block->BufLen))) {
       break;
     }
   }
@@ -305,8 +294,8 @@ UsbHcGetHostAddrForPciAddr (
   //
   // calculate the pci memory address for host memory address.
   //
-  Offset = (UINT8 *)Mem - Block->Buf;
-  HostAddr = (EFI_PHYSICAL_ADDRESS)(UINTN) (Block->BufHost + Offset);
+  Offset   = (UINT8 *)Mem - Block->Buf;
+  HostAddr = (EFI_PHYSICAL_ADDRESS)(UINTN)(Block->BufHost + Offset);
   return HostAddr;
 }
 
@@ -319,8 +308,8 @@ UsbHcGetHostAddrForPciAddr (
 **/
 VOID
 UsbHcInsertMemBlockToPool (
-  IN USBHC_MEM_BLOCK      *Head,
-  IN USBHC_MEM_BLOCK      *Block
+  IN USBHC_MEM_BLOCK  *Head,
+  IN USBHC_MEM_BLOCK  *Block
   )
 {
   ASSERT ((Head != NULL) && (Block != NULL));
@@ -328,7 +317,6 @@ UsbHcInsertMemBlockToPool (
   Head->Next  = Block;
 }
 
-
 /**
   Is the memory block empty?
 
@@ -340,10 +328,10 @@ UsbHcInsertMemBlockToPool (
 **/
 BOOLEAN
 UsbHcIsMemBlockEmpty (
-  IN USBHC_MEM_BLOCK     *Block
+  IN USBHC_MEM_BLOCK  *Block
   )
 {
-  UINTN                   Index;
+  UINTN  Index;
 
   for (Index = 0; Index < Block->BitsLen; Index++) {
     if (Block->Bits[Index] != 0) {
@@ -354,7 +342,6 @@ UsbHcIsMemBlockEmpty (
   return TRUE;
 }
 
-
 /**
   Unlink the memory block from the pool's list.
 
@@ -364,11 +351,11 @@ UsbHcIsMemBlockEmpty (
 **/
 VOID
 UsbHcUnlinkMemBlock (
-  IN USBHC_MEM_BLOCK      *Head,
-  IN USBHC_MEM_BLOCK      *BlockToUnlink
+  IN USBHC_MEM_BLOCK  *Head,
+  IN USBHC_MEM_BLOCK  *BlockToUnlink
   )
 {
-  USBHC_MEM_BLOCK         *Block;
+  USBHC_MEM_BLOCK  *Block;
 
   ASSERT ((Head != NULL) && (BlockToUnlink != NULL));
 
@@ -381,7 +368,6 @@ UsbHcUnlinkMemBlock (
   }
 }
 
-
 /**
   Initialize the memory management pool for the host controller.
 
@@ -396,7 +382,7 @@ UsbHcInitMemPool (
   IN EFI_PCI_IO_PROTOCOL  *PciIo
   )
 {
-  USBHC_MEM_POOL          *Pool;
+  USBHC_MEM_POOL  *Pool;
 
   Pool = AllocatePool (sizeof (USBHC_MEM_POOL));
 
@@ -404,8 +390,8 @@ UsbHcInitMemPool (
     return Pool;
   }
 
-  Pool->PciIo   = PciIo;
-  Pool->Head    = UsbHcAllocMemBlock (Pool, USBHC_MEM_DEFAULT_PAGES);
+  Pool->PciIo = PciIo;
+  Pool->Head  = UsbHcAllocMemBlock (Pool, USBHC_MEM_DEFAULT_PAGES);
 
   if (Pool->Head == NULL) {
     gBS->FreePool (Pool);
@@ -415,7 +401,6 @@ UsbHcInitMemPool (
   return Pool;
 }
 
-
 /**
   Release the memory management pool.
 
@@ -427,10 +412,10 @@ UsbHcInitMemPool (
 **/
 EFI_STATUS
 UsbHcFreeMemPool (
-  IN USBHC_MEM_POOL       *Pool
+  IN USBHC_MEM_POOL  *Pool
   )
 {
-  USBHC_MEM_BLOCK *Block;
+  USBHC_MEM_BLOCK  *Block;
 
   ASSERT (Pool->Head != NULL);
 
@@ -449,7 +434,6 @@ UsbHcFreeMemPool (
   return EFI_SUCCESS;
 }
 
-
 /**
   Allocate some memory from the host controller's memory pool
   which can be used to communicate with host controller.
@@ -462,16 +446,16 @@ UsbHcFreeMemPool (
 **/
 VOID *
 UsbHcAllocateMem (
-  IN  USBHC_MEM_POOL      *Pool,
-  IN  UINTN               Size
+  IN  USBHC_MEM_POOL  *Pool,
+  IN  UINTN           Size
   )
 {
-  USBHC_MEM_BLOCK         *Head;
-  USBHC_MEM_BLOCK         *Block;
-  USBHC_MEM_BLOCK         *NewBlock;
-  VOID                    *Mem;
-  UINTN                   AllocSize;
-  UINTN                   Pages;
+  USBHC_MEM_BLOCK  *Head;
+  USBHC_MEM_BLOCK  *Block;
+  USBHC_MEM_BLOCK  *NewBlock;
+  VOID             *Mem;
+  UINTN            AllocSize;
+  UINTN            Pages;
 
   Mem       = NULL;
   AllocSize = USBHC_MEM_ROUND (Size);
@@ -509,7 +493,7 @@ UsbHcAllocateMem (
   NewBlock = UsbHcAllocMemBlock (Pool, Pages);
 
   if (NewBlock == NULL) {
-    DEBUG ((EFI_D_ERROR, "UsbHcAllocateMem: failed to allocate block\n"));
+    DEBUG ((DEBUG_ERROR, "UsbHcAllocateMem: failed to allocate block\n"));
     return NULL;
   }
 
@@ -526,7 +510,6 @@ UsbHcAllocateMem (
   return Mem;
 }
 
-
 /**
   Free the allocated memory back to the memory pool.
 
@@ -537,22 +520,22 @@ UsbHcAllocateMem (
 **/
 VOID
 UsbHcFreeMem (
-  IN USBHC_MEM_POOL       *Pool,
-  IN VOID                 *Mem,
-  IN UINTN                Size
+  IN USBHC_MEM_POOL  *Pool,
+  IN VOID            *Mem,
+  IN UINTN           Size
   )
 {
-  USBHC_MEM_BLOCK         *Head;
-  USBHC_MEM_BLOCK         *Block;
-  UINT8                   *ToFree;
-  UINTN                   AllocSize;
-  UINTN                   Byte;
-  UINTN                   Bit;
-  UINTN                   Count;
+  USBHC_MEM_BLOCK  *Head;
+  USBHC_MEM_BLOCK  *Block;
+  UINT8            *ToFree;
+  UINTN            AllocSize;
+  UINTN            Byte;
+  UINTN            Bit;
+  UINTN            Count;
 
   Head      = Pool->Head;
   AllocSize = USBHC_MEM_ROUND (Size);
-  ToFree    = (UINT8 *) Mem;
+  ToFree    = (UINT8 *)Mem;
 
   for (Block = Head; Block != NULL; Block = Block->Next) {
     //
@@ -563,16 +546,16 @@ UsbHcFreeMem (
       //
       // compute the start byte and bit in the bit array
       //
-      Byte  = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) / 8;
-      Bit   = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) % 8;
+      Byte = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) / 8;
+      Bit  = ((ToFree - Block->BufHost) / USBHC_MEM_UNIT) % 8;
 
       //
-      // reset associated bits in bit arry
+      // reset associated bits in bit array
       //
       for (Count = 0; Count < (AllocSize / USBHC_MEM_UNIT); Count++) {
         ASSERT (USB_HC_BIT_IS_SET (Block->Bits[Byte], Bit));
 
-        Block->Bits[Byte] = (UINT8) (Block->Bits[Byte] ^ USB_HC_BIT (Bit));
+        Block->Bits[Byte] = (UINT8)(Block->Bits[Byte] ^ USB_HC_BIT (Bit));
         NEXT_BIT (Byte, Bit);
       }
 
@@ -595,26 +578,26 @@ UsbHcFreeMem (
     UsbHcFreeMemBlock (Pool, Block);
   }
 
-  return ;
+  return;
 }
 
-/**  
+/**
   Allocates pages at a specified alignment that are suitable for an EfiPciIoOperationBusMasterCommonBuffer mapping.
-  
+
   If Alignment is not a power of two and Alignment is not zero, then ASSERT().
 
   @param  PciIo                 The PciIo that can be used to access the host controller.
   @param  Pages                 The number of pages to allocate.
   @param  Alignment             The requested alignment of the allocation.  Must be a power of two.
   @param  HostAddress           The system memory address to map to the PCI controller.
-  @param  DeviceAddress         The resulting map address for the bus master PCI controller to 
+  @param  DeviceAddress         The resulting map address for the bus master PCI controller to
                                 use to access the hosts HostAddress.
   @param  Mapping               A resulting value to pass to Unmap().
 
   @retval EFI_SUCCESS           Success to allocate aligned pages.
   @retval EFI_INVALID_PARAMETER Pages or Alignment is not valid.
   @retval EFI_OUT_OF_RESOURCES  Do not have enough resources to allocate memory.
-  
+
 
 **/
 EFI_STATUS
@@ -627,50 +610,52 @@ UsbHcAllocateAlignedPages (
   OUT VOID                  **Mapping
   )
 {
-  EFI_STATUS            Status;
-  VOID                  *Memory;
-  UINTN                 AlignedMemory;
-  UINTN                 AlignmentMask;
-  UINTN                 UnalignedPages;
-  UINTN                 RealPages;
-  UINTN                 Bytes;
+  EFI_STATUS  Status;
+  VOID        *Memory;
+  UINTN       AlignedMemory;
+  UINTN       AlignmentMask;
+  UINTN       UnalignedPages;
+  UINTN       RealPages;
+  UINTN       Bytes;
 
   //
   // Alignment must be a power of two or zero.
   //
   ASSERT ((Alignment & (Alignment - 1)) == 0);
-  
+
   if ((Alignment & (Alignment - 1)) != 0) {
     return EFI_INVALID_PARAMETER;
   }
- 
+
   if (Pages == 0) {
     return EFI_INVALID_PARAMETER;
   }
+
   if (Alignment > EFI_PAGE_SIZE) {
     //
-    // Caculate the total number of pages since alignment is larger than page size.
+    // Calculate the total number of pages since alignment is larger than page size.
     //
-    AlignmentMask  = Alignment - 1;
-    RealPages      = Pages + EFI_SIZE_TO_PAGES (Alignment);
+    AlignmentMask = Alignment - 1;
+    RealPages     = Pages + EFI_SIZE_TO_PAGES (Alignment);
     //
     // Make sure that Pages plus EFI_SIZE_TO_PAGES (Alignment) does not overflow.
     //
     ASSERT (RealPages > Pages);
- 
+
     Status = PciIo->AllocateBuffer (
                       PciIo,
                       AllocateAnyPages,
                       EfiBootServicesData,
-                      Pages,
+                      RealPages,
                       &Memory,
                       0
-                      );    
+                      );
     if (EFI_ERROR (Status)) {
       return EFI_OUT_OF_RESOURCES;
     }
-    AlignedMemory  = ((UINTN) Memory + AlignmentMask) & ~AlignmentMask;
-    UnalignedPages = EFI_SIZE_TO_PAGES (AlignedMemory - (UINTN) Memory);
+
+    AlignedMemory  = ((UINTN)Memory + AlignmentMask) & ~AlignmentMask;
+    UnalignedPages = EFI_SIZE_TO_PAGES (AlignedMemory - (UINTN)Memory);
     if (UnalignedPages > 0) {
       //
       // Free first unaligned page(s).
@@ -678,6 +663,7 @@ UsbHcAllocateAlignedPages (
       Status = PciIo->FreeBuffer (PciIo, UnalignedPages, Memory);
       ASSERT_EFI_ERROR (Status);
     }
+
     Memory         = (VOID *)(UINTN)(AlignedMemory + EFI_PAGES_TO_SIZE (Pages));
     UnalignedPages = RealPages - Pages - UnalignedPages;
     if (UnalignedPages > 0) {
@@ -702,32 +688,33 @@ UsbHcAllocateAlignedPages (
     if (EFI_ERROR (Status)) {
       return EFI_OUT_OF_RESOURCES;
     }
-    AlignedMemory  = (UINTN) Memory;
+
+    AlignedMemory = (UINTN)Memory;
   }
 
-  Bytes = EFI_PAGES_TO_SIZE (Pages);
+  Bytes  = EFI_PAGES_TO_SIZE (Pages);
   Status = PciIo->Map (
                     PciIo,
                     EfiPciIoOperationBusMasterCommonBuffer,
-                    (VOID *) AlignedMemory,
+                    (VOID *)AlignedMemory,
                     &Bytes,
                     DeviceAddress,
                     Mapping
                     );
 
   if (EFI_ERROR (Status) || (Bytes != EFI_PAGES_TO_SIZE (Pages))) {
-    Status = PciIo->FreeBuffer (PciIo, Pages, (VOID *) AlignedMemory);
+    Status = PciIo->FreeBuffer (PciIo, Pages, (VOID *)AlignedMemory);
     return EFI_OUT_OF_RESOURCES;
   }
-  
-  *HostAddress = (VOID *) AlignedMemory;
+
+  *HostAddress = (VOID *)AlignedMemory;
 
   return EFI_SUCCESS;
 }
 
 /**
   Frees memory that was allocated with UsbHcAllocateAlignedPages().
-  
+
   @param  PciIo                 The PciIo that can be used to access the host controller.
   @param  HostAddress           The system memory address to map to the PCI controller.
   @param  Pages                 The number of 4 KB pages to free.
@@ -736,16 +723,16 @@ UsbHcAllocateAlignedPages (
 **/
 VOID
 UsbHcFreeAlignedPages (
-  IN EFI_PCI_IO_PROTOCOL    *PciIo,
-  IN VOID                   *HostAddress,
-  IN UINTN                  Pages,
-  VOID                      *Mapping
+  IN EFI_PCI_IO_PROTOCOL  *PciIo,
+  IN VOID                 *HostAddress,
+  IN UINTN                Pages,
+  VOID                    *Mapping
   )
 {
-  EFI_STATUS      Status;
-  
+  EFI_STATUS  Status;
+
   ASSERT (Pages != 0);
-  
+
   Status = PciIo->Unmap (PciIo, Mapping);
   ASSERT_EFI_ERROR (Status);
 
@@ -753,6 +740,6 @@ UsbHcFreeAlignedPages (
                     PciIo,
                     Pages,
                     HostAddress
-                    );     
+                    );
   ASSERT_EFI_ERROR (Status);
 }
