@@ -3,13 +3,7 @@
   The XHCI register operation routines.
 
 Copyright (c) 2011 - 2017, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -27,24 +21,24 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 **/
 UINT8
 XhcReadCapReg8 (
-  IN  USB_XHCI_INSTANCE   *Xhc,
-  IN  UINT32              Offset
+  IN  USB_XHCI_INSTANCE  *Xhc,
+  IN  UINT32             Offset
   )
 {
-  UINT8                   Data;
-  EFI_STATUS              Status;
+  UINT8       Data;
+  EFI_STATUS  Status;
 
   Status = Xhc->PciIo->Mem.Read (
                              Xhc->PciIo,
                              EfiPciIoWidthUint8,
                              XHC_BAR_INDEX,
-                             (UINT64) Offset,
+                             (UINT64)Offset,
                              1,
                              &Data
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcReadCapReg: Pci Io read error - %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcReadCapReg: Pci Io read error - %r at %d\n", Status, Offset));
     Data = 0xFF;
   }
 
@@ -63,24 +57,24 @@ XhcReadCapReg8 (
 **/
 UINT32
 XhcReadCapReg (
-  IN  USB_XHCI_INSTANCE   *Xhc,
-  IN  UINT32              Offset
+  IN  USB_XHCI_INSTANCE  *Xhc,
+  IN  UINT32             Offset
   )
 {
-  UINT32                  Data;
-  EFI_STATUS              Status;
+  UINT32      Data;
+  EFI_STATUS  Status;
 
   Status = Xhc->PciIo->Mem.Read (
                              Xhc->PciIo,
                              EfiPciIoWidthUint32,
                              XHC_BAR_INDEX,
-                             (UINT64) Offset,
+                             (UINT64)Offset,
                              1,
                              &Data
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcReadCapReg: Pci Io read error - %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcReadCapReg: Pci Io read error - %r at %d\n", Status, Offset));
     Data = 0xFFFFFFFF;
   }
 
@@ -99,12 +93,12 @@ XhcReadCapReg (
 **/
 UINT32
 XhcReadOpReg (
-  IN  USB_XHCI_INSTANCE   *Xhc,
-  IN  UINT32              Offset
+  IN  USB_XHCI_INSTANCE  *Xhc,
+  IN  UINT32             Offset
   )
 {
-  UINT32                  Data;
-  EFI_STATUS              Status;
+  UINT32      Data;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->CapLength != 0);
 
@@ -118,7 +112,7 @@ XhcReadOpReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcReadOpReg: Pci Io Read error - %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcReadOpReg: Pci Io Read error - %r at %d\n", Status, Offset));
     Data = 0xFFFFFFFF;
   }
 
@@ -135,12 +129,12 @@ XhcReadOpReg (
 **/
 VOID
 XhcWriteOpReg (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Data
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Data
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->CapLength != 0);
 
@@ -154,14 +148,10 @@ XhcWriteOpReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcWriteOpReg: Pci Io Write error: %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcWriteOpReg: Pci Io Write error: %r at %d\n", Status, Offset));
   }
 }
 
-
-
-
-
 /**
   Write the data to the XHCI door bell register.
 
@@ -172,12 +162,12 @@ XhcWriteOpReg (
 **/
 VOID
 XhcWriteDoorBellReg (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Data
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Data
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->DBOff != 0);
 
@@ -191,7 +181,7 @@ XhcWriteDoorBellReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcWriteOpReg: Pci Io Write error: %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcWriteOpReg: Pci Io Write error: %r at %d\n", Status, Offset));
   }
 }
 
@@ -206,12 +196,12 @@ XhcWriteDoorBellReg (
 **/
 UINT32
 XhcReadRuntimeReg (
-  IN  USB_XHCI_INSTANCE   *Xhc,
-  IN  UINT32              Offset
+  IN  USB_XHCI_INSTANCE  *Xhc,
+  IN  UINT32             Offset
   )
 {
-  UINT32                  Data;
-  EFI_STATUS              Status;
+  UINT32      Data;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->RTSOff != 0);
 
@@ -225,7 +215,7 @@ XhcReadRuntimeReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcReadRuntimeReg: Pci Io Read error - %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcReadRuntimeReg: Pci Io Read error - %r at %d\n", Status, Offset));
     Data = 0xFFFFFFFF;
   }
 
@@ -242,12 +232,12 @@ XhcReadRuntimeReg (
 **/
 VOID
 XhcWriteRuntimeReg (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Data
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Data
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->RTSOff != 0);
 
@@ -261,7 +251,7 @@ XhcWriteRuntimeReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcWriteRuntimeReg: Pci Io Write error: %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcWriteRuntimeReg: Pci Io Write error: %r at %d\n", Status, Offset));
   }
 }
 
@@ -276,12 +266,12 @@ XhcWriteRuntimeReg (
 **/
 UINT32
 XhcReadExtCapReg (
-  IN  USB_XHCI_INSTANCE   *Xhc,
-  IN  UINT32              Offset
+  IN  USB_XHCI_INSTANCE  *Xhc,
+  IN  UINT32             Offset
   )
 {
-  UINT32                  Data;
-  EFI_STATUS              Status;
+  UINT32      Data;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->ExtCapRegBase != 0);
 
@@ -295,7 +285,7 @@ XhcReadExtCapReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcReadExtCapReg: Pci Io Read error - %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcReadExtCapReg: Pci Io Read error - %r at %d\n", Status, Offset));
     Data = 0xFFFFFFFF;
   }
 
@@ -312,12 +302,12 @@ XhcReadExtCapReg (
 **/
 VOID
 XhcWriteExtCapReg (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Data
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Data
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   ASSERT (Xhc->ExtCapRegBase != 0);
 
@@ -331,11 +321,10 @@ XhcWriteExtCapReg (
                              );
 
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "XhcWriteExtCapReg: Pci Io Write error: %r at %d\n", Status, Offset));
+    DEBUG ((DEBUG_ERROR, "XhcWriteExtCapReg: Pci Io Write error: %r at %d\n", Status, Offset));
   }
 }
 
-
 /**
   Set one bit of the runtime register while keeping other bits.
 
@@ -346,12 +335,12 @@ XhcWriteExtCapReg (
 **/
 VOID
 XhcSetRuntimeRegBit (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Bit
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Bit
   )
 {
-  UINT32                  Data;
+  UINT32  Data;
 
   Data  = XhcReadRuntimeReg (Xhc, Offset);
   Data |= Bit;
@@ -368,12 +357,12 @@ XhcSetRuntimeRegBit (
 **/
 VOID
 XhcClearRuntimeRegBit (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Bit
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Bit
   )
 {
-  UINT32                  Data;
+  UINT32  Data;
 
   Data  = XhcReadRuntimeReg (Xhc, Offset);
   Data &= ~Bit;
@@ -390,19 +379,18 @@ XhcClearRuntimeRegBit (
 **/
 VOID
 XhcSetOpRegBit (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Bit
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Bit
   )
 {
-  UINT32                  Data;
+  UINT32  Data;
 
   Data  = XhcReadOpReg (Xhc, Offset);
   Data |= Bit;
   XhcWriteOpReg (Xhc, Offset, Data);
 }
 
-
 /**
   Clear one bit of the operational register while keeping other bits.
 
@@ -413,12 +401,12 @@ XhcSetOpRegBit (
 **/
 VOID
 XhcClearOpRegBit (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Bit
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Bit
   )
 {
-  UINT32                  Data;
+  UINT32  Data;
 
   Data  = XhcReadOpReg (Xhc, Offset);
   Data &= ~Bit;
@@ -429,39 +417,74 @@ XhcClearOpRegBit (
   Wait the operation register's bit as specified by Bit
   to become set (or clear).
 
-  @param  Xhc          The XHCI Instance.
-  @param  Offset       The offset of the operation register.
-  @param  Bit          The bit of the register to wait for.
-  @param  WaitToSet    Wait the bit to set or clear.
-  @param  Timeout      The time to wait before abort (in millisecond, ms).
+  @param  Xhc                    The XHCI Instance.
+  @param  Offset                 The offset of the operation register.
+  @param  Bit                    The bit of the register to wait for.
+  @param  WaitToSet              Wait the bit to set or clear.
+  @param  Timeout                The time to wait before abort (in millisecond, ms).
 
-  @retval EFI_SUCCESS  The bit successfully changed by host controller.
-  @retval EFI_TIMEOUT  The time out occurred.
+  @retval EFI_SUCCESS            The bit successfully changed by host controller.
+  @retval EFI_TIMEOUT            The time out occurred.
+  @retval EFI_OUT_OF_RESOURCES   Memory for the timer event could not be allocated.
 
 **/
 EFI_STATUS
 XhcWaitOpRegBit (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Offset,
-  IN UINT32               Bit,
-  IN BOOLEAN              WaitToSet,
-  IN UINT32               Timeout
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Offset,
+  IN UINT32             Bit,
+  IN BOOLEAN            WaitToSet,
+  IN UINT32             Timeout
   )
 {
-  UINT32                  Index;
-  UINT64                  Loop;
+  EFI_STATUS  Status;
+  EFI_EVENT   TimeoutEvent;
 
-  Loop   = Timeout * XHC_1_MILLISECOND;
+  TimeoutEvent = NULL;
 
-  for (Index = 0; Index < Loop; Index++) {
+  if (Timeout == 0) {
+    return EFI_TIMEOUT;
+  }
+
+  Status = gBS->CreateEvent (
+                  EVT_TIMER,
+                  TPL_CALLBACK,
+                  NULL,
+                  NULL,
+                  &TimeoutEvent
+                  );
+
+  if (EFI_ERROR (Status)) {
+    goto DONE;
+  }
+
+  Status = gBS->SetTimer (
+                  TimeoutEvent,
+                  TimerRelative,
+                  EFI_TIMER_PERIOD_MILLISECONDS (Timeout)
+                  );
+
+  if (EFI_ERROR (Status)) {
+    goto DONE;
+  }
+
+  do {
     if (XHC_REG_BIT_IS_SET (Xhc, Offset, Bit) == WaitToSet) {
-      return EFI_SUCCESS;
+      Status = EFI_SUCCESS;
+      goto DONE;
     }
 
     gBS->Stall (XHC_1_MICROSECOND);
+  } while (EFI_ERROR (gBS->CheckEvent (TimeoutEvent)));
+
+  Status = EFI_TIMEOUT;
+
+DONE:
+  if (TimeoutEvent != NULL) {
+    gBS->CloseEvent (TimeoutEvent);
   }
 
-  return EFI_TIMEOUT;
+  return Status;
 }
 
 /**
@@ -472,16 +495,16 @@ XhcWaitOpRegBit (
 **/
 VOID
 XhcSetBiosOwnership (
-  IN USB_XHCI_INSTANCE    *Xhc
+  IN USB_XHCI_INSTANCE  *Xhc
   )
 {
-  UINT32                    Buffer;
+  UINT32  Buffer;
 
   if (Xhc->UsbLegSupOffset == 0xFFFFFFFF) {
     return;
   }
 
-  DEBUG ((EFI_D_INFO, "XhcSetBiosOwnership: called to set BIOS ownership\n"));
+  DEBUG ((DEBUG_INFO, "XhcSetBiosOwnership: called to set BIOS ownership\n"));
 
   Buffer = XhcReadExtCapReg (Xhc, Xhc->UsbLegSupOffset);
   Buffer = ((Buffer & (~USBLEGSP_OS_SEMAPHORE)) | USBLEGSP_BIOS_SEMAPHORE);
@@ -496,16 +519,16 @@ XhcSetBiosOwnership (
 **/
 VOID
 XhcClearBiosOwnership (
-  IN USB_XHCI_INSTANCE    *Xhc
+  IN USB_XHCI_INSTANCE  *Xhc
   )
 {
-  UINT32                    Buffer;
+  UINT32  Buffer;
 
   if (Xhc->UsbLegSupOffset == 0xFFFFFFFF) {
     return;
   }
 
-  DEBUG ((EFI_D_INFO, "XhcClearBiosOwnership: called to clear BIOS ownership\n"));
+  DEBUG ((DEBUG_INFO, "XhcClearBiosOwnership: called to clear BIOS ownership\n"));
 
   Buffer = XhcReadExtCapReg (Xhc, Xhc->UsbLegSupOffset);
   Buffer = ((Buffer & (~USBLEGSP_BIOS_SEMAPHORE)) | USBLEGSP_OS_SEMAPHORE);
@@ -523,13 +546,13 @@ XhcClearBiosOwnership (
 **/
 UINT32
 XhcGetCapabilityAddr (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT8                CapId
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT8              CapId
   )
 {
-  UINT32 ExtCapOffset;
-  UINT8  NextExtCapReg;
-  UINT32 Data;
+  UINT32  ExtCapOffset;
+  UINT8   NextExtCapReg;
+  UINT32  Data;
 
   ExtCapOffset = 0;
 
@@ -541,6 +564,7 @@ XhcGetCapabilityAddr (
     if ((Data & 0xFF) == CapId) {
       return ExtCapOffset;
     }
+
     //
     // If not, then traverse all of the ext capability registers till finding out it.
     //
@@ -562,13 +586,12 @@ XhcGetCapabilityAddr (
 **/
 BOOLEAN
 XhcIsHalt (
-  IN USB_XHCI_INSTANCE    *Xhc
+  IN USB_XHCI_INSTANCE  *Xhc
   )
 {
   return XHC_REG_BIT_IS_SET (Xhc, XHC_USBSTS_OFFSET, XHC_USBSTS_HALT);
 }
 
-
 /**
   Whether system error occurred.
 
@@ -580,7 +603,7 @@ XhcIsHalt (
 **/
 BOOLEAN
 XhcIsSysError (
-  IN USB_XHCI_INSTANCE    *Xhc
+  IN USB_XHCI_INSTANCE  *Xhc
   )
 {
   return XHC_REG_BIT_IS_SET (Xhc, XHC_USBSTS_OFFSET, XHC_USBSTS_HSE);
@@ -600,11 +623,11 @@ XhcSetHsee (
   IN USB_XHCI_INSTANCE  *Xhc
   )
 {
-  EFI_STATUS            Status;
-  EFI_PCI_IO_PROTOCOL   *PciIo;
-  UINT16                XhciCmd;
+  EFI_STATUS           Status;
+  EFI_PCI_IO_PROTOCOL  *PciIo;
+  UINT16               XhciCmd;
 
-  PciIo = Xhc->PciIo;
+  PciIo  = Xhc->PciIo;
   Status = PciIo->Pci.Read (
                         PciIo,
                         EfiPciIoWidthUint16,
@@ -631,15 +654,15 @@ XhcSetHsee (
 **/
 EFI_STATUS
 XhcResetHC (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Timeout
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Timeout
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   Status = EFI_SUCCESS;
 
-  DEBUG ((EFI_D_INFO, "XhcResetHC!\n"));
+  DEBUG ((DEBUG_INFO, "XhcResetHC!\n"));
   //
   // Host can only be reset when it is halt. If not so, halt it
   //
@@ -652,7 +675,8 @@ XhcResetHC (
   }
 
   if ((Xhc->DebugCapSupOffset == 0xFFFFFFFF) || ((XhcReadExtCapReg (Xhc, Xhc->DebugCapSupOffset) & 0xFF) != XHC_CAP_USB_DEBUG) ||
-      ((XhcReadExtCapReg (Xhc, Xhc->DebugCapSupOffset + XHC_DC_DCCTRL) & BIT0) == 0)) {
+      ((XhcReadExtCapReg (Xhc, Xhc->DebugCapSupOffset + XHC_DC_DCCTRL) & BIT0) == 0))
+  {
     XhcSetOpRegBit (Xhc, XHC_USBCMD_OFFSET, XHC_USBCMD_RESET);
     //
     // Some XHCI host controllers require to have extra 1ms delay before accessing any MMIO register during reset.
@@ -674,7 +698,6 @@ XhcResetHC (
   return Status;
 }
 
-
 /**
   Halt the XHCI host controller.
 
@@ -687,18 +710,17 @@ XhcResetHC (
 **/
 EFI_STATUS
 XhcHaltHC (
-  IN USB_XHCI_INSTANCE   *Xhc,
-  IN UINT32              Timeout
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Timeout
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   XhcClearOpRegBit (Xhc, XHC_USBCMD_OFFSET, XHC_USBCMD_RUN);
   Status = XhcWaitOpRegBit (Xhc, XHC_USBSTS_OFFSET, XHC_USBSTS_HALT, TRUE, Timeout);
   return Status;
 }
 
-
 /**
   Set the XHCI host controller to run.
 
@@ -711,14 +733,13 @@ XhcHaltHC (
 **/
 EFI_STATUS
 XhcRunHC (
-  IN USB_XHCI_INSTANCE    *Xhc,
-  IN UINT32               Timeout
+  IN USB_XHCI_INSTANCE  *Xhc,
+  IN UINT32             Timeout
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   XhcSetOpRegBit (Xhc, XHC_USBCMD_OFFSET, XHC_USBCMD_RUN);
   Status = XhcWaitOpRegBit (Xhc, XHC_USBSTS_OFFSET, XHC_USBSTS_HALT, FALSE, Timeout);
   return Status;
 }
-
