@@ -14,34 +14,34 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 // Global to avoid infinite reentrance of memory allocation when updating
 // page table attributes, which may need allocate pages for new PDE/PTE.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED BOOLEAN mOnGuarding = FALSE;
+GLOBAL_REMOVE_IF_UNREFERENCED BOOLEAN  mOnGuarding = FALSE;
 
 //
 // Pointer to table tracking the Guarded memory with bitmap, in which  '1'
 // is used to indicate memory guarded. '0' might be free memory or Guard
 // page itself, depending on status of memory adjacent to it.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED UINT64 mGuardedMemoryMap = 0;
+GLOBAL_REMOVE_IF_UNREFERENCED UINT64  mGuardedMemoryMap = 0;
 
 //
 // Current depth level of map table pointed by mGuardedMemoryMap.
 // mMapLevel must be initialized at least by 1. It will be automatically
 // updated according to the address of memory just tracked.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED UINTN mMapLevel = 1;
+GLOBAL_REMOVE_IF_UNREFERENCED UINTN  mMapLevel = 1;
 
 //
 // Shift and mask for each level of map table
 //
-GLOBAL_REMOVE_IF_UNREFERENCED UINTN mLevelShift[GUARDED_HEAP_MAP_TABLE_DEPTH]
-                                    = GUARDED_HEAP_MAP_TABLE_DEPTH_SHIFTS;
-GLOBAL_REMOVE_IF_UNREFERENCED UINTN mLevelMask[GUARDED_HEAP_MAP_TABLE_DEPTH]
-                                    = GUARDED_HEAP_MAP_TABLE_DEPTH_MASKS;
+GLOBAL_REMOVE_IF_UNREFERENCED UINTN  mLevelShift[GUARDED_HEAP_MAP_TABLE_DEPTH]
+  = GUARDED_HEAP_MAP_TABLE_DEPTH_SHIFTS;
+GLOBAL_REMOVE_IF_UNREFERENCED UINTN  mLevelMask[GUARDED_HEAP_MAP_TABLE_DEPTH]
+  = GUARDED_HEAP_MAP_TABLE_DEPTH_MASKS;
 
 //
 // Used for promoting freed but not used pages.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED EFI_PHYSICAL_ADDRESS mLastPromotedPage = BASE_4GB;
+GLOBAL_REMOVE_IF_UNREFERENCED EFI_PHYSICAL_ADDRESS  mLastPromotedPage = BASE_4GB;
 
 /**
   Set corresponding bits in bitmap table to 1 according to the address.
@@ -55,29 +55,29 @@ GLOBAL_REMOVE_IF_UNREFERENCED EFI_PHYSICAL_ADDRESS mLastPromotedPage = BASE_4GB;
 STATIC
 VOID
 SetBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   BitNumber,
-  IN UINT64                  *BitMap
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 BitNumber,
+  IN UINT64                *BitMap
   )
 {
-  UINTN           Lsbs;
-  UINTN           Qwords;
-  UINTN           Msbs;
-  UINTN           StartBit;
-  UINTN           EndBit;
+  UINTN  Lsbs;
+  UINTN  Qwords;
+  UINTN  Msbs;
+  UINTN  StartBit;
+  UINTN  EndBit;
 
-  StartBit  = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
-  EndBit    = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
+  StartBit = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
+  EndBit   = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
 
   if ((StartBit + BitNumber) >= GUARDED_HEAP_MAP_ENTRY_BITS) {
-    Msbs    = (GUARDED_HEAP_MAP_ENTRY_BITS - StartBit) %
-              GUARDED_HEAP_MAP_ENTRY_BITS;
-    Lsbs    = (EndBit + 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
-    Qwords  = (BitNumber - Msbs) / GUARDED_HEAP_MAP_ENTRY_BITS;
+    Msbs = (GUARDED_HEAP_MAP_ENTRY_BITS - StartBit) %
+           GUARDED_HEAP_MAP_ENTRY_BITS;
+    Lsbs   = (EndBit + 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
+    Qwords = (BitNumber - Msbs) / GUARDED_HEAP_MAP_ENTRY_BITS;
   } else {
-    Msbs    = BitNumber;
-    Lsbs    = 0;
-    Qwords  = 0;
+    Msbs   = BitNumber;
+    Lsbs   = 0;
+    Qwords = 0;
   }
 
   if (Msbs > 0) {
@@ -86,8 +86,11 @@ SetBits (
   }
 
   if (Qwords > 0) {
-    SetMem64 ((VOID *)BitMap, Qwords * GUARDED_HEAP_MAP_ENTRY_BYTES,
-              (UINT64)-1);
+    SetMem64 (
+      (VOID *)BitMap,
+      Qwords * GUARDED_HEAP_MAP_ENTRY_BYTES,
+      (UINT64)-1
+      );
     BitMap += Qwords;
   }
 
@@ -108,29 +111,29 @@ SetBits (
 STATIC
 VOID
 ClearBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   BitNumber,
-  IN UINT64                  *BitMap
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 BitNumber,
+  IN UINT64                *BitMap
   )
 {
-  UINTN           Lsbs;
-  UINTN           Qwords;
-  UINTN           Msbs;
-  UINTN           StartBit;
-  UINTN           EndBit;
+  UINTN  Lsbs;
+  UINTN  Qwords;
+  UINTN  Msbs;
+  UINTN  StartBit;
+  UINTN  EndBit;
 
-  StartBit  = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
-  EndBit    = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
+  StartBit = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
+  EndBit   = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
 
   if ((StartBit + BitNumber) >= GUARDED_HEAP_MAP_ENTRY_BITS) {
-    Msbs    = (GUARDED_HEAP_MAP_ENTRY_BITS - StartBit) %
-              GUARDED_HEAP_MAP_ENTRY_BITS;
-    Lsbs    = (EndBit + 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
-    Qwords  = (BitNumber - Msbs) / GUARDED_HEAP_MAP_ENTRY_BITS;
+    Msbs = (GUARDED_HEAP_MAP_ENTRY_BITS - StartBit) %
+           GUARDED_HEAP_MAP_ENTRY_BITS;
+    Lsbs   = (EndBit + 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
+    Qwords = (BitNumber - Msbs) / GUARDED_HEAP_MAP_ENTRY_BITS;
   } else {
-    Msbs    = BitNumber;
-    Lsbs    = 0;
-    Qwords  = 0;
+    Msbs   = BitNumber;
+    Lsbs   = 0;
+    Qwords = 0;
   }
 
   if (Msbs > 0) {
@@ -163,21 +166,21 @@ ClearBits (
 STATIC
 UINT64
 GetBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   BitNumber,
-  IN UINT64                  *BitMap
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 BitNumber,
+  IN UINT64                *BitMap
   )
 {
-  UINTN           StartBit;
-  UINTN           EndBit;
-  UINTN           Lsbs;
-  UINTN           Msbs;
-  UINT64          Result;
+  UINTN   StartBit;
+  UINTN   EndBit;
+  UINTN   Lsbs;
+  UINTN   Msbs;
+  UINT64  Result;
 
   ASSERT (BitNumber <= GUARDED_HEAP_MAP_ENTRY_BITS);
 
-  StartBit  = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
-  EndBit    = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
+  StartBit = (UINTN)GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address);
+  EndBit   = (StartBit + BitNumber - 1) % GUARDED_HEAP_MAP_ENTRY_BITS;
 
   if ((StartBit + BitNumber) > GUARDED_HEAP_MAP_ENTRY_BITS) {
     Msbs = GUARDED_HEAP_MAP_ENTRY_BITS - StartBit;
@@ -187,13 +190,13 @@ GetBits (
     Lsbs = 0;
   }
 
-  if (StartBit == 0 && BitNumber == GUARDED_HEAP_MAP_ENTRY_BITS) {
+  if ((StartBit == 0) && (BitNumber == GUARDED_HEAP_MAP_ENTRY_BITS)) {
     Result = *BitMap;
   } else {
-    Result    = RShiftU64((*BitMap), StartBit) & (LShiftU64(1, Msbs) - 1);
+    Result = RShiftU64 ((*BitMap), StartBit) & (LShiftU64 (1, Msbs) - 1);
     if (Lsbs > 0) {
-      BitMap  += 1;
-      Result  |= LShiftU64 ((*BitMap) & (LShiftU64 (1, Lsbs) - 1), Msbs);
+      BitMap += 1;
+      Result |= LShiftU64 ((*BitMap) & (LShiftU64 (1, Lsbs) - 1), Msbs);
     }
   }
 
@@ -212,18 +215,18 @@ GetBits (
 **/
 UINTN
 FindGuardedMemoryMap (
-  IN  EFI_PHYSICAL_ADDRESS    Address,
-  IN  BOOLEAN                 AllocMapUnit,
-  OUT UINT64                  **BitMap
+  IN  EFI_PHYSICAL_ADDRESS  Address,
+  IN  BOOLEAN               AllocMapUnit,
+  OUT UINT64                **BitMap
   )
 {
-  UINTN                   Level;
-  UINT64                  *GuardMap;
-  UINT64                  MapMemory;
-  UINTN                   Index;
-  UINTN                   Size;
-  UINTN                   BitsToUnitEnd;
-  EFI_STATUS              Status;
+  UINTN       Level;
+  UINT64      *GuardMap;
+  UINT64      MapMemory;
+  UINTN       Index;
+  UINTN       Size;
+  UINTN       BitsToUnitEnd;
+  EFI_STATUS  Status;
 
   MapMemory = 0;
 
@@ -235,50 +238,49 @@ FindGuardedMemoryMap (
          RShiftU64 (
            Address,
            mLevelShift[GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel - 1]
-           ) != 0) {
-
+           ) != 0)
+  {
     if (mGuardedMemoryMap != 0) {
       Size = (mLevelMask[GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel - 1] + 1)
              * GUARDED_HEAP_MAP_ENTRY_BYTES;
       Status = CoreInternalAllocatePages (
-                  AllocateAnyPages,
-                  EfiBootServicesData,
-                  EFI_SIZE_TO_PAGES (Size),
-                  &MapMemory,
-                  FALSE
-                  );
+                 AllocateAnyPages,
+                 EfiBootServicesData,
+                 EFI_SIZE_TO_PAGES (Size),
+                 &MapMemory,
+                 FALSE
+                 );
       ASSERT_EFI_ERROR (Status);
       ASSERT (MapMemory != 0);
 
       SetMem ((VOID *)(UINTN)MapMemory, Size, 0);
 
       *(UINT64 *)(UINTN)MapMemory = mGuardedMemoryMap;
-      mGuardedMemoryMap = MapMemory;
+      mGuardedMemoryMap           = MapMemory;
     }
 
     mMapLevel++;
-
   }
 
   GuardMap = &mGuardedMemoryMap;
   for (Level = GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel;
        Level < GUARDED_HEAP_MAP_TABLE_DEPTH;
-       ++Level) {
-
+       ++Level)
+  {
     if (*GuardMap == 0) {
       if (!AllocMapUnit) {
         GuardMap = NULL;
         break;
       }
 
-      Size = (mLevelMask[Level] + 1) * GUARDED_HEAP_MAP_ENTRY_BYTES;
+      Size   = (mLevelMask[Level] + 1) * GUARDED_HEAP_MAP_ENTRY_BYTES;
       Status = CoreInternalAllocatePages (
-                  AllocateAnyPages,
-                  EfiBootServicesData,
-                  EFI_SIZE_TO_PAGES (Size),
-                  &MapMemory,
-                  FALSE
-                  );
+                 AllocateAnyPages,
+                 EfiBootServicesData,
+                 EFI_SIZE_TO_PAGES (Size),
+                 &MapMemory,
+                 FALSE
+                 );
       ASSERT_EFI_ERROR (Status);
       ASSERT (MapMemory != 0);
 
@@ -286,10 +288,9 @@ FindGuardedMemoryMap (
       *GuardMap = MapMemory;
     }
 
-    Index     = (UINTN)RShiftU64 (Address, mLevelShift[Level]);
-    Index     &= mLevelMask[Level];
-    GuardMap  = (UINT64 *)(UINTN)((*GuardMap) + Index * sizeof (UINT64));
-
+    Index    = (UINTN)RShiftU64 (Address, mLevelShift[Level]);
+    Index   &= mLevelMask[Level];
+    GuardMap = (UINT64 *)(UINTN)((*GuardMap) + Index * sizeof (UINT64));
   }
 
   BitsToUnitEnd = GUARDED_HEAP_MAP_BITS - GUARDED_HEAP_MAP_BIT_INDEX (Address);
@@ -309,13 +310,13 @@ FindGuardedMemoryMap (
 VOID
 EFIAPI
 SetGuardedMemoryBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   NumberOfPages
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 NumberOfPages
   )
 {
-  UINT64            *BitMap;
-  UINTN             Bits;
-  UINTN             BitsToUnitEnd;
+  UINT64  *BitMap;
+  UINTN   Bits;
+  UINTN   BitsToUnitEnd;
 
   while (NumberOfPages > 0) {
     BitsToUnitEnd = FindGuardedMemoryMap (Address, TRUE, &BitMap);
@@ -325,7 +326,7 @@ SetGuardedMemoryBits (
       // Cross map unit
       Bits = BitsToUnitEnd;
     } else {
-      Bits  = NumberOfPages;
+      Bits = NumberOfPages;
     }
 
     SetBits (Address, Bits, BitMap);
@@ -346,13 +347,13 @@ SetGuardedMemoryBits (
 VOID
 EFIAPI
 ClearGuardedMemoryBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   NumberOfPages
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 NumberOfPages
   )
 {
-  UINT64            *BitMap;
-  UINTN             Bits;
-  UINTN             BitsToUnitEnd;
+  UINT64  *BitMap;
+  UINTN   Bits;
+  UINTN   BitsToUnitEnd;
 
   while (NumberOfPages > 0) {
     BitsToUnitEnd = FindGuardedMemoryMap (Address, TRUE, &BitMap);
@@ -362,7 +363,7 @@ ClearGuardedMemoryBits (
       // Cross map unit
       Bits = BitsToUnitEnd;
     } else {
-      Bits  = NumberOfPages;
+      Bits = NumberOfPages;
     }
 
     ClearBits (Address, Bits, BitMap);
@@ -382,15 +383,15 @@ ClearGuardedMemoryBits (
 **/
 UINT64
 GetGuardedMemoryBits (
-  IN EFI_PHYSICAL_ADDRESS    Address,
-  IN UINTN                   NumberOfPages
+  IN EFI_PHYSICAL_ADDRESS  Address,
+  IN UINTN                 NumberOfPages
   )
 {
-  UINT64            *BitMap;
-  UINTN             Bits;
-  UINT64            Result;
-  UINTN             Shift;
-  UINTN             BitsToUnitEnd;
+  UINT64  *BitMap;
+  UINTN   Bits;
+  UINT64  Result;
+  UINTN   Shift;
+  UINTN   BitsToUnitEnd;
 
   ASSERT (NumberOfPages <= GUARDED_HEAP_MAP_ENTRY_BITS);
 
@@ -401,9 +402,9 @@ GetGuardedMemoryBits (
 
     if (NumberOfPages > BitsToUnitEnd) {
       // Cross map unit
-      Bits  = BitsToUnitEnd;
+      Bits = BitsToUnitEnd;
     } else {
-      Bits  = NumberOfPages;
+      Bits = NumberOfPages;
     }
 
     if (BitMap != NULL) {
@@ -428,15 +429,18 @@ GetGuardedMemoryBits (
 UINTN
 EFIAPI
 GetGuardMapBit (
-  IN EFI_PHYSICAL_ADDRESS    Address
+  IN EFI_PHYSICAL_ADDRESS  Address
   )
 {
-  UINT64        *GuardMap;
+  UINT64  *GuardMap;
 
   FindGuardedMemoryMap (Address, FALSE, &GuardMap);
   if (GuardMap != NULL) {
-    if (RShiftU64 (*GuardMap,
-                   GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address)) & 1) {
+    if (RShiftU64 (
+          *GuardMap,
+          GUARDED_HEAP_MAP_ENTRY_BIT_INDEX (Address)
+          ) & 1)
+    {
       return 1;
     }
   }
@@ -444,7 +448,6 @@ GetGuardMapBit (
   return 0;
 }
 
-
 /**
   Check to see if the page at the given address is a Guard page or not.
 
@@ -456,10 +459,10 @@ GetGuardMapBit (
 BOOLEAN
 EFIAPI
 IsGuardPage (
-  IN EFI_PHYSICAL_ADDRESS    Address
+  IN EFI_PHYSICAL_ADDRESS  Address
   )
 {
-  UINT64        BitMap;
+  UINT64  BitMap;
 
   //
   // There must be at least one guarded page before and/or after given
@@ -470,7 +473,6 @@ IsGuardPage (
   return ((BitMap == BIT0) || (BitMap == BIT2) || (BitMap == (BIT2 | BIT0)));
 }
 
-
 /**
   Check to see if the page at the given address is guarded or not.
 
@@ -482,7 +484,7 @@ IsGuardPage (
 BOOLEAN
 EFIAPI
 IsMemoryGuarded (
-  IN EFI_PHYSICAL_ADDRESS    Address
+  IN EFI_PHYSICAL_ADDRESS  Address
   )
 {
   return (GetGuardMapBit (Address) == 1);
@@ -500,10 +502,10 @@ IsMemoryGuarded (
 VOID
 EFIAPI
 SetGuardPage (
-  IN  EFI_PHYSICAL_ADDRESS      BaseAddress
+  IN  EFI_PHYSICAL_ADDRESS  BaseAddress
   )
 {
-  EFI_STATUS      Status;
+  EFI_STATUS  Status;
 
   if (gCpu == NULL) {
     return;
@@ -535,11 +537,11 @@ SetGuardPage (
 VOID
 EFIAPI
 UnsetGuardPage (
-  IN  EFI_PHYSICAL_ADDRESS      BaseAddress
+  IN  EFI_PHYSICAL_ADDRESS  BaseAddress
   )
 {
-  UINT64          Attributes;
-  EFI_STATUS      Status;
+  UINT64      Attributes;
+  EFI_STATUS  Status;
 
   if (gCpu == NULL) {
     return;
@@ -583,13 +585,13 @@ UnsetGuardPage (
 **/
 BOOLEAN
 IsMemoryTypeToGuard (
-  IN EFI_MEMORY_TYPE        MemoryType,
-  IN EFI_ALLOCATE_TYPE      AllocateType,
-  IN UINT8                  PageOrPool
+  IN EFI_MEMORY_TYPE    MemoryType,
+  IN EFI_ALLOCATE_TYPE  AllocateType,
+  IN UINT8              PageOrPool
   )
 {
-  UINT64 TestBit;
-  UINT64 ConfigBit;
+  UINT64  TestBit;
+  UINT64  ConfigBit;
 
   if (AllocateType == AllocateAddress) {
     return FALSE;
@@ -609,7 +611,7 @@ IsMemoryTypeToGuard (
 
   if ((UINT32)MemoryType >= MEMORY_TYPE_OS_RESERVED_MIN) {
     TestBit = BIT63;
-  } else if ((UINT32) MemoryType >= MEMORY_TYPE_OEM_RESERVED_MIN) {
+  } else if ((UINT32)MemoryType >= MEMORY_TYPE_OEM_RESERVED_MIN) {
     TestBit = BIT62;
   } else if (MemoryType < EfiMaxMemoryType) {
     TestBit = LShiftU64 (1, MemoryType);
@@ -633,11 +635,14 @@ IsMemoryTypeToGuard (
 **/
 BOOLEAN
 IsPoolTypeToGuard (
-  IN EFI_MEMORY_TYPE        MemoryType
+  IN EFI_MEMORY_TYPE  MemoryType
   )
 {
-  return IsMemoryTypeToGuard (MemoryType, AllocateAnyPages,
-                              GUARD_HEAP_TYPE_POOL);
+  return IsMemoryTypeToGuard (
+           MemoryType,
+           AllocateAnyPages,
+           GUARD_HEAP_TYPE_POOL
+           );
 }
 
 /**
@@ -651,8 +656,8 @@ IsPoolTypeToGuard (
 **/
 BOOLEAN
 IsPageTypeToGuard (
-  IN EFI_MEMORY_TYPE        MemoryType,
-  IN EFI_ALLOCATE_TYPE      AllocateType
+  IN EFI_MEMORY_TYPE    MemoryType,
+  IN EFI_ALLOCATE_TYPE  AllocateType
   )
 {
   return IsMemoryTypeToGuard (MemoryType, AllocateType, GUARD_HEAP_TYPE_PAGE);
@@ -667,7 +672,7 @@ IsPageTypeToGuard (
 **/
 BOOLEAN
 IsHeapGuardEnabled (
-  UINT8           GuardType
+  UINT8  GuardType
   )
 {
   return IsMemoryTypeToGuard (EfiMaxMemoryType, AllocateAnyPages, GuardType);
@@ -683,11 +688,11 @@ IsHeapGuardEnabled (
 **/
 VOID
 SetGuardForMemory (
-  IN EFI_PHYSICAL_ADDRESS   Memory,
-  IN UINTN                  NumberOfPages
+  IN EFI_PHYSICAL_ADDRESS  Memory,
+  IN UINTN                 NumberOfPages
   )
 {
-  EFI_PHYSICAL_ADDRESS    GuardPage;
+  EFI_PHYSICAL_ADDRESS  GuardPage;
 
   //
   // Set tail Guard
@@ -719,8 +724,8 @@ SetGuardForMemory (
 **/
 VOID
 UnsetGuardForMemory (
-  IN EFI_PHYSICAL_ADDRESS   Memory,
-  IN UINTN                  NumberOfPages
+  IN EFI_PHYSICAL_ADDRESS  Memory,
+  IN UINTN                 NumberOfPages
   )
 {
   EFI_PHYSICAL_ADDRESS  GuardPage;
@@ -742,7 +747,7 @@ UnsetGuardForMemory (
   //          -------------------
   //      Start -> -1    -2
   //
-  GuardPage = Memory - EFI_PAGES_TO_SIZE (1);
+  GuardPage   = Memory - EFI_PAGES_TO_SIZE (1);
   GuardBitmap = GetGuardedMemoryBits (Memory - EFI_PAGES_TO_SIZE (2), 2);
   if ((GuardBitmap & BIT1) == 0) {
     //
@@ -775,7 +780,7 @@ UnsetGuardForMemory (
   //  --------------------
   //        +1    +0 <- End
   //
-  GuardPage = Memory + EFI_PAGES_TO_SIZE (NumberOfPages);
+  GuardPage   = Memory + EFI_PAGES_TO_SIZE (NumberOfPages);
   GuardBitmap = GetGuardedMemoryBits (GuardPage, 2);
   if ((GuardBitmap & BIT0) == 0) {
     //
@@ -799,7 +804,7 @@ UnsetGuardForMemory (
   //
   // No matter what, we just clear the mark of the Guarded memory.
   //
-  ClearGuardedMemoryBits(Memory, NumberOfPages);
+  ClearGuardedMemoryBits (Memory, NumberOfPages);
 }
 
 /**
@@ -818,9 +823,9 @@ UnsetGuardForMemory (
 **/
 UINT64
 AdjustMemoryS (
-  IN UINT64                  Start,
-  IN UINT64                  Size,
-  IN UINT64                  SizeRequested
+  IN UINT64  Start,
+  IN UINT64  Size,
+  IN UINT64  SizeRequested
   )
 {
   UINT64  Target;
@@ -831,7 +836,7 @@ AdjustMemoryS (
   // make sure alignment of the returned pool address.
   //
   if ((PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) == 0) {
-    SizeRequested = ALIGN_VALUE(SizeRequested, 8);
+    SizeRequested = ALIGN_VALUE (SizeRequested, 8);
   }
 
   Target = Start + Size - SizeRequested;
@@ -877,8 +882,8 @@ AdjustMemoryS (
 **/
 VOID
 AdjustMemoryF (
-  IN OUT EFI_PHYSICAL_ADDRESS    *Memory,
-  IN OUT UINTN                   *NumberOfPages
+  IN OUT EFI_PHYSICAL_ADDRESS  *Memory,
+  IN OUT UINTN                 *NumberOfPages
   )
 {
   EFI_PHYSICAL_ADDRESS  Start;
@@ -886,11 +891,11 @@ AdjustMemoryF (
   UINTN                 PagesToFree;
   UINT64                GuardBitmap;
 
-  if (Memory == NULL || NumberOfPages == NULL || *NumberOfPages == 0) {
+  if ((Memory == NULL) || (NumberOfPages == NULL) || (*NumberOfPages == 0)) {
     return;
   }
 
-  Start = *Memory;
+  Start       = *Memory;
   PagesToFree = *NumberOfPages;
 
   //
@@ -906,7 +911,7 @@ AdjustMemoryF (
   //      Start -> -1    -2
   //
   MemoryToTest = Start - EFI_PAGES_TO_SIZE (2);
-  GuardBitmap = GetGuardedMemoryBits (MemoryToTest, 2);
+  GuardBitmap  = GetGuardedMemoryBits (MemoryToTest, 2);
   if ((GuardBitmap & BIT1) == 0) {
     //
     // Head Guard exists.
@@ -941,7 +946,7 @@ AdjustMemoryF (
   //        +1    +0 <- End
   //
   MemoryToTest = Start + EFI_PAGES_TO_SIZE (PagesToFree);
-  GuardBitmap = GetGuardedMemoryBits (MemoryToTest, 2);
+  GuardBitmap  = GetGuardedMemoryBits (MemoryToTest, 2);
   if ((GuardBitmap & BIT0) == 0) {
     //
     // Tail Guard exists.
@@ -961,8 +966,8 @@ AdjustMemoryF (
     PagesToFree -= 1;
   }
 
-  *Memory         = Start;
-  *NumberOfPages  = PagesToFree;
+  *Memory        = Start;
+  *NumberOfPages = PagesToFree;
 }
 
 /**
@@ -975,8 +980,8 @@ AdjustMemoryF (
 **/
 VOID
 AdjustMemoryA (
-  IN OUT EFI_PHYSICAL_ADDRESS    *Memory,
-  IN OUT UINTN                   *NumberOfPages
+  IN OUT EFI_PHYSICAL_ADDRESS  *Memory,
+  IN OUT UINTN                 *NumberOfPages
   )
 {
   //
@@ -1009,12 +1014,12 @@ AdjustMemoryA (
 **/
 VOID *
 AdjustPoolHeadA (
-  IN EFI_PHYSICAL_ADDRESS    Memory,
-  IN UINTN                   NoPages,
-  IN UINTN                   Size
+  IN EFI_PHYSICAL_ADDRESS  Memory,
+  IN UINTN                 NoPages,
+  IN UINTN                 Size
   )
 {
-  if (Memory == 0 || (PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) != 0) {
+  if ((Memory == 0) || ((PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) != 0)) {
     //
     // Pool head is put near the head Guard
     //
@@ -1037,10 +1042,10 @@ AdjustPoolHeadA (
 **/
 VOID *
 AdjustPoolHeadF (
-  IN EFI_PHYSICAL_ADDRESS    Memory
+  IN EFI_PHYSICAL_ADDRESS  Memory
   )
 {
-  if (Memory == 0 || (PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) != 0) {
+  if ((Memory == 0) || ((PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) != 0)) {
     //
     // Pool head is put near the head Guard
     //
@@ -1103,30 +1108,31 @@ SetAllGuardPages (
   VOID
   )
 {
-  UINTN     Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    TableEntry;
-  UINT64    Address;
-  UINT64    GuardPage;
-  INTN      Level;
-  UINTN     Index;
-  BOOLEAN   OnGuarding;
+  UINTN    Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN    Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN    Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64   Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64   Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64   TableEntry;
+  UINT64   Address;
+  UINT64   GuardPage;
+  INTN     Level;
+  UINTN    Index;
+  BOOLEAN  OnGuarding;
 
-  if (mGuardedMemoryMap == 0 ||
-      mMapLevel == 0 ||
-      mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH) {
+  if ((mGuardedMemoryMap == 0) ||
+      (mMapLevel == 0) ||
+      (mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH))
+  {
     return;
   }
 
   CopyMem (Entries, mLevelMask, sizeof (Entries));
   CopyMem (Shifts, mLevelShift, sizeof (Shifts));
 
-  SetMem (Tables, sizeof(Tables), 0);
-  SetMem (Addresses, sizeof(Addresses), 0);
-  SetMem (Indices, sizeof(Indices), 0);
+  SetMem (Tables, sizeof (Tables), 0);
+  SetMem (Addresses, sizeof (Addresses), 0);
+  SetMem (Indices, sizeof (Indices), 0);
 
   Level         = GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel;
   Tables[Level] = mGuardedMemoryMap;
@@ -1135,32 +1141,26 @@ SetAllGuardPages (
 
   DEBUG_CODE (
     DumpGuardedMemoryBitmap ();
-  );
+    );
 
   while (TRUE) {
     if (Indices[Level] > Entries[Level]) {
       Tables[Level] = 0;
       Level        -= 1;
     } else {
-
-      TableEntry  = ((UINT64 *)(UINTN)(Tables[Level]))[Indices[Level]];
-      Address     = Addresses[Level];
+      TableEntry = ((UINT64 *)(UINTN)(Tables[Level]))[Indices[Level]];
+      Address    = Addresses[Level];
 
       if (TableEntry == 0) {
-
         OnGuarding = FALSE;
-
       } else if (Level < GUARDED_HEAP_MAP_TABLE_DEPTH - 1) {
-
-        Level            += 1;
-        Tables[Level]     = TableEntry;
-        Addresses[Level]  = Address;
-        Indices[Level]    = 0;
+        Level           += 1;
+        Tables[Level]    = TableEntry;
+        Addresses[Level] = Address;
+        Indices[Level]   = 0;
 
         continue;
-
       } else {
-
         Index = 0;
         while (Index < GUARDED_HEAP_MAP_ENTRY_BITS) {
           if ((TableEntry & 1) == 1) {
@@ -1169,6 +1169,7 @@ SetAllGuardPages (
             } else {
               GuardPage = Address - EFI_PAGE_SIZE;
             }
+
             OnGuarding = TRUE;
           } else {
             if (OnGuarding) {
@@ -1176,6 +1177,7 @@ SetAllGuardPages (
             } else {
               GuardPage = 0;
             }
+
             OnGuarding = FALSE;
           }
 
@@ -1198,10 +1200,9 @@ SetAllGuardPages (
       break;
     }
 
-    Indices[Level] += 1;
-    Address = (Level == 0) ? 0 : Addresses[Level - 1];
-    Addresses[Level] = Address | LShiftU64(Indices[Level], Shifts[Level]);
-
+    Indices[Level]  += 1;
+    Address          = (Level == 0) ? 0 : Addresses[Level - 1];
+    Addresses[Level] = Address | LShiftU64 (Indices[Level], Shifts[Level]);
   }
 }
 
@@ -1214,31 +1215,32 @@ SetAllGuardPages (
 **/
 VOID
 GetLastGuardedFreePageAddress (
-  OUT EFI_PHYSICAL_ADDRESS      *Address
+  OUT EFI_PHYSICAL_ADDRESS  *Address
   )
 {
-  EFI_PHYSICAL_ADDRESS    AddressGranularity;
-  EFI_PHYSICAL_ADDRESS    BaseAddress;
-  UINTN                   Level;
-  UINT64                  Map;
-  INTN                    Index;
+  EFI_PHYSICAL_ADDRESS  AddressGranularity;
+  EFI_PHYSICAL_ADDRESS  BaseAddress;
+  UINTN                 Level;
+  UINT64                Map;
+  INTN                  Index;
 
   ASSERT (mMapLevel >= 1);
 
   BaseAddress = 0;
-  Map = mGuardedMemoryMap;
+  Map         = mGuardedMemoryMap;
   for (Level = GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel;
        Level < GUARDED_HEAP_MAP_TABLE_DEPTH;
-       ++Level) {
+       ++Level)
+  {
     AddressGranularity = LShiftU64 (1, mLevelShift[Level]);
 
     //
     // Find the non-NULL entry at largest index.
     //
-    for (Index = (INTN)mLevelMask[Level]; Index >= 0 ; --Index) {
+    for (Index = (INTN)mLevelMask[Level]; Index >= 0; --Index) {
       if (((UINT64 *)(UINTN)Map)[Index] != 0) {
         BaseAddress += MultU64x32 (AddressGranularity, (UINT32)Index);
-        Map = ((UINT64 *)(UINTN)Map)[Index];
+        Map          = ((UINT64 *)(UINTN)Map)[Index];
         break;
       }
     }
@@ -1248,7 +1250,7 @@ GetLastGuardedFreePageAddress (
   // Find the non-zero MSB then get the page address.
   //
   while (Map != 0) {
-    Map = RShiftU64 (Map, 1);
+    Map          = RShiftU64 (Map, 1);
     BaseAddress += EFI_PAGES_TO_SIZE (1);
   }
 
@@ -1265,8 +1267,8 @@ GetLastGuardedFreePageAddress (
 **/
 VOID
 MarkFreedPages (
-  IN EFI_PHYSICAL_ADDRESS     BaseAddress,
-  IN UINTN                    Pages
+  IN EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN UINTN                 Pages
   )
 {
   SetGuardedMemoryBits (BaseAddress, Pages);
@@ -1283,11 +1285,11 @@ MarkFreedPages (
 VOID
 EFIAPI
 GuardFreedPages (
-  IN  EFI_PHYSICAL_ADDRESS    BaseAddress,
-  IN  UINTN                   Pages
+  IN  EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN  UINTN                 Pages
   )
 {
-  EFI_STATUS      Status;
+  EFI_STATUS  Status;
 
   //
   // Legacy memory lower than 1MB might be accessed with no allocation. Leave
@@ -1322,6 +1324,7 @@ GuardFreedPages (
     if (EFI_ERROR (Status)) {
       DEBUG ((DEBUG_WARN, "Failed to guard freed pages: %p (%lu)\n", BaseAddress, (UINT64)Pages));
     }
+
     mOnGuarding = FALSE;
   }
 }
@@ -1337,8 +1340,8 @@ GuardFreedPages (
 VOID
 EFIAPI
 GuardFreedPagesChecked (
-  IN  EFI_PHYSICAL_ADDRESS    BaseAddress,
-  IN  UINTN                   Pages
+  IN  EFI_PHYSICAL_ADDRESS  BaseAddress,
+  IN  UINTN                 Pages
   )
 {
   if (IsHeapGuardEnabled (GUARD_HEAP_TYPE_FREED)) {
@@ -1355,30 +1358,31 @@ GuardAllFreedPages (
   VOID
   )
 {
-  UINTN     Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    TableEntry;
-  UINT64    Address;
-  UINT64    GuardPage;
-  INTN      Level;
-  UINT64    BitIndex;
-  UINTN     GuardPageNumber;
+  UINTN   Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN   Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN   Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  TableEntry;
+  UINT64  Address;
+  UINT64  GuardPage;
+  INTN    Level;
+  UINT64  BitIndex;
+  UINTN   GuardPageNumber;
 
-  if (mGuardedMemoryMap == 0 ||
-      mMapLevel == 0 ||
-      mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH) {
+  if ((mGuardedMemoryMap == 0) ||
+      (mMapLevel == 0) ||
+      (mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH))
+  {
     return;
   }
 
   CopyMem (Entries, mLevelMask, sizeof (Entries));
   CopyMem (Shifts, mLevelShift, sizeof (Shifts));
 
-  SetMem (Tables, sizeof(Tables), 0);
-  SetMem (Addresses, sizeof(Addresses), 0);
-  SetMem (Indices, sizeof(Indices), 0);
+  SetMem (Tables, sizeof (Tables), 0);
+  SetMem (Addresses, sizeof (Addresses), 0);
+  SetMem (Indices, sizeof (Indices), 0);
 
   Level           = GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel;
   Tables[Level]   = mGuardedMemoryMap;
@@ -1391,14 +1395,14 @@ GuardAllFreedPages (
       Tables[Level] = 0;
       Level        -= 1;
     } else {
-      TableEntry  = ((UINT64 *)(UINTN)(Tables[Level]))[Indices[Level]];
-      Address     = Addresses[Level];
+      TableEntry = ((UINT64 *)(UINTN)(Tables[Level]))[Indices[Level]];
+      Address    = Addresses[Level];
 
       if (Level < GUARDED_HEAP_MAP_TABLE_DEPTH - 1) {
-        Level            += 1;
-        Tables[Level]     = TableEntry;
-        Addresses[Level]  = Address;
-        Indices[Level]    = 0;
+        Level           += 1;
+        Tables[Level]    = TableEntry;
+        Addresses[Level] = Address;
+        Indices[Level]   = 0;
 
         continue;
       } else {
@@ -1408,6 +1412,7 @@ GuardAllFreedPages (
             if (GuardPage == (UINT64)-1) {
               GuardPage = Address;
             }
+
             ++GuardPageNumber;
           } else if (GuardPageNumber > 0) {
             GuardFreedPages (GuardPage, GuardPageNumber);
@@ -1429,10 +1434,9 @@ GuardAllFreedPages (
       break;
     }
 
-    Indices[Level] += 1;
-    Address = (Level == 0) ? 0 : Addresses[Level - 1];
+    Indices[Level]  += 1;
+    Address          = (Level == 0) ? 0 : Addresses[Level - 1];
     Addresses[Level] = Address | LShiftU64 (Indices[Level], Shifts[Level]);
-
   }
 
   //
@@ -1457,16 +1461,17 @@ GuardAllFreedPages (
 **/
 VOID
 MergeGuardPages (
-  IN EFI_MEMORY_DESCRIPTOR      *MemoryMapEntry,
-  IN EFI_PHYSICAL_ADDRESS       MaxAddress
+  IN EFI_MEMORY_DESCRIPTOR  *MemoryMapEntry,
+  IN EFI_PHYSICAL_ADDRESS   MaxAddress
   )
 {
-  EFI_PHYSICAL_ADDRESS        EndAddress;
-  UINT64                      Bitmap;
-  INTN                        Pages;
+  EFI_PHYSICAL_ADDRESS  EndAddress;
+  UINT64                Bitmap;
+  INTN                  Pages;
 
   if (!IsHeapGuardEnabled (GUARD_HEAP_TYPE_FREED) ||
-      MemoryMapEntry->Type >= EfiMemoryMappedIO) {
+      (MemoryMapEntry->Type >= EfiMemoryMappedIO))
+  {
     return;
   }
 
@@ -1511,14 +1516,14 @@ MergeGuardPages (
 **/
 BOOLEAN
 PromoteGuardedFreePages (
-  OUT EFI_PHYSICAL_ADDRESS      *StartAddress,
-  OUT EFI_PHYSICAL_ADDRESS      *EndAddress
+  OUT EFI_PHYSICAL_ADDRESS  *StartAddress,
+  OUT EFI_PHYSICAL_ADDRESS  *EndAddress
   )
 {
-  EFI_STATUS              Status;
-  UINTN                   AvailablePages;
-  UINT64                  Bitmap;
-  EFI_PHYSICAL_ADDRESS    Start;
+  EFI_STATUS            Status;
+  UINTN                 AvailablePages;
+  UINT64                Bitmap;
+  EFI_PHYSICAL_ADDRESS  Start;
 
   if (!IsHeapGuardEnabled (GUARD_HEAP_TYPE_FREED)) {
     return FALSE;
@@ -1528,8 +1533,8 @@ PromoteGuardedFreePages (
   // Similar to memory allocation service, always search the freed pages in
   // descending direction.
   //
-  Start           = mLastPromotedPage;
-  AvailablePages  = 0;
+  Start          = mLastPromotedPage;
+  AvailablePages = 0;
   while (AvailablePages == 0) {
     Start -= EFI_PAGES_TO_SIZE (GUARDED_HEAP_MAP_ENTRY_BITS);
     //
@@ -1565,7 +1570,7 @@ PromoteGuardedFreePages (
       // operation; otherwise infinite loops could be caused.
       //
       mOnGuarding = TRUE;
-      Status = gCpu->SetMemoryAttributes (gCpu, Start, EFI_PAGES_TO_SIZE(AvailablePages), 0);
+      Status      = gCpu->SetMemoryAttributes (gCpu, Start, EFI_PAGES_TO_SIZE (AvailablePages), 0);
       ASSERT_EFI_ERROR (Status);
       mOnGuarding = FALSE;
     }
@@ -1590,7 +1595,8 @@ HeapGuardCpuArchProtocolNotify (
   ASSERT (gCpu != NULL);
 
   if (IsHeapGuardEnabled (GUARD_HEAP_TYPE_PAGE|GUARD_HEAP_TYPE_POOL) &&
-      IsHeapGuardEnabled (GUARD_HEAP_TYPE_FREED)) {
+      IsHeapGuardEnabled (GUARD_HEAP_TYPE_FREED))
+  {
     DEBUG ((DEBUG_ERROR, "Heap guard and freed memory guard cannot be enabled at the same time.\n"));
     CpuDeadLoop ();
   }
@@ -1614,11 +1620,11 @@ HeapGuardCpuArchProtocolNotify (
 **/
 VOID
 Uint64ToBinString (
-  IN  UINT64      Value,
-  OUT CHAR8       *BinString
+  IN  UINT64  Value,
+  OUT CHAR8   *BinString
   )
 {
-  UINTN Index;
+  UINTN  Index;
 
   if (BinString == NULL) {
     return;
@@ -1626,8 +1632,9 @@ Uint64ToBinString (
 
   for (Index = 64; Index > 0; --Index) {
     BinString[Index - 1] = '0' + (Value & 1);
-    Value = RShiftU64 (Value, 1);
+    Value                = RShiftU64 (Value, 1);
   }
+
   BinString[64] = '\0';
 }
 
@@ -1640,44 +1647,48 @@ DumpGuardedMemoryBitmap (
   VOID
   )
 {
-  UINTN     Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINTN     Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
-  UINT64    TableEntry;
-  UINT64    Address;
-  INTN      Level;
-  UINTN     RepeatZero;
-  CHAR8     String[GUARDED_HEAP_MAP_ENTRY_BITS + 1];
-  CHAR8     *Ruler1;
-  CHAR8     *Ruler2;
+  UINTN   Entries[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN   Shifts[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINTN   Indices[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  Tables[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  Addresses[GUARDED_HEAP_MAP_TABLE_DEPTH];
+  UINT64  TableEntry;
+  UINT64  Address;
+  INTN    Level;
+  UINTN   RepeatZero;
+  CHAR8   String[GUARDED_HEAP_MAP_ENTRY_BITS + 1];
+  CHAR8   *Ruler1;
+  CHAR8   *Ruler2;
 
   if (!IsHeapGuardEnabled (GUARD_HEAP_TYPE_ALL)) {
     return;
   }
 
-  if (mGuardedMemoryMap == 0 ||
-      mMapLevel == 0 ||
-      mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH) {
+  if ((mGuardedMemoryMap == 0) ||
+      (mMapLevel == 0) ||
+      (mMapLevel > GUARDED_HEAP_MAP_TABLE_DEPTH))
+  {
     return;
   }
 
   Ruler1 = "               3               2               1               0";
   Ruler2 = "FEDCBA9876543210FEDCBA9876543210FEDCBA9876543210FEDCBA9876543210";
 
-  DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "============================="
-                                  " Guarded Memory Bitmap "
-                                  "==============================\r\n"));
+  DEBUG ((
+    HEAP_GUARD_DEBUG_LEVEL,
+    "============================="
+    " Guarded Memory Bitmap "
+    "==============================\r\n"
+    ));
   DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "                  %a\r\n", Ruler1));
   DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "                  %a\r\n", Ruler2));
 
   CopyMem (Entries, mLevelMask, sizeof (Entries));
   CopyMem (Shifts, mLevelShift, sizeof (Shifts));
 
-  SetMem (Indices, sizeof(Indices), 0);
-  SetMem (Tables, sizeof(Tables), 0);
-  SetMem (Addresses, sizeof(Addresses), 0);
+  SetMem (Indices, sizeof (Indices), 0);
+  SetMem (Tables, sizeof (Tables), 0);
+  SetMem (Addresses, sizeof (Addresses), 0);
 
   Level         = GUARDED_HEAP_MAP_TABLE_DEPTH - mMapLevel;
   Tables[Level] = mGuardedMemoryMap;
@@ -1686,7 +1697,6 @@ DumpGuardedMemoryBitmap (
 
   while (TRUE) {
     if (Indices[Level] > Entries[Level]) {
-
       Tables[Level] = 0;
       Level        -= 1;
       RepeatZero    = 0;
@@ -1696,40 +1706,33 @@ DumpGuardedMemoryBitmap (
         "========================================="
         "=========================================\r\n"
         ));
-
     } else {
-
-      TableEntry  = ((UINT64 *)(UINTN)Tables[Level])[Indices[Level]];
-      Address     = Addresses[Level];
+      TableEntry = ((UINT64 *)(UINTN)Tables[Level])[Indices[Level]];
+      Address    = Addresses[Level];
 
       if (TableEntry == 0) {
-
         if (Level == GUARDED_HEAP_MAP_TABLE_DEPTH - 1) {
           if (RepeatZero == 0) {
-            Uint64ToBinString(TableEntry, String);
+            Uint64ToBinString (TableEntry, String);
             DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "%016lx: %a\r\n", Address, String));
           } else if (RepeatZero == 1) {
             DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "...             : ...\r\n"));
           }
+
           RepeatZero += 1;
         }
-
       } else if (Level < GUARDED_HEAP_MAP_TABLE_DEPTH - 1) {
-
-        Level            += 1;
-        Tables[Level]     = TableEntry;
-        Addresses[Level]  = Address;
-        Indices[Level]    = 0;
-        RepeatZero        = 0;
+        Level           += 1;
+        Tables[Level]    = TableEntry;
+        Addresses[Level] = Address;
+        Indices[Level]   = 0;
+        RepeatZero       = 0;
 
         continue;
-
       } else {
-
         RepeatZero = 0;
-        Uint64ToBinString(TableEntry, String);
+        Uint64ToBinString (TableEntry, String);
         DEBUG ((HEAP_GUARD_DEBUG_LEVEL, "%016lx: %a\r\n", Address, String));
-
       }
     }
 
@@ -1737,10 +1740,8 @@ DumpGuardedMemoryBitmap (
       break;
     }
 
-    Indices[Level] += 1;
-    Address = (Level == 0) ? 0 : Addresses[Level - 1];
-    Addresses[Level] = Address | LShiftU64(Indices[Level], Shifts[Level]);
-
+    Indices[Level]  += 1;
+    Address          = (Level == 0) ? 0 : Addresses[Level - 1];
+    Addresses[Level] = Address | LShiftU64 (Indices[Level], Shifts[Level]);
   }
 }
-
