@@ -13,7 +13,7 @@ LIST_ENTRY  mSmmPoolLists[SmmPoolTypeMax][MAX_POOL_INDEX];
 // To cache the SMRAM base since when Loading modules At fixed address feature is enabled,
 // all module is assigned an offset relative the SMRAM base in build time.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED  EFI_PHYSICAL_ADDRESS       gLoadModuleAtFixAddressSmramBase = 0;
+GLOBAL_REMOVE_IF_UNREFERENCED  EFI_PHYSICAL_ADDRESS  gLoadModuleAtFixAddressSmramBase = 0;
 
 /**
   Convert a UEFI memory type to SMM pool type.
@@ -24,21 +24,20 @@ GLOBAL_REMOVE_IF_UNREFERENCED  EFI_PHYSICAL_ADDRESS       gLoadModuleAtFixAddres
 **/
 SMM_POOL_TYPE
 UefiMemoryTypeToSmmPoolType (
-  IN  EFI_MEMORY_TYPE   MemoryType
+  IN  EFI_MEMORY_TYPE  MemoryType
   )
 {
   ASSERT ((MemoryType == EfiRuntimeServicesCode) || (MemoryType == EfiRuntimeServicesData));
   switch (MemoryType) {
-  case EfiRuntimeServicesCode:
-    return SmmPoolTypeCode;
-  case EfiRuntimeServicesData:
-    return SmmPoolTypeData;
-  default:
-    return SmmPoolTypeMax;
+    case EfiRuntimeServicesCode:
+      return SmmPoolTypeCode;
+    case EfiRuntimeServicesData:
+      return SmmPoolTypeData;
+    default:
+      return SmmPoolTypeMax;
   }
 }
 
-
 /**
   Called to initialize the memory service.
 
@@ -52,10 +51,10 @@ SmmInitializeMemoryServices (
   IN EFI_SMRAM_DESCRIPTOR  *SmramRanges
   )
 {
-  UINTN                  Index;
-  EFI_STATUS             Status;
-  UINTN                  SmmPoolTypeIndex;
-  EFI_LOAD_FIXED_ADDRESS_CONFIGURATION_TABLE *LMFAConfigurationTable;
+  UINTN                                       Index;
+  EFI_STATUS                                  Status;
+  UINTN                                       SmmPoolTypeIndex;
+  EFI_LOAD_FIXED_ADDRESS_CONFIGURATION_TABLE  *LMFAConfigurationTable;
 
   //
   // Initialize Pool list
@@ -67,10 +66,10 @@ SmmInitializeMemoryServices (
   }
 
   Status = EfiGetSystemConfigurationTable (
-            &gLoadFixedAddressConfigurationTableGuid,
-           (VOID **) &LMFAConfigurationTable
-           );
-  if (!EFI_ERROR (Status) && LMFAConfigurationTable != NULL) {
+             &gLoadFixedAddressConfigurationTableGuid,
+             (VOID **)&LMFAConfigurationTable
+             );
+  if (!EFI_ERROR (Status) && (LMFAConfigurationTable != NULL)) {
     gLoadModuleAtFixAddressSmramBase = LMFAConfigurationTable->SmramBase;
   }
 
@@ -82,6 +81,7 @@ SmmInitializeMemoryServices (
     if ((SmramRanges[Index].RegionState & (EFI_ALLOCATED | EFI_NEEDS_TESTING | EFI_NEEDS_ECC_INITIALIZATION)) != 0) {
       continue;
     }
+
     SmmAddMemoryRegion (
       SmramRanges[Index].CpuStart,
       SmramRanges[Index].PhysicalSize,
@@ -97,6 +97,7 @@ SmmInitializeMemoryServices (
     if ((SmramRanges[Index].RegionState & (EFI_ALLOCATED | EFI_NEEDS_TESTING | EFI_NEEDS_ECC_INITIALIZATION)) == 0) {
       continue;
     }
+
     SmmAddMemoryRegion (
       SmramRanges[Index].CpuStart,
       SmramRanges[Index].PhysicalSize,
@@ -104,7 +105,6 @@ SmmInitializeMemoryServices (
       SmramRanges[Index].RegionState
       );
   }
-
 }
 
 /**
@@ -132,19 +132,24 @@ InternalAllocPoolByIndex (
   SMM_POOL_TYPE         SmmPoolType;
 
   Address     = 0;
-  SmmPoolType = UefiMemoryTypeToSmmPoolType(PoolType);
+  SmmPoolType = UefiMemoryTypeToSmmPoolType (PoolType);
 
   ASSERT (PoolIndex <= MAX_POOL_INDEX);
   Status = EFI_SUCCESS;
-  Hdr = NULL;
+  Hdr    = NULL;
   if (PoolIndex == MAX_POOL_INDEX) {
-    Status = SmmInternalAllocatePages (AllocateAnyPages, PoolType,
-                                       EFI_SIZE_TO_PAGES (MAX_POOL_SIZE << 1),
-                                       &Address, FALSE);
+    Status = SmmInternalAllocatePages (
+               AllocateAnyPages,
+               PoolType,
+               EFI_SIZE_TO_PAGES (MAX_POOL_SIZE << 1),
+               &Address,
+               FALSE
+               );
     if (EFI_ERROR (Status)) {
       return EFI_OUT_OF_RESOURCES;
     }
-    Hdr = (FREE_POOL_HEADER *) (UINTN) Address;
+
+    Hdr = (FREE_POOL_HEADER *)(UINTN)Address;
   } else if (!IsListEmpty (&mSmmPoolLists[SmmPoolType][PoolIndex])) {
     Hdr = BASE_CR (GetFirstNode (&mSmmPoolLists[SmmPoolType][PoolIndex]), FREE_POOL_HEADER, Link);
     RemoveEntryList (&Hdr->Link);
@@ -152,25 +157,25 @@ InternalAllocPoolByIndex (
     Status = InternalAllocPoolByIndex (PoolType, PoolIndex + 1, &Hdr);
     if (!EFI_ERROR (Status)) {
       Hdr->Header.Signature = 0;
-      Hdr->Header.Size >>= 1;
+      Hdr->Header.Size    >>= 1;
       Hdr->Header.Available = TRUE;
-      Hdr->Header.Type = 0;
-      Tail = HEAD_TO_TAIL(&Hdr->Header);
-      Tail->Signature = 0;
-      Tail->Size = 0;
+      Hdr->Header.Type      = 0;
+      Tail                  = HEAD_TO_TAIL (&Hdr->Header);
+      Tail->Signature       = 0;
+      Tail->Size            = 0;
       InsertHeadList (&mSmmPoolLists[SmmPoolType][PoolIndex], &Hdr->Link);
-      Hdr = (FREE_POOL_HEADER*)((UINT8*)Hdr + Hdr->Header.Size);
+      Hdr = (FREE_POOL_HEADER *)((UINT8 *)Hdr + Hdr->Header.Size);
     }
   }
 
   if (!EFI_ERROR (Status)) {
     Hdr->Header.Signature = POOL_HEAD_SIGNATURE;
-    Hdr->Header.Size = MIN_POOL_SIZE << PoolIndex;
+    Hdr->Header.Size      = MIN_POOL_SIZE << PoolIndex;
     Hdr->Header.Available = FALSE;
-    Hdr->Header.Type = PoolType;
-    Tail = HEAD_TO_TAIL(&Hdr->Header);
-    Tail->Signature = POOL_TAIL_SIGNATURE;
-    Tail->Size = Hdr->Header.Size;
+    Hdr->Header.Type      = PoolType;
+    Tail                  = HEAD_TO_TAIL (&Hdr->Header);
+    Tail->Signature       = POOL_TAIL_SIGNATURE;
+    Tail->Size            = Hdr->Header.Size;
   }
 
   *FreePoolHdr = Hdr;
@@ -192,21 +197,21 @@ InternalFreePoolByIndex (
   IN POOL_TAIL         *PoolTail
   )
 {
-  UINTN                 PoolIndex;
-  SMM_POOL_TYPE         SmmPoolType;
+  UINTN          PoolIndex;
+  SMM_POOL_TYPE  SmmPoolType;
 
   ASSERT ((FreePoolHdr->Header.Size & (FreePoolHdr->Header.Size - 1)) == 0);
   ASSERT (((UINTN)FreePoolHdr & (FreePoolHdr->Header.Size - 1)) == 0);
   ASSERT (FreePoolHdr->Header.Size >= MIN_POOL_SIZE);
 
-  SmmPoolType = UefiMemoryTypeToSmmPoolType(FreePoolHdr->Header.Type);
+  SmmPoolType = UefiMemoryTypeToSmmPoolType (FreePoolHdr->Header.Type);
 
-  PoolIndex = (UINTN) (HighBitSet32 ((UINT32)FreePoolHdr->Header.Size) - MIN_POOL_SHIFT);
+  PoolIndex                     = (UINTN)(HighBitSet32 ((UINT32)FreePoolHdr->Header.Size) - MIN_POOL_SHIFT);
   FreePoolHdr->Header.Signature = 0;
   FreePoolHdr->Header.Available = TRUE;
-  FreePoolHdr->Header.Type = 0;
-  PoolTail->Signature = 0;
-  PoolTail->Size = 0;
+  FreePoolHdr->Header.Type      = 0;
+  PoolTail->Signature           = 0;
+  PoolTail->Size                = 0;
   ASSERT (PoolIndex < MAX_POOL_INDEX);
   InsertHeadList (&mSmmPoolLists[SmmPoolType][PoolIndex], &FreePoolHdr->Link);
   return EFI_SUCCESS;
@@ -245,8 +250,9 @@ SmmInternalAllocatePool (
 
   Address = 0;
 
-  if (PoolType != EfiRuntimeServicesCode &&
-      PoolType != EfiRuntimeServicesData) {
+  if ((PoolType != EfiRuntimeServicesCode) &&
+      (PoolType != EfiRuntimeServicesData))
+  {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -258,14 +264,19 @@ SmmInternalAllocatePool (
   // Adjust the size by the pool header & tail overhead
   //
   Size += POOL_OVERHEAD;
-  if (Size > MAX_POOL_SIZE || NeedGuard) {
+  if ((Size > MAX_POOL_SIZE) || NeedGuard) {
     if (!HasPoolTail) {
       Size -= sizeof (POOL_TAIL);
     }
 
     NoPages = EFI_SIZE_TO_PAGES (Size);
-    Status = SmmInternalAllocatePages (AllocateAnyPages, PoolType, NoPages,
-                                       &Address, NeedGuard);
+    Status  = SmmInternalAllocatePages (
+                AllocateAnyPages,
+                PoolType,
+                NoPages,
+                &Address,
+                NeedGuard
+                );
     if (EFI_ERROR (Status)) {
       return Status;
     }
@@ -279,32 +290,33 @@ SmmInternalAllocatePool (
                                                );
     }
 
-    PoolHdr = (POOL_HEADER*)(UINTN)Address;
+    PoolHdr            = (POOL_HEADER *)(UINTN)Address;
     PoolHdr->Signature = POOL_HEAD_SIGNATURE;
-    PoolHdr->Size = EFI_PAGES_TO_SIZE (NoPages);
+    PoolHdr->Size      = EFI_PAGES_TO_SIZE (NoPages);
     PoolHdr->Available = FALSE;
-    PoolHdr->Type = PoolType;
+    PoolHdr->Type      = PoolType;
 
     if (HasPoolTail) {
-      PoolTail = HEAD_TO_TAIL (PoolHdr);
+      PoolTail            = HEAD_TO_TAIL (PoolHdr);
       PoolTail->Signature = POOL_TAIL_SIGNATURE;
-      PoolTail->Size = PoolHdr->Size;
+      PoolTail->Size      = PoolHdr->Size;
     }
 
     *Buffer = PoolHdr + 1;
     return Status;
   }
 
-  Size = (Size + MIN_POOL_SIZE - 1) >> MIN_POOL_SHIFT;
-  PoolIndex = (UINTN) HighBitSet32 ((UINT32)Size);
+  Size      = (Size + MIN_POOL_SIZE - 1) >> MIN_POOL_SHIFT;
+  PoolIndex = (UINTN)HighBitSet32 ((UINT32)Size);
   if ((Size & (Size - 1)) != 0) {
     PoolIndex++;
   }
 
   Status = InternalAllocPoolByIndex (PoolType, PoolIndex, &FreePoolHdr);
-  if (!EFI_ERROR(Status)) {
+  if (!EFI_ERROR (Status)) {
     *Buffer = &FreePoolHdr->Header + 1;
   }
+
   return Status;
 }
 
@@ -334,7 +346,7 @@ SmmAllocatePool (
   Status = SmmInternalAllocatePool (PoolType, Size, Buffer);
   if (!EFI_ERROR (Status)) {
     SmmCoreUpdateProfile (
-      (EFI_PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS (0),
+      (EFI_PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MemoryProfileActionAllocatePool,
       PoolType,
       Size,
@@ -342,6 +354,7 @@ SmmAllocatePool (
       NULL
       );
   }
+
   return Status;
 }
 
@@ -371,10 +384,10 @@ SmmInternalFreePool (
 
   MemoryGuarded = IsHeapGuardEnabled () &&
                   IsMemoryGuarded ((EFI_PHYSICAL_ADDRESS)(UINTN)Buffer);
-  HasPoolTail   = !(MemoryGuarded &&
-                    ((PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) == 0));
+  HasPoolTail = !(MemoryGuarded &&
+                  ((PcdGet8 (PcdHeapGuardPropertyMask) & BIT7) == 0));
 
-  FreePoolHdr = (FREE_POOL_HEADER*)((POOL_HEADER*)Buffer - 1);
+  FreePoolHdr = (FREE_POOL_HEADER *)((POOL_HEADER *)Buffer - 1);
   ASSERT (FreePoolHdr->Header.Signature == POOL_HEAD_SIGNATURE);
   ASSERT (!FreePoolHdr->Header.Available);
   if (FreePoolHdr->Header.Signature != POOL_HEAD_SIGNATURE) {
@@ -414,6 +427,7 @@ SmmInternalFreePool (
              FALSE
              );
   }
+
   return InternalFreePoolByIndex (FreePoolHdr, PoolTail);
 }
 
@@ -437,7 +451,7 @@ SmmFreePool (
   Status = SmmInternalFreePool (Buffer);
   if (!EFI_ERROR (Status)) {
     SmmCoreUpdateProfile (
-      (EFI_PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS (0),
+      (EFI_PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MemoryProfileActionFreePool,
       EfiMaxMemoryType,
       0,
@@ -445,5 +459,6 @@ SmmFreePool (
       NULL
       );
   }
+
   return Status;
 }
