@@ -1,16 +1,10 @@
 /** @file
 
   The internal header file includes the common header files, defines
-  internal structure and functions used by FtwLite module.
+  internal structure and functions used by Ftw module.
 
-Copyright (c) 2006 - 2013, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials                          
-are licensed and made available under the terms and conditions of the BSD License         
-which accompanies this distribution.  The full text of the license may be found at        
-http://opensource.org/licenses/bsd-license.php                                            
-                                                                                          
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,                     
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED. 
+Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -31,7 +25,6 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 #include <Library/UefiDriverEntryPoint.h>
 #include <Library/BaseMemoryLib.h>
 #include <Library/MemoryAllocationLib.h>
-#include <Library/UefiBootServicesTableLib.h>
 #include <Library/ReportStatusCodeLib.h>
 
 //
@@ -39,17 +32,18 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 //
 #define FTW_ERASE_POLARITY  1
 
-#define FTW_ERASED_BYTE     ((UINT8) (255))
-#define FTW_POLARITY_REVERT ((UINT8) (255))
+#define FTW_ERASED_BYTE      ((UINT8) (255))
+#define FTW_POLARITY_REVERT  ((UINT8) (255))
 
 #define HEADER_ALLOCATED  0x1
 #define WRITES_ALLOCATED  0x2
 #define WRITES_COMPLETED  0x4
 
-#define BOOT_BLOCK_UPDATE 0x1
-#define SPARE_COMPLETED   0x2
-#define DEST_COMPLETED    0x4
+#define BOOT_BLOCK_UPDATE  0x1
+#define SPARE_COMPLETED    0x2
+#define DEST_COMPLETED     0x4
 
+#define FTW_BLOCKS(Length, BlockSize)  ((UINTN) ((Length) / (BlockSize) + (((Length) & ((BlockSize) - 1)) ? 1 : 0)))
 
 #define FTW_DEVICE_SIGNATURE  SIGNATURE_32 ('F', 'T', 'W', 'D')
 
@@ -57,26 +51,31 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 // EFI Fault tolerant protocol private data structure
 //
 typedef struct {
-  UINTN                                   Signature;
-  EFI_HANDLE                              Handle;
-  EFI_FAULT_TOLERANT_WRITE_PROTOCOL       FtwInstance;
-  EFI_PHYSICAL_ADDRESS                    WorkSpaceAddress;   // Base address of working space range in flash.
-  EFI_PHYSICAL_ADDRESS                    SpareAreaAddress;   // Base address of spare range in flash.
-  UINTN                                   WorkSpaceLength;    // Size of working space range in flash.
-  UINTN                                   SpareAreaLength;    // Size of spare range in flash.
-  UINTN                                   NumberOfSpareBlock; // Number of the blocks in spare block.
-  UINTN                                   BlockSize;          // Block size in bytes of the blocks in flash
-  EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER *FtwWorkSpaceHeader;// Pointer to Working Space Header in memory buffer
-  EFI_FAULT_TOLERANT_WRITE_HEADER         *FtwLastWriteHeader;// Pointer to last record header in memory buffer
-  EFI_FAULT_TOLERANT_WRITE_RECORD         *FtwLastWriteRecord;// Pointer to last record in memory buffer
-  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL      *FtwFvBlock;        // FVB of working block
-  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL      *FtwBackupFvb;      // FVB of spare block
-  EFI_LBA                                 FtwSpareLba;        // Start LBA of spare block
-  EFI_LBA                                 FtwWorkBlockLba;    // Start LBA of working block that contains working space in its last block.
-  EFI_LBA                                 FtwWorkSpaceLba;    // Start LBA of working space
-  UINTN                                   FtwWorkSpaceBase;   // Offset into the FtwWorkSpaceLba block.
-  UINTN                                   FtwWorkSpaceSize;   // Size of working space range that stores write record.
-  UINT8                                   *FtwWorkSpace;      // Point to Work Space in memory buffer 
+  UINTN                                      Signature;
+  EFI_HANDLE                                 Handle;
+  EFI_FAULT_TOLERANT_WRITE_PROTOCOL          FtwInstance;
+  EFI_PHYSICAL_ADDRESS                       WorkSpaceAddress;        // Base address of working space range in flash.
+  EFI_PHYSICAL_ADDRESS                       SpareAreaAddress;        // Base address of spare range in flash.
+  UINTN                                      WorkSpaceLength;         // Size of working space range in flash.
+  UINTN                                      NumberOfWorkSpaceBlock;  // Number of the blocks in work block for work space.
+  UINTN                                      WorkBlockSize;           // Block size in bytes of the work blocks in flash
+  UINTN                                      SpareAreaLength;         // Size of spare range in flash.
+  UINTN                                      NumberOfSpareBlock;      // Number of the blocks in spare block.
+  UINTN                                      SpareBlockSize;          // Block size in bytes of the spare blocks in flash
+  EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER    *FtwWorkSpaceHeader;     // Pointer to Working Space Header in memory buffer
+  EFI_FAULT_TOLERANT_WRITE_HEADER            *FtwLastWriteHeader;     // Pointer to last record header in memory buffer
+  EFI_FAULT_TOLERANT_WRITE_RECORD            *FtwLastWriteRecord;     // Pointer to last record in memory buffer
+  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL         *FtwFvBlock;             // FVB of working block
+  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL         *FtwBackupFvb;           // FVB of spare block
+  EFI_LBA                                    FtwSpareLba;             // Start LBA of spare block
+  EFI_LBA                                    FtwWorkBlockLba;         // Start LBA of working block that contains working space in its last block.
+  UINTN                                      NumberOfWorkBlock;       // Number of the blocks in work block.
+  EFI_LBA                                    FtwWorkSpaceLba;         // Start LBA of working space
+  UINTN                                      FtwWorkSpaceBase;        // Offset into the FtwWorkSpaceLba block.
+  UINTN                                      FtwWorkSpaceSize;        // Size of working space range that stores write record.
+  EFI_LBA                                    FtwWorkSpaceLbaInSpare;  // Start LBA of working space in spare block.
+  UINTN                                      FtwWorkSpaceBaseInSpare; // Offset into the FtwWorkSpaceLbaInSpare block.
+  UINT8                                      *FtwWorkSpace;           // Point to Work Space in memory buffer
   //
   // Following a buffer of FtwWorkSpace[FTW_WORK_SPACE_SIZE],
   // Allocated with EFI_FTW_DEVICE.
@@ -88,6 +87,7 @@ typedef struct {
 //
 // Driver entry point
 //
+
 /**
   This function is the entry point of the Fault Tolerant Write driver.
 
@@ -104,8 +104,8 @@ typedef struct {
 EFI_STATUS
 EFIAPI
 InitializeFaultTolerantWrite (
-  IN EFI_HANDLE         ImageHandle,
-  IN EFI_SYSTEM_TABLE   *SystemTable
+  IN EFI_HANDLE        ImageHandle,
+  IN EFI_SYSTEM_TABLE  *SystemTable
   );
 
 //
@@ -126,8 +126,8 @@ InitializeFaultTolerantWrite (
 EFI_STATUS
 EFIAPI
 FtwGetMaxBlockSize (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL    *This,
-  OUT UINTN                               *BlockSize
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This,
+  OUT UINTN                             *BlockSize
   );
 
 /**
@@ -154,10 +154,10 @@ FtwGetMaxBlockSize (
 EFI_STATUS
 EFIAPI
 FtwAllocate (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL    *This,
-  IN EFI_GUID                             *CallerId,
-  IN UINTN                                PrivateDataSize,
-  IN UINTN                                NumberOfWrites
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This,
+  IN EFI_GUID                           *CallerId,
+  IN UINTN                              PrivateDataSize,
+  IN UINTN                              NumberOfWrites
   );
 
 /**
@@ -177,11 +177,11 @@ FtwAllocate (
                          reading, writing, and erasing the target block.
   @param Buffer          The data to write.
 
-  @retval EFI_SUCCESS          The function completed successfully 
-  @retval EFI_ABORTED          The function could not complete successfully. 
-  @retval EFI_BAD_BUFFER_SIZE  The input data can't fit within the spare block. 
+  @retval EFI_SUCCESS          The function completed successfully
+  @retval EFI_ABORTED          The function could not complete successfully.
+  @retval EFI_BAD_BUFFER_SIZE  The input data can't fit within the spare block.
                                Offset + *NumBytes > SpareAreaLength.
-  @retval EFI_ACCESS_DENIED    No writes have been allocated. 
+  @retval EFI_ACCESS_DENIED    No writes have been allocated.
   @retval EFI_OUT_OF_RESOURCES Cannot allocate enough memory resource.
   @retval EFI_NOT_FOUND        Cannot find FVB protocol by handle.
 
@@ -189,13 +189,13 @@ FtwAllocate (
 EFI_STATUS
 EFIAPI
 FtwWrite (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL     *This,
-  IN EFI_LBA                               Lba,
-  IN UINTN                                 Offset,
-  IN UINTN                                 Length,
-  IN VOID                                  *PrivateData,
-  IN EFI_HANDLE                            FvBlockHandle,
-  IN VOID                                  *Buffer
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This,
+  IN EFI_LBA                            Lba,
+  IN UINTN                              Offset,
+  IN UINTN                              Length,
+  IN VOID                               *PrivateData,
+  IN EFI_HANDLE                         FvBlockHandle,
+  IN VOID                               *Buffer
   );
 
 /**
@@ -215,8 +215,8 @@ FtwWrite (
 EFI_STATUS
 EFIAPI
 FtwRestart (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL     *This,
-  IN EFI_HANDLE                            FvBlockHandle
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This,
+  IN EFI_HANDLE                         FvBlockHandle
   );
 
 /**
@@ -232,7 +232,7 @@ FtwRestart (
 EFI_STATUS
 EFIAPI
 FtwAbort (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL     *This
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This
   );
 
 /**
@@ -261,14 +261,14 @@ FtwAbort (
 EFI_STATUS
 EFIAPI
 FtwGetLastWrite (
-  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL     *This,
-  OUT EFI_GUID                             *CallerId,
-  OUT EFI_LBA                              *Lba,
-  OUT UINTN                                *Offset,
-  OUT UINTN                                *Length,
-  IN OUT UINTN                             *PrivateDataSize,
-  OUT VOID                                 *PrivateData,
-  OUT BOOLEAN                              *Complete
+  IN EFI_FAULT_TOLERANT_WRITE_PROTOCOL  *This,
+  OUT EFI_GUID                          *CallerId,
+  OUT EFI_LBA                           *Lba,
+  OUT UINTN                             *Offset,
+  OUT UINTN                             *Length,
+  IN OUT UINTN                          *PrivateDataSize,
+  OUT VOID                              *PrivateData,
+  OUT BOOLEAN                           *Complete
   );
 
 /**
@@ -284,17 +284,17 @@ FtwGetLastWrite (
                                 partially erased.
   @retval EFI_INVALID_PARAMETER One or more of the LBAs listed
                                 in the variable argument list do
-                                not exist in the firmware volume.  
+                                not exist in the firmware volume.
 
 
 **/
 EFI_STATUS
 FtwEraseSpareBlock (
-  IN EFI_FTW_DEVICE   *FtwDevice
+  IN EFI_FTW_DEVICE  *FtwDevice
   );
 
 /**
-  Retrive the proper FVB protocol interface by HANDLE.
+  Retrieve the proper FVB protocol interface by HANDLE.
 
 
   @param FvBlockHandle   The handle of FVB protocol that provides services for
@@ -335,7 +335,6 @@ IsWorkingBlock (
 
   @param FtwDevice       The private data of FTW driver
   @param FvBlock         Fvb protocol instance
-  @param Lba             The block specified
 
   @return A BOOLEAN value indicating in boot block or not.
 
@@ -343,19 +342,20 @@ IsWorkingBlock (
 BOOLEAN
 IsBootBlock (
   EFI_FTW_DEVICE                      *FtwDevice,
-  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock,
-  EFI_LBA                             Lba
+  EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock
   );
 
 /**
   Copy the content of spare block to a target block. Size is FTW_BLOCK_SIZE.
-  Spare block is accessed by FTW backup FVB protocol interface. LBA is 1.
-  Target block is accessed by FvbBlock protocol interface. LBA is Lba.
+  Spare block is accessed by FTW backup FVB protocol interface.
+  Target block is accessed by FvBlock protocol interface.
 
 
   @param FtwDevice       The private data of FTW driver
   @param FvBlock         FVB Protocol interface to access target block
   @param Lba             Lba of the target block
+  @param BlockSize       The size of the block
+  @param NumberOfBlocks  The number of consecutive blocks starting with Lba
 
   @retval  EFI_SUCCESS               Spare block content is copied to target block
   @retval  EFI_INVALID_PARAMETER     Input parameter error
@@ -367,7 +367,9 @@ EFI_STATUS
 FlushSpareBlockToTargetBlock (
   EFI_FTW_DEVICE                      *FtwDevice,
   EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock,
-  EFI_LBA                             Lba
+  EFI_LBA                             Lba,
+  UINTN                               BlockSize,
+  UINTN                               NumberOfBlocks
   );
 
 /**
@@ -390,13 +392,13 @@ FlushSpareBlockToTargetBlock (
 **/
 EFI_STATUS
 FlushSpareBlockToWorkingBlock (
-  EFI_FTW_DEVICE                      *FtwDevice
+  EFI_FTW_DEVICE  *FtwDevice
   );
 
 /**
   Copy the content of spare block to a boot block. Size is FTW_BLOCK_SIZE.
-  Spare block is accessed by FTW working FVB protocol interface. LBA is 1.
-  Target block is accessed by FvbBlock protocol interface. LBA is Lba.
+  Spare block is accessed by FTW working FVB protocol interface.
+  Target block is accessed by FvBlock protocol interface.
 
   FTW will do extra work on boot block update.
   FTW should depend on a protocol of EFI_ADDRESS_RANGE_SWAP_PROTOCOL,
@@ -405,7 +407,7 @@ FlushSpareBlockToWorkingBlock (
   1. GetRangeLocation(), if the Range is inside the boot block, FTW know
   that boot block will be update. It shall add a FLAG in the working block.
   2. When spare block is ready,
-  3. SetSwapState(EFI_SWAPPED)
+  3. SetSwapState(SWAPPED)
   4. erasing boot block,
   5. programming boot block until the boot block is ok.
   6. SetSwapState(UNSWAPPED)
@@ -421,7 +423,7 @@ FlushSpareBlockToWorkingBlock (
 **/
 EFI_STATUS
 FlushSpareBlockToBootBlock (
-  EFI_FTW_DEVICE                      *FtwDevice
+  EFI_FTW_DEVICE  *FtwDevice
   );
 
 /**
@@ -431,6 +433,7 @@ FlushSpareBlockToBootBlock (
 
 
   @param FvBlock         FVB Protocol interface to access SrcBlock and DestBlock
+  @param BlockSize       The size of the block
   @param Lba             Lba of a block
   @param Offset          Offset on the Lba
   @param NewBit          New value that will override the old value if it can be change
@@ -445,6 +448,7 @@ FlushSpareBlockToBootBlock (
 EFI_STATUS
 FtwUpdateFvState (
   IN EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock,
+  IN UINTN                               BlockSize,
   IN EFI_LBA                             Lba,
   IN UINTN                               Offset,
   IN UINT8                               NewBit
@@ -486,8 +490,8 @@ FtwGetLastWriteHeader (
 **/
 EFI_STATUS
 FtwGetLastWriteRecord (
-  IN EFI_FAULT_TOLERANT_WRITE_HEADER          *FtwWriteHeader,
-  OUT EFI_FAULT_TOLERANT_WRITE_RECORD         **FtwWriteRecord
+  IN EFI_FAULT_TOLERANT_WRITE_HEADER   *FtwWriteHeader,
+  OUT EFI_FAULT_TOLERANT_WRITE_RECORD  **FtwWriteRecord
   );
 
 /**
@@ -502,8 +506,8 @@ FtwGetLastWriteRecord (
 **/
 BOOLEAN
 IsFirstRecordOfWrites (
-  IN EFI_FAULT_TOLERANT_WRITE_HEADER    *FtwHeader,
-  IN EFI_FAULT_TOLERANT_WRITE_RECORD    *FtwRecord
+  IN EFI_FAULT_TOLERANT_WRITE_HEADER  *FtwHeader,
+  IN EFI_FAULT_TOLERANT_WRITE_RECORD  *FtwRecord
   );
 
 /**
@@ -520,8 +524,8 @@ IsFirstRecordOfWrites (
 **/
 BOOLEAN
 IsLastRecordOfWrites (
-  IN EFI_FAULT_TOLERANT_WRITE_HEADER    *FtwHeader,
-  IN EFI_FAULT_TOLERANT_WRITE_RECORD    *FtwRecord
+  IN EFI_FAULT_TOLERANT_WRITE_HEADER  *FtwHeader,
+  IN EFI_FAULT_TOLERANT_WRITE_RECORD  *FtwRecord
   );
 
 /**
@@ -536,8 +540,8 @@ IsLastRecordOfWrites (
 **/
 EFI_STATUS
 GetPreviousRecordOfWrites (
-  IN     EFI_FAULT_TOLERANT_WRITE_HEADER    *FtwHeader,
-  IN OUT EFI_FAULT_TOLERANT_WRITE_RECORD    **FtwRecord
+  IN     EFI_FAULT_TOLERANT_WRITE_HEADER  *FtwHeader,
+  IN OUT EFI_FAULT_TOLERANT_WRITE_RECORD  **FtwRecord
   );
 
 /**
@@ -552,9 +556,10 @@ GetPreviousRecordOfWrites (
 **/
 BOOLEAN
 IsErasedFlashBuffer (
-  IN UINT8           *Buffer,
-  IN UINTN           BufferSize
+  IN UINT8  *Buffer,
+  IN UINTN  BufferSize
   );
+
 /**
   Initialize a work space when there is no work space.
 
@@ -566,8 +571,9 @@ IsErasedFlashBuffer (
 **/
 EFI_STATUS
 InitWorkSpaceHeader (
-  IN EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER *WorkingHeader
+  IN EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER  *WorkingHeader
   );
+
 /**
   Read from working block to refresh the work space in memory.
 
@@ -581,6 +587,7 @@ EFI_STATUS
 WorkSpaceRefresh (
   IN EFI_FTW_DEVICE  *FtwDevice
   );
+
 /**
   Check to see if it is a valid work space.
 
@@ -593,8 +600,9 @@ WorkSpaceRefresh (
 **/
 BOOLEAN
 IsValidWorkSpace (
-  IN EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER *WorkingHeader
+  IN EFI_FAULT_TOLERANT_WORKING_BLOCK_HEADER  *WorkingHeader
   );
+
 /**
   Reclaim the work space on the working block.
 
@@ -614,7 +622,7 @@ FtwReclaimWorkSpace (
 
 /**
 
-  Get firmware block by address.
+  Get firmware volume block by address.
 
 
   @param Address         Address specified the block
@@ -626,12 +634,12 @@ FtwReclaimWorkSpace (
 **/
 EFI_HANDLE
 GetFvbByAddress (
-  IN  EFI_PHYSICAL_ADDRESS               Address,
-  OUT EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL **FvBlock
+  IN  EFI_PHYSICAL_ADDRESS                Address,
+  OUT EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  **FvBlock
   );
 
 /**
-  Retrive the proper Swap Address Range protocol interface.
+  Retrieve the proper Swap Address Range protocol interface.
 
   @param[out] SarProtocol       The interface of SAR protocol
 
@@ -642,12 +650,12 @@ GetFvbByAddress (
 **/
 EFI_STATUS
 FtwGetSarProtocol (
-  OUT VOID                                **SarProtocol
+  OUT VOID  **SarProtocol
   );
-  
+
 /**
   Function returns an array of handles that support the FVB protocol
-  in a buffer allocated from pool. 
+  in a buffer allocated from pool.
 
   @param[out]  NumberHandles    The number of handles returned in Buffer.
   @param[out]  Buffer           A pointer to the buffer to return the requested
@@ -662,11 +670,10 @@ FtwGetSarProtocol (
 **/
 EFI_STATUS
 GetFvbCountAndBuffer (
-  OUT UINTN                               *NumberHandles,
-  OUT EFI_HANDLE                          **Buffer
+  OUT UINTN       *NumberHandles,
+  OUT EFI_HANDLE  **Buffer
   );
 
-
 /**
   Allocate private data for FTW driver and initialize it.
 
@@ -679,10 +686,9 @@ GetFvbCountAndBuffer (
 **/
 EFI_STATUS
 InitFtwDevice (
-  OUT EFI_FTW_DEVICE               **FtwData 
+  OUT EFI_FTW_DEVICE  **FtwData
   );
 
-
 /**
   Initialization for Fault Tolerant Write is done in this handler.
 
@@ -690,11 +696,11 @@ InitFtwDevice (
 
   @retval EFI_SUCCESS           Initialize the FTW protocol successfully.
   @retval EFI_NOT_FOUND         No proper FVB protocol was found.
-  
+
 **/
 EFI_STATUS
 InitFtwProtocol (
-  IN OUT EFI_FTW_DEVICE               *FtwDevice
+  IN OUT EFI_FTW_DEVICE  *FtwDevice
   );
 
 /**
@@ -707,5 +713,75 @@ VOID
 InitializeLocalWorkSpaceHeader (
   VOID
   );
- 
+
+/**
+  Read work space data from work block or spare block.
+
+  @param FvBlock        FVB Protocol interface to access the block.
+  @param BlockSize      The size of the block.
+  @param Lba            Lba of the block.
+  @param Offset         The offset within the block.
+  @param Length         The number of bytes to read from the block.
+  @param Buffer         The data is read.
+
+  @retval EFI_SUCCESS   The function completed successfully.
+  @retval EFI_ABORTED   The function could not complete successfully.
+
+**/
+EFI_STATUS
+ReadWorkSpaceData (
+  IN EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock,
+  IN UINTN                               BlockSize,
+  IN EFI_LBA                             Lba,
+  IN UINTN                               Offset,
+  IN UINTN                               Length,
+  OUT UINT8                              *Buffer
+  );
+
+/**
+  Write data to work block.
+
+  @param FvBlock        FVB Protocol interface to access the block.
+  @param BlockSize      The size of the block.
+  @param Lba            Lba of the block.
+  @param Offset         The offset within the block to place the data.
+  @param Length         The number of bytes to write to the block.
+  @param Buffer         The data to write.
+
+  @retval EFI_SUCCESS   The function completed successfully.
+  @retval EFI_ABORTED   The function could not complete successfully.
+
+**/
+EFI_STATUS
+WriteWorkSpaceData (
+  IN EFI_FIRMWARE_VOLUME_BLOCK_PROTOCOL  *FvBlock,
+  IN UINTN                               BlockSize,
+  IN EFI_LBA                             Lba,
+  IN UINTN                               Offset,
+  IN UINTN                               Length,
+  IN UINT8                               *Buffer
+  );
+
+/**
+  Internal implementation of CRC32. Depending on the execution context
+  (traditional SMM or DXE vs standalone MM), this function is implemented
+  via a call to the CalculateCrc32 () boot service, or via a library
+  call.
+
+  If Buffer is NULL, then ASSERT().
+  If Length is greater than (MAX_ADDRESS - Buffer + 1), then ASSERT().
+
+  @param[in]  Buffer       A pointer to the buffer on which the 32-bit CRC is
+                           to be computed.
+  @param[in]  Length       The number of bytes in the buffer Data.
+
+  @retval Crc32            The 32-bit CRC was computed for the data buffer.
+
+**/
+UINT32
+FtwCalculateCrc32 (
+  IN  VOID   *Buffer,
+  IN  UINTN  Length
+  );
+
 #endif
