@@ -39,8 +39,8 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 /// Unicode String Table
 ///
 typedef struct {
-  CHAR8   *Language;
-  CHAR16  *UnicodeString;
+  CHAR8     *Language;
+  CHAR16    *UnicodeString;
 } EFI_UNICODE_STRING_TABLE;
 
 ///
@@ -56,9 +56,9 @@ typedef enum {
 /// EFI Lock
 ///
 typedef struct {
-  EFI_TPL         Tpl;
-  EFI_TPL         OwnerTpl;
-  EFI_LOCK_STATE  Lock;
+  EFI_TPL           Tpl;
+  EFI_TPL           OwnerTpl;
+  EFI_LOCK_STATE    Lock;
 } EFI_LOCK;
 
 /**
@@ -71,7 +71,7 @@ typedef struct {
           by Microseconds.
 
 **/
-#define EFI_TIMER_PERIOD_MICROSECONDS(Microseconds) MultU64x32((UINT64)(Microseconds), 10)
+#define EFI_TIMER_PERIOD_MICROSECONDS(Microseconds)  MultU64x32((UINT64)(Microseconds), 10)
 
 /**
   Macro that returns the number of 100 ns units for a specified number of milliseconds.
@@ -83,7 +83,7 @@ typedef struct {
           by Milliseconds.
 
 **/
-#define EFI_TIMER_PERIOD_MILLISECONDS(Milliseconds) MultU64x32((UINT64)(Milliseconds), 10000)
+#define EFI_TIMER_PERIOD_MILLISECONDS(Milliseconds)  MultU64x32((UINT64)(Milliseconds), 10000)
 
 /**
   Macro that returns the number of 100 ns units for a specified number of seconds.
@@ -95,7 +95,7 @@ typedef struct {
           by Seconds.
 
 **/
-#define EFI_TIMER_PERIOD_SECONDS(Seconds)           MultU64x32((UINT64)(Seconds), 10000000)
+#define EFI_TIMER_PERIOD_SECONDS(Seconds)  MultU64x32((UINT64)(Seconds), 10000000)
 
 /**
   Macro that returns the a pointer to the next EFI_MEMORY_DESCRIPTOR in an array
@@ -165,11 +165,11 @@ EfiGetSystemConfigurationTable (
 **/
 EFI_EVENT
 EFIAPI
-EfiCreateProtocolNotifyEvent(
+EfiCreateProtocolNotifyEvent (
   IN  EFI_GUID          *ProtocolGuid,
   IN  EFI_TPL           NotifyTpl,
   IN  EFI_EVENT_NOTIFY  NotifyFunction,
-  IN  VOID              *NotifyContext,  OPTIONAL
+  IN  VOID              *NotifyContext   OPTIONAL,
   OUT VOID              **Registration
   );
 
@@ -199,7 +199,7 @@ EfiNamedEventListen (
   IN CONST EFI_GUID    *Name,
   IN EFI_TPL           NotifyTpl,
   IN EFI_EVENT_NOTIFY  NotifyFunction,
-  IN CONST VOID        *NotifyContext,  OPTIONAL
+  IN CONST VOID        *NotifyContext   OPTIONAL,
   OUT VOID             *Registration OPTIONAL
   );
 
@@ -237,7 +237,7 @@ EfiNamedEventSignal (
 EFI_STATUS
 EFIAPI
 EfiEventGroupSignal (
-  IN CONST EFI_GUID *EventGroup
+  IN CONST EFI_GUID  *EventGroup
   );
 
 /**
@@ -252,8 +252,8 @@ EfiEventGroupSignal (
 VOID
 EFIAPI
 EfiEventEmptyFunction (
-  IN EFI_EVENT              Event,
-  IN VOID                   *Context
+  IN EFI_EVENT  Event,
+  IN VOID       *Context
   );
 
 /**
@@ -294,7 +294,7 @@ EFI_LOCK *
 EFIAPI
 EfiInitializeLock (
   IN OUT EFI_LOCK  *Lock,
-  IN EFI_TPL        Priority
+  IN EFI_TPL       Priority
   );
 
 /**
@@ -313,7 +313,6 @@ EfiInitializeLock (
 #define EFI_INITIALIZE_LOCK_VARIABLE(Priority) \
   {Priority, TPL_APPLICATION, EfiLockReleased }
 
-
 /**
   Macro that calls DebugAssert() if an EFI_LOCK structure is not in the locked state.
 
@@ -328,8 +327,8 @@ EfiInitializeLock (
   @param  LockParameter  A pointer to the lock to acquire.
 
 **/
-#if !defined(MDEPKG_NDEBUG)
-  #define ASSERT_LOCKED(LockParameter)                  \
+#if !defined (MDEPKG_NDEBUG)
+#define ASSERT_LOCKED(LockParameter)                  \
     do {                                                \
       if (DebugAssertEnabled ()) {                      \
         ASSERT (LockParameter != NULL);                 \
@@ -339,10 +338,9 @@ EfiInitializeLock (
       }                                                 \
     } while (FALSE)
 #else
-  #define ASSERT_LOCKED(LockParameter)
+#define ASSERT_LOCKED(LockParameter)
 #endif
 
-
 /**
   Acquires ownership of a lock.
 
@@ -429,9 +427,9 @@ EfiReleaseLock (
 EFI_STATUS
 EFIAPI
 EfiTestManagedDevice (
-  IN CONST EFI_HANDLE       ControllerHandle,
-  IN CONST EFI_HANDLE       DriverBindingHandle,
-  IN CONST EFI_GUID         *ProtocolGuid
+  IN CONST EFI_HANDLE  ControllerHandle,
+  IN CONST EFI_HANDLE  DriverBindingHandle,
+  IN CONST EFI_GUID    *ProtocolGuid
   );
 
 /**
@@ -456,9 +454,9 @@ EfiTestManagedDevice (
 EFI_STATUS
 EFIAPI
 EfiTestChildHandle (
-  IN CONST EFI_HANDLE       ControllerHandle,
-  IN CONST EFI_HANDLE       ChildHandle,
-  IN CONST EFI_GUID         *ProtocolGuid
+  IN CONST EFI_HANDLE  ControllerHandle,
+  IN CONST EFI_HANDLE  ChildHandle,
+  IN CONST EFI_GUID    *ProtocolGuid
   );
 
 /**
@@ -475,8 +473,8 @@ EfiTestChildHandle (
 EFI_STATUS
 EFIAPI
 IsLanguageSupported (
-  IN CONST CHAR8 *SupportedLanguages,
-  IN CONST CHAR8 *TargetLanguage
+  IN CONST CHAR8  *SupportedLanguages,
+  IN CONST CHAR8  *TargetLanguage
   );
 
 /**
@@ -680,60 +678,6 @@ FreeUnicodeStringTable (
   IN EFI_UNICODE_STRING_TABLE  *UnicodeStringTable
   );
 
-#ifndef DISABLE_NEW_DEPRECATED_INTERFACES
-
-/**
-  [ATTENTION] This function will be deprecated for security reason.
-
-  Returns a pointer to an allocated buffer that contains the contents of a
-  variable retrieved through the UEFI Runtime Service GetVariable().  The
-  returned buffer is allocated using AllocatePool().  The caller is responsible
-  for freeing this buffer with FreePool().
-
-  If Name is NULL, then ASSERT().
-  If Guid is NULL, then ASSERT().
-
-  @param[in]  Name  The pointer to a Null-terminated Unicode string.
-  @param[in]  Guid  The pointer to an EFI_GUID structure.
-
-  @retval NULL   The variable could not be retrieved.
-  @retval NULL   There are not enough resources available for the variable contents.
-  @retval Other  A pointer to allocated buffer containing the variable contents.
-
-**/
-VOID *
-EFIAPI
-GetVariable (
-  IN CONST CHAR16    *Name,
-  IN CONST EFI_GUID  *Guid
-  );
-
-/**
-  [ATTENTION] This function will be deprecated for security reason.
-
-  Returns a pointer to an allocated buffer that contains the contents of a
-  variable retrieved through the UEFI Runtime Service GetVariable().  This
-  function always uses the EFI_GLOBAL_VARIABLE GUID to retrieve variables.
-  The returned buffer is allocated using AllocatePool().  The caller is
-  responsible for freeing this buffer with FreePool().
-
-  If Name is NULL, then ASSERT().
-
-  @param[in]  Name  The pointer to a Null-terminated Unicode string.
-
-  @retval NULL   The variable could not be retrieved.
-  @retval NULL   There are not enough resources available for the variable contents.
-  @retval Other  A pointer to allocated buffer containing the variable contents.
-
-**/
-VOID *
-EFIAPI
-GetEfiGlobalVariable (
-  IN CONST CHAR16  *Name
-  );
-#endif
-
-
 /**
   Returns the status whether get the variable success. The function retrieves
   variable  through the UEFI Runtime Service GetVariable().  The
@@ -785,9 +729,9 @@ GetVariable2 (
 EFI_STATUS
 EFIAPI
 GetEfiGlobalVariable2 (
-  IN CONST CHAR16    *Name,
-  OUT VOID           **Value,
-  OUT UINTN          *Size OPTIONAL
+  IN CONST CHAR16  *Name,
+  OUT VOID         **Value,
+  OUT UINTN        *Size OPTIONAL
   );
 
 /** Return the attributes of the variable.
@@ -815,12 +759,12 @@ GetEfiGlobalVariable2 (
 **/
 EFI_STATUS
 EFIAPI
-GetVariable3(
-  IN CONST CHAR16       *Name,
-  IN CONST EFI_GUID     *Guid,
-     OUT VOID           **Value,
-     OUT UINTN          *Size OPTIONAL,
-     OUT UINT32         *Attr OPTIONAL
+GetVariable3 (
+  IN CONST CHAR16    *Name,
+  IN CONST EFI_GUID  *Guid,
+  OUT VOID           **Value,
+  OUT UINTN          *Size OPTIONAL,
+  OUT UINT32         *Attr OPTIONAL
   );
 
 /**
@@ -894,7 +838,7 @@ VOID
 EFIAPI
 CreatePopUp (
   IN  UINTN          Attribute,
-  OUT EFI_INPUT_KEY  *Key,      OPTIONAL
+  OUT EFI_INPUT_KEY  *Key       OPTIONAL,
   ...
   );
 
@@ -942,6 +886,7 @@ UnicodeStringDisplayLength (
 //
 // Functions that abstract early Framework contamination of UEFI.
 //
+
 /**
   Create, Signal, and Close the Ready to Boot event using EfiSignalEventReadyToBoot().
 
@@ -1018,8 +963,8 @@ EFI_STATUS
 EFIAPI
 EfiCreateEventLegacyBootEx (
   IN  EFI_TPL           NotifyTpl,
-  IN  EFI_EVENT_NOTIFY  NotifyFunction,  OPTIONAL
-  IN  VOID              *NotifyContext,  OPTIONAL
+  IN  EFI_EVENT_NOTIFY  NotifyFunction   OPTIONAL,
+  IN  VOID              *NotifyContext   OPTIONAL,
   OUT EFI_EVENT         *LegacyBootEvent
   );
 
@@ -1069,8 +1014,8 @@ EFI_STATUS
 EFIAPI
 EfiCreateEventReadyToBootEx (
   IN  EFI_TPL           NotifyTpl,
-  IN  EFI_EVENT_NOTIFY  NotifyFunction,  OPTIONAL
-  IN  VOID              *NotifyContext,  OPTIONAL
+  IN  EFI_EVENT_NOTIFY  NotifyFunction   OPTIONAL,
+  IN  VOID              *NotifyContext   OPTIONAL,
   OUT EFI_EVENT         *ReadyToBootEvent
   );
 
@@ -1227,7 +1172,6 @@ AsciiErrorPrint (
   ...
   );
 
-
 /**
   Prints a formatted Unicode string to a graphics console device specified by
   ConsoleOutputHandle defined in the EFI_SYSTEM_TABLE at the given (X,Y) coordinates.
@@ -1271,11 +1215,11 @@ AsciiErrorPrint (
 UINTN
 EFIAPI
 PrintXY (
-  IN UINTN                            PointX,
-  IN UINTN                            PointY,
-  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL    *ForeGround, OPTIONAL
-  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL    *BackGround, OPTIONAL
-  IN CONST CHAR16                     *Format,
+  IN UINTN                          PointX,
+  IN UINTN                          PointY,
+  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL  *ForeGround  OPTIONAL,
+  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL  *BackGround  OPTIONAL,
+  IN CONST CHAR16                   *Format,
   ...
   );
 
@@ -1321,15 +1265,14 @@ PrintXY (
 UINTN
 EFIAPI
 AsciiPrintXY (
-  IN UINTN                            PointX,
-  IN UINTN                            PointY,
-  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL    *ForeGround, OPTIONAL
-  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL    *BackGround, OPTIONAL
-  IN CONST CHAR8                      *Format,
+  IN UINTN                          PointX,
+  IN UINTN                          PointY,
+  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL  *ForeGround  OPTIONAL,
+  IN EFI_GRAPHICS_OUTPUT_BLT_PIXEL  *BackGround  OPTIONAL,
+  IN CONST CHAR8                    *Format,
   ...
   );
 
-
 /**
   Installs and completes the initialization of a Driver Binding Protocol instance.
 
@@ -1361,7 +1304,6 @@ EfiLibInstallDriverBinding (
   IN EFI_HANDLE                   DriverBindingHandle
   );
 
-
 /**
   Uninstalls a Driver Binding Protocol instance.
 
@@ -1380,7 +1322,6 @@ EfiLibUninstallDriverBinding (
   IN EFI_DRIVER_BINDING_PROTOCOL  *DriverBinding
   );
 
-
 /**
   Installs and completes the initialization of a Driver Binding Protocol instance and
   optionally installs the Component Name, Driver Configuration and Driver Diagnostics Protocols.
@@ -1414,12 +1355,11 @@ EfiLibInstallAllDriverProtocols (
   IN CONST EFI_SYSTEM_TABLE                   *SystemTable,
   IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
   IN EFI_HANDLE                               DriverBindingHandle,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,       OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration, OPTIONAL
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName        OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration  OPTIONAL,
   IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL    *DriverDiagnostics    OPTIONAL
   );
 
-
 /**
   Uninstalls a Driver Binding Protocol instance and optionally uninstalls the
   Component Name, Driver Configuration and Driver Diagnostics Protocols.
@@ -1440,12 +1380,11 @@ EFI_STATUS
 EFIAPI
 EfiLibUninstallAllDriverProtocols (
   IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,       OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration, OPTIONAL
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName        OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration  OPTIONAL,
   IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL    *DriverDiagnostics    OPTIONAL
   );
 
-
 /**
   Installs Driver Binding Protocol with optional Component Name and Component Name 2 Protocols.
 
@@ -1472,15 +1411,14 @@ EfiLibUninstallAllDriverProtocols (
 EFI_STATUS
 EFIAPI
 EfiLibInstallDriverBindingComponentName2 (
-  IN CONST EFI_HANDLE                         ImageHandle,
-  IN CONST EFI_SYSTEM_TABLE                   *SystemTable,
-  IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
-  IN EFI_HANDLE                               DriverBindingHandle,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,       OPTIONAL
-  IN CONST EFI_COMPONENT_NAME2_PROTOCOL       *ComponentName2       OPTIONAL
+  IN CONST EFI_HANDLE                    ImageHandle,
+  IN CONST EFI_SYSTEM_TABLE              *SystemTable,
+  IN EFI_DRIVER_BINDING_PROTOCOL         *DriverBinding,
+  IN EFI_HANDLE                          DriverBindingHandle,
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL   *ComponentName        OPTIONAL,
+  IN CONST EFI_COMPONENT_NAME2_PROTOCOL  *ComponentName2       OPTIONAL
   );
 
-
 /**
   Uninstalls Driver Binding Protocol with optional Component Name and Component Name 2 Protocols.
 
@@ -1498,12 +1436,11 @@ EfiLibInstallDriverBindingComponentName2 (
 EFI_STATUS
 EFIAPI
 EfiLibUninstallDriverBindingComponentName2 (
-  IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,       OPTIONAL
-  IN CONST EFI_COMPONENT_NAME2_PROTOCOL       *ComponentName2       OPTIONAL
+  IN EFI_DRIVER_BINDING_PROTOCOL         *DriverBinding,
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL   *ComponentName        OPTIONAL,
+  IN CONST EFI_COMPONENT_NAME2_PROTOCOL  *ComponentName2       OPTIONAL
   );
 
-
 /**
   Installs Driver Binding Protocol with optional Component Name, Component Name 2, Driver
   Configuration, Driver Configuration 2, Driver Diagnostics, and Driver Diagnostics 2 Protocols.
@@ -1536,19 +1473,18 @@ EfiLibUninstallDriverBindingComponentName2 (
 EFI_STATUS
 EFIAPI
 EfiLibInstallAllDriverProtocols2 (
-  IN CONST EFI_HANDLE                         ImageHandle,
-  IN CONST EFI_SYSTEM_TABLE                   *SystemTable,
-  IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
-  IN EFI_HANDLE                               DriverBindingHandle,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,        OPTIONAL
-  IN CONST EFI_COMPONENT_NAME2_PROTOCOL       *ComponentName2,       OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration,  OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION2_PROTOCOL *DriverConfiguration2, OPTIONAL
-  IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL    *DriverDiagnostics,    OPTIONAL
-  IN CONST EFI_DRIVER_DIAGNOSTICS2_PROTOCOL   *DriverDiagnostics2    OPTIONAL
+  IN CONST EFI_HANDLE                          ImageHandle,
+  IN CONST EFI_SYSTEM_TABLE                    *SystemTable,
+  IN EFI_DRIVER_BINDING_PROTOCOL               *DriverBinding,
+  IN EFI_HANDLE                                DriverBindingHandle,
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL         *ComponentName         OPTIONAL,
+  IN CONST EFI_COMPONENT_NAME2_PROTOCOL        *ComponentName2        OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL   *DriverConfiguration   OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION2_PROTOCOL  *DriverConfiguration2  OPTIONAL,
+  IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL     *DriverDiagnostics     OPTIONAL,
+  IN CONST EFI_DRIVER_DIAGNOSTICS2_PROTOCOL    *DriverDiagnostics2    OPTIONAL
   );
 
-
 /**
   Uninstalls Driver Binding Protocol with optional Component Name, Component Name 2, Driver
   Configuration, Driver Configuration 2, Driver Diagnostics, and Driver Diagnostics 2 Protocols.
@@ -1572,16 +1508,15 @@ EfiLibInstallAllDriverProtocols2 (
 EFI_STATUS
 EFIAPI
 EfiLibUninstallAllDriverProtocols2 (
-  IN EFI_DRIVER_BINDING_PROTOCOL              *DriverBinding,
-  IN CONST EFI_COMPONENT_NAME_PROTOCOL        *ComponentName,        OPTIONAL
-  IN CONST EFI_COMPONENT_NAME2_PROTOCOL       *ComponentName2,       OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL  *DriverConfiguration,  OPTIONAL
-  IN CONST EFI_DRIVER_CONFIGURATION2_PROTOCOL *DriverConfiguration2, OPTIONAL
-  IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL    *DriverDiagnostics,    OPTIONAL
-  IN CONST EFI_DRIVER_DIAGNOSTICS2_PROTOCOL   *DriverDiagnostics2    OPTIONAL
+  IN EFI_DRIVER_BINDING_PROTOCOL               *DriverBinding,
+  IN CONST EFI_COMPONENT_NAME_PROTOCOL         *ComponentName         OPTIONAL,
+  IN CONST EFI_COMPONENT_NAME2_PROTOCOL        *ComponentName2        OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION_PROTOCOL   *DriverConfiguration   OPTIONAL,
+  IN CONST EFI_DRIVER_CONFIGURATION2_PROTOCOL  *DriverConfiguration2  OPTIONAL,
+  IN CONST EFI_DRIVER_DIAGNOSTICS_PROTOCOL     *DriverDiagnostics     OPTIONAL,
+  IN CONST EFI_DRIVER_DIAGNOSTICS2_PROTOCOL    *DriverDiagnostics2    OPTIONAL
   );
 
-
 /**
   Appends a formatted Unicode string to a Null-terminated Unicode string
 
@@ -1603,10 +1538,10 @@ EfiLibUninstallAllDriverProtocols2 (
   @return         Null-terminated Unicode string is that is the formatted
                   string appended to String.
 **/
-CHAR16*
+CHAR16 *
 EFIAPI
 CatVSPrint (
-  IN  CHAR16  *String, OPTIONAL
+  IN  CHAR16        *String  OPTIONAL,
   IN  CONST CHAR16  *FormatString,
   IN  VA_LIST       Marker
   );
@@ -1637,7 +1572,7 @@ CatVSPrint (
 CHAR16 *
 EFIAPI
 CatSPrint (
-  IN  CHAR16  *String, OPTIONAL
+  IN  CHAR16        *String  OPTIONAL,
   IN  CONST CHAR16  *FormatString,
   ...
   );
@@ -1784,8 +1719,8 @@ EfiOpenFileByDevicePath (
 EFI_ACPI_COMMON_HEADER *
 EFIAPI
 EfiLocateNextAcpiTable (
-  IN UINT32                     Signature,
-  IN EFI_ACPI_COMMON_HEADER     *PreviousTable OPTIONAL
+  IN UINT32                  Signature,
+  IN EFI_ACPI_COMMON_HEADER  *PreviousTable OPTIONAL
   );
 
 /**
@@ -1808,7 +1743,7 @@ EfiLocateNextAcpiTable (
 EFI_ACPI_COMMON_HEADER *
 EFIAPI
 EfiLocateFirstAcpiTable (
-  IN UINT32                     Signature
+  IN UINT32  Signature
   );
 
 #endif
