@@ -7,13 +7,7 @@
   but interfaces in dynamic-ex type PCD require token space guid as parameter.
 
 Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials are licensed and made available under
-the terms and conditions of the BSD License that accompanies this distribution.
-The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php.
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
   @par Revision Reference:
   This Protocol was introduced in PI Specification 1.2.
@@ -23,13 +17,12 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 #ifndef __PCD_H__
 #define __PCD_H__
 
-extern EFI_GUID gPcdProtocolGuid;
+extern EFI_GUID  gPcdProtocolGuid;
 
 #define PCD_PROTOCOL_GUID \
   { 0x11b34006, 0xd85b, 0x4d0a, { 0xa2, 0x90, 0xd5, 0xa5, 0x71, 0x31, 0xe, 0xf7 } }
 
-#define PCD_INVALID_TOKEN_NUMBER ((UINTN) 0)
-
+#define PCD_INVALID_TOKEN_NUMBER  ((UINTN) 0)
 
 /**
   Sets the SKU value for subsequent calls to set or get PCD token values.
@@ -59,8 +52,6 @@ VOID
   IN  UINTN                  SkuId
   );
 
-
-
 /**
   Retrieves an 8-bit value for a given PCD token.
 
@@ -78,8 +69,6 @@ UINT8
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a 16-bit value for a given PCD token.
 
@@ -97,8 +86,6 @@ UINT16
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a 32-bit value for a given PCD token.
 
@@ -116,8 +103,6 @@ UINT32
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a 64-bit value for a given PCD token.
 
@@ -135,8 +120,6 @@ UINT64
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a pointer to a value for a given PCD token.
 
@@ -156,8 +139,6 @@ VOID *
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a Boolean value for a given PCD token.
 
@@ -177,8 +158,6 @@ BOOLEAN
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves the size of the value for a given PCD token.
 
@@ -196,8 +175,6 @@ UINTN
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves an 8-bit value for a given PCD token.
 
@@ -219,8 +196,6 @@ UINT8
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a 16-bit value for a given PCD token.
 
@@ -242,8 +217,6 @@ UINT16
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a 32-bit value for a given PCD token.
 
@@ -265,8 +238,6 @@ UINT32
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves an 64-bit value for a given PCD token.
 
@@ -288,8 +259,6 @@ UINT64
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a pointer to a value for a given PCD token.
 
@@ -311,8 +280,6 @@ VOID *
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves a Boolean value for a given PCD token.
 
@@ -334,8 +301,6 @@ BOOLEAN
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Retrieves the size of the value for a given PCD token.
 
@@ -355,8 +320,6 @@ UINTN
   IN UINTN             TokenNumber
   );
 
-
-
 /**
   Sets an 8-bit value for a given PCD token.
 
@@ -381,8 +344,6 @@ EFI_STATUS
   IN UINT8             Value
   );
 
-
-
 /**
   Sets a 16-bit value for a given PCD token.
 
@@ -407,8 +368,6 @@ EFI_STATUS
   IN UINT16             Value
   );
 
-
-
 /**
   Sets a 32-bit value for a given PCD token.
 
@@ -433,8 +392,6 @@ EFI_STATUS
   IN UINT32             Value
   );
 
-
-
 /**
   Sets a 64-bit value for a given PCD token.
 
@@ -459,8 +416,6 @@ EFI_STATUS
   IN UINT64            Value
   );
 
-
-
 /**
   Sets a value of a specified size for a given PCD token.
 
@@ -490,8 +445,6 @@ EFI_STATUS
   IN      VOID              *Buffer
   );
 
-
-
 /**
   Sets a Boolean value for a given PCD token.
 
@@ -516,8 +469,6 @@ EFI_STATUS
   IN BOOLEAN           Value
   );
 
-
-
 /**
   Sets an 8-bit value for a given PCD token.
 
@@ -544,8 +495,6 @@ EFI_STATUS
   IN UINT8             Value
   );
 
-
-
 /**
   Sets an 16-bit value for a given PCD token.
 
@@ -572,8 +521,6 @@ EFI_STATUS
   IN UINT16            Value
   );
 
-
-
 /**
   Sets a 32-bit value for a given PCD token.
 
@@ -600,8 +547,6 @@ EFI_STATUS
   IN UINT32             Value
   );
 
-
-
 /**
   Sets a 64-bit value for a given PCD token.
 
@@ -628,8 +573,6 @@ EFI_STATUS
   IN UINT64            Value
   );
 
-
-
 /**
   Sets a value of a specified size for a given PCD token.
 
@@ -661,8 +604,6 @@ EFI_STATUS
   IN       VOID              *Buffer
   );
 
-
-
 /**
   Sets a Boolean value for a given PCD token.
 
@@ -689,8 +630,6 @@ EFI_STATUS
   IN BOOLEAN           Value
   );
 
-
-
 /**
   Callback on SET function prototype definition.
 
@@ -713,14 +652,12 @@ EFI_STATUS
 typedef
 VOID
 (EFIAPI *PCD_PROTOCOL_CALLBACK)(
-  IN CONST EFI_GUID         *CallBackGuid, OPTIONAL
+  IN CONST EFI_GUID         *CallBackGuid  OPTIONAL,
   IN       UINTN            CallBackToken,
   IN OUT   VOID             *TokenData,
   IN       UINTN            TokenDataSize
   );
 
-
-
 /**
   Specifies a function to be called anytime the value of a designated token is changed.
 
@@ -736,13 +673,11 @@ VOID
 typedef
 EFI_STATUS
 (EFIAPI *PCD_PROTOCOL_CALLBACK_ONSET)(
-  IN  CONST EFI_GUID          *Guid, OPTIONAL
+  IN  CONST EFI_GUID          *Guid  OPTIONAL,
   IN  UINTN                   TokenNumber,
   IN  PCD_PROTOCOL_CALLBACK   CallBackFunction
   );
 
-
-
 /**
   Cancels a previously set callback function for a particular PCD token number.
 
@@ -758,13 +693,11 @@ EFI_STATUS
 typedef
 EFI_STATUS
 (EFIAPI *PCD_PROTOCOL_CANCEL_CALLBACK)(
-  IN  CONST EFI_GUID          *Guid, OPTIONAL
+  IN  CONST EFI_GUID          *Guid  OPTIONAL,
   IN  UINTN                   TokenNumber,
   IN  PCD_PROTOCOL_CALLBACK   CallBackFunction
   );
 
-
-
 /**
   Retrieves the next valid token number in a given namespace.
 
@@ -794,12 +727,10 @@ EFI_STATUS
 typedef
 EFI_STATUS
 (EFIAPI *PCD_PROTOCOL_GET_NEXT_TOKEN)(
-  IN      CONST EFI_GUID      *Guid, OPTIONAL
+  IN      CONST EFI_GUID      *Guid  OPTIONAL,
   IN OUT  UINTN               *TokenNumber
   );
 
-
-
 /**
   Retrieves the next valid PCD token namespace for a given namespace.
 
@@ -826,42 +757,42 @@ EFI_STATUS
 /// This service abstracts the ability to set/get Platform Configuration Database (PCD).
 ///
 typedef struct {
-  PCD_PROTOCOL_SET_SKU              SetSku;
+  PCD_PROTOCOL_SET_SKU                SetSku;
 
-  PCD_PROTOCOL_GET8                 Get8;
-  PCD_PROTOCOL_GET16                Get16;
-  PCD_PROTOCOL_GET32                Get32;
-  PCD_PROTOCOL_GET64                Get64;
-  PCD_PROTOCOL_GET_POINTER          GetPtr;
-  PCD_PROTOCOL_GET_BOOLEAN          GetBool;
-  PCD_PROTOCOL_GET_SIZE             GetSize;
+  PCD_PROTOCOL_GET8                   Get8;
+  PCD_PROTOCOL_GET16                  Get16;
+  PCD_PROTOCOL_GET32                  Get32;
+  PCD_PROTOCOL_GET64                  Get64;
+  PCD_PROTOCOL_GET_POINTER            GetPtr;
+  PCD_PROTOCOL_GET_BOOLEAN            GetBool;
+  PCD_PROTOCOL_GET_SIZE               GetSize;
 
-  PCD_PROTOCOL_GET_EX_8             Get8Ex;
-  PCD_PROTOCOL_GET_EX_16            Get16Ex;
-  PCD_PROTOCOL_GET_EX_32            Get32Ex;
-  PCD_PROTOCOL_GET_EX_64            Get64Ex;
-  PCD_PROTOCOL_GET_EX_POINTER       GetPtrEx;
-  PCD_PROTOCOL_GET_EX_BOOLEAN       GetBoolEx;
-  PCD_PROTOCOL_GET_EX_SIZE          GetSizeEx;
+  PCD_PROTOCOL_GET_EX_8               Get8Ex;
+  PCD_PROTOCOL_GET_EX_16              Get16Ex;
+  PCD_PROTOCOL_GET_EX_32              Get32Ex;
+  PCD_PROTOCOL_GET_EX_64              Get64Ex;
+  PCD_PROTOCOL_GET_EX_POINTER         GetPtrEx;
+  PCD_PROTOCOL_GET_EX_BOOLEAN         GetBoolEx;
+  PCD_PROTOCOL_GET_EX_SIZE            GetSizeEx;
 
-  PCD_PROTOCOL_SET8                 Set8;
-  PCD_PROTOCOL_SET16                Set16;
-  PCD_PROTOCOL_SET32                Set32;
-  PCD_PROTOCOL_SET64                Set64;
-  PCD_PROTOCOL_SET_POINTER          SetPtr;
-  PCD_PROTOCOL_SET_BOOLEAN          SetBool;
+  PCD_PROTOCOL_SET8                   Set8;
+  PCD_PROTOCOL_SET16                  Set16;
+  PCD_PROTOCOL_SET32                  Set32;
+  PCD_PROTOCOL_SET64                  Set64;
+  PCD_PROTOCOL_SET_POINTER            SetPtr;
+  PCD_PROTOCOL_SET_BOOLEAN            SetBool;
 
-  PCD_PROTOCOL_SET_EX_8             Set8Ex;
-  PCD_PROTOCOL_SET_EX_16            Set16Ex;
-  PCD_PROTOCOL_SET_EX_32            Set32Ex;
-  PCD_PROTOCOL_SET_EX_64            Set64Ex;
-  PCD_PROTOCOL_SET_EX_POINTER       SetPtrEx;
-  PCD_PROTOCOL_SET_EX_BOOLEAN       SetBoolEx;
+  PCD_PROTOCOL_SET_EX_8               Set8Ex;
+  PCD_PROTOCOL_SET_EX_16              Set16Ex;
+  PCD_PROTOCOL_SET_EX_32              Set32Ex;
+  PCD_PROTOCOL_SET_EX_64              Set64Ex;
+  PCD_PROTOCOL_SET_EX_POINTER         SetPtrEx;
+  PCD_PROTOCOL_SET_EX_BOOLEAN         SetBoolEx;
 
-  PCD_PROTOCOL_CALLBACK_ONSET       CallbackOnSet;
-  PCD_PROTOCOL_CANCEL_CALLBACK      CancelCallback;
-  PCD_PROTOCOL_GET_NEXT_TOKEN       GetNextToken;
-  PCD_PROTOCOL_GET_NEXT_TOKENSPACE  GetNextTokenSpace;
+  PCD_PROTOCOL_CALLBACK_ONSET         CallbackOnSet;
+  PCD_PROTOCOL_CANCEL_CALLBACK        CancelCallback;
+  PCD_PROTOCOL_GET_NEXT_TOKEN         GetNextToken;
+  PCD_PROTOCOL_GET_NEXT_TOKENSPACE    GetNextTokenSpace;
 } PCD_PROTOCOL;
 
 #endif
