@@ -42,88 +42,88 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 // position of RGB in the frame buffer is specified in the VBE Mode information
 //
 typedef struct {
-  UINT8 Position; // Position of the color
-  UINT8 Mask;     // The number of bits expressed as a mask
+  UINT8    Position; // Position of the color
+  UINT8    Mask;     // The number of bits expressed as a mask
 } BIOS_VIDEO_COLOR_PLACEMENT;
 
 //
 // BIOS Graphics Output Graphical Mode Data
 //
 typedef struct {
-  UINT16                      VbeModeNumber;
-  UINT16                      BytesPerScanLine;
-  VOID                        *LinearFrameBuffer;
-  UINTN                       FrameBufferSize;
-  UINT32                      HorizontalResolution;
-  UINT32                      VerticalResolution;
-  UINT32                      ColorDepth;
-  UINT32                      RefreshRate;
-  UINT32                      BitsPerPixel;
-  BIOS_VIDEO_COLOR_PLACEMENT  Red;
-  BIOS_VIDEO_COLOR_PLACEMENT  Green;
-  BIOS_VIDEO_COLOR_PLACEMENT  Blue;
-  BIOS_VIDEO_COLOR_PLACEMENT  Reserved;
-  EFI_GRAPHICS_PIXEL_FORMAT   PixelFormat;
-  EFI_PIXEL_BITMASK           PixelBitMask;
+  UINT16                        VbeModeNumber;
+  UINT16                        BytesPerScanLine;
+  VOID                          *LinearFrameBuffer;
+  UINTN                         FrameBufferSize;
+  UINT32                        HorizontalResolution;
+  UINT32                        VerticalResolution;
+  UINT32                        ColorDepth;
+  UINT32                        RefreshRate;
+  UINT32                        BitsPerPixel;
+  BIOS_VIDEO_COLOR_PLACEMENT    Red;
+  BIOS_VIDEO_COLOR_PLACEMENT    Green;
+  BIOS_VIDEO_COLOR_PLACEMENT    Blue;
+  BIOS_VIDEO_COLOR_PLACEMENT    Reserved;
+  EFI_GRAPHICS_PIXEL_FORMAT     PixelFormat;
+  EFI_PIXEL_BITMASK             PixelBitMask;
 } BIOS_VIDEO_MODE_DATA;
 
 //
 // BIOS video child handle private data Structure
 //
-#define BIOS_VIDEO_DEV_SIGNATURE    SIGNATURE_32 ('B', 'V', 'M', 'p')
+#define BIOS_VIDEO_DEV_SIGNATURE  SIGNATURE_32 ('B', 'V', 'M', 'p')
 
 typedef struct {
-  UINTN                                       Signature;
-  EFI_HANDLE                                  Handle;
+  UINTN                                          Signature;
+  EFI_HANDLE                                     Handle;
 
   //
   // Consumed Protocols
   //
-  EFI_PCI_IO_PROTOCOL                         *PciIo;
-  EFI_LEGACY_BIOS_PROTOCOL                    *LegacyBios;
+  EFI_PCI_IO_PROTOCOL                            *PciIo;
+  EFI_LEGACY_BIOS_PROTOCOL                       *LegacyBios;
 
   //
   // Produced Protocols
   //
-  EFI_GRAPHICS_OUTPUT_PROTOCOL                GraphicsOutput;
-  EFI_EDID_DISCOVERED_PROTOCOL                EdidDiscovered;
-  EFI_EDID_ACTIVE_PROTOCOL                    EdidActive;
-  EFI_VGA_MINI_PORT_PROTOCOL                  VgaMiniPort;
+  EFI_GRAPHICS_OUTPUT_PROTOCOL                   GraphicsOutput;
+  EFI_EDID_DISCOVERED_PROTOCOL                   EdidDiscovered;
+  EFI_EDID_ACTIVE_PROTOCOL                       EdidActive;
+  EFI_VGA_MINI_PORT_PROTOCOL                     VgaMiniPort;
 
   //
   // General fields
   //
-  BOOLEAN                                     VgaCompatible;
-  BOOLEAN                                     ProduceGraphicsOutput;
+  BOOLEAN                                        VgaCompatible;
+  BOOLEAN                                        ProduceGraphicsOutput;
 
   //
   // Graphics Output Protocol related fields
   //
-  BOOLEAN                                     HardwareNeedsStarting;
-  UINTN                                       CurrentMode;
-  UINTN                                       MaxMode;
-  BIOS_VIDEO_MODE_DATA                        *ModeData;
-  UINT8                                       *LineBuffer;
-  EFI_GRAPHICS_OUTPUT_BLT_PIXEL               *VbeFrameBuffer;
-  UINT8                                       *VgaFrameBuffer;
+  BOOLEAN                                        HardwareNeedsStarting;
+  UINTN                                          CurrentMode;
+  UINTN                                          MaxMode;
+  BIOS_VIDEO_MODE_DATA                           *ModeData;
+  UINT8                                          *LineBuffer;
+  EFI_GRAPHICS_OUTPUT_BLT_PIXEL                  *VbeFrameBuffer;
+  UINT8                                          *VgaFrameBuffer;
 
   //
   // VESA Bios Extensions related fields
   //
-  UINTN                                       NumberOfPagesBelow1MB;     // Number of 4KB pages in PagesBelow1MB
-  EFI_PHYSICAL_ADDRESS                        PagesBelow1MB;             // Buffer for all VBE Information Blocks
-  VESA_BIOS_EXTENSIONS_INFORMATION_BLOCK      *VbeInformationBlock;      // 0x200 bytes.  Must be allocated below 1MB
-  VESA_BIOS_EXTENSIONS_MODE_INFORMATION_BLOCK *VbeModeInformationBlock;  // 0x100 bytes.  Must be allocated below 1MB
-  VESA_BIOS_EXTENSIONS_EDID_DATA_BLOCK        *VbeEdidDataBlock;         // 0x80  bytes.  Must be allocated below 1MB
-  VESA_BIOS_EXTENSIONS_CRTC_INFORMATION_BLOCK *VbeCrtcInformationBlock;  // 59 bytes.  Must be allocated below 1MB
-  UINTN                                       VbeSaveRestorePages;       // Number of 4KB pages in VbeSaveRestoreBuffer
-  EFI_PHYSICAL_ADDRESS                        VbeSaveRestoreBuffer;      // Must be allocated below 1MB
+  UINTN                                          NumberOfPagesBelow1MB;    // Number of 4KB pages in PagesBelow1MB
+  EFI_PHYSICAL_ADDRESS                           PagesBelow1MB;            // Buffer for all VBE Information Blocks
+  VESA_BIOS_EXTENSIONS_INFORMATION_BLOCK         *VbeInformationBlock;     // 0x200 bytes.  Must be allocated below 1MB
+  VESA_BIOS_EXTENSIONS_MODE_INFORMATION_BLOCK    *VbeModeInformationBlock; // 0x100 bytes.  Must be allocated below 1MB
+  VESA_BIOS_EXTENSIONS_EDID_DATA_BLOCK           *VbeEdidDataBlock;        // 0x80  bytes.  Must be allocated below 1MB
+  VESA_BIOS_EXTENSIONS_CRTC_INFORMATION_BLOCK    *VbeCrtcInformationBlock; // 59 bytes.  Must be allocated below 1MB
+  UINTN                                          VbeSaveRestorePages;      // Number of 4KB pages in VbeSaveRestoreBuffer
+  EFI_PHYSICAL_ADDRESS                           VbeSaveRestoreBuffer;     // Must be allocated below 1MB
   //
   // Status code
   //
-  EFI_DEVICE_PATH_PROTOCOL                    *GopDevicePath;
+  EFI_DEVICE_PATH_PROTOCOL                       *GopDevicePath;
 
-  EFI_EVENT                                   ExitBootServicesEvent;
+  EFI_EVENT                                      ExitBootServicesEvent;
 } BIOS_VIDEO_DEV;
 
 #define BIOS_VIDEO_DEV_FROM_PCI_IO_THIS(a)           CR (a, BIOS_VIDEO_DEV, PciIo, BIOS_VIDEO_DEV_SIGNATURE)
@@ -164,7 +164,6 @@ BiosVideoDriverBindingSupported (
   IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   );
 
-
 /**
   Install Graphics Output Protocol onto VGA device handles.
 
@@ -184,7 +183,6 @@ BiosVideoDriverBindingStart (
   IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   );
 
-
 /**
   Stop.
 
@@ -223,7 +221,6 @@ BiosVideoCheckForVbe (
   IN OUT BIOS_VIDEO_DEV  *BiosVideoPrivate
   );
 
-
 /**
   Check for VGA device.
 
@@ -237,9 +234,6 @@ BiosVideoCheckForVga (
   IN OUT BIOS_VIDEO_DEV  *BiosVideoPrivate
   );
 
-
-
-
 /**
   Release resource for BIOS video instance.
 
@@ -282,7 +276,6 @@ BiosVideoGraphicsOutputQueryMode (
   OUT EFI_GRAPHICS_OUTPUT_MODE_INFORMATION  **Info
   );
 
-
 /**
   Graphics Output protocol interface to set video mode.
 
@@ -298,11 +291,10 @@ BiosVideoGraphicsOutputQueryMode (
 EFI_STATUS
 EFIAPI
 BiosVideoGraphicsOutputSetMode (
-  IN  EFI_GRAPHICS_OUTPUT_PROTOCOL * This,
-  IN  UINT32                       ModeNumber
+  IN  EFI_GRAPHICS_OUTPUT_PROTOCOL  *This,
+  IN  UINT32                        ModeNumber
   );
 
-
 /**
   Graphics Output protocol instance to block transfer for VBE device.
 
@@ -334,7 +326,7 @@ EFI_STATUS
 EFIAPI
 BiosVideoGraphicsOutputVbeBlt (
   IN  EFI_GRAPHICS_OUTPUT_PROTOCOL       *This,
-  IN  EFI_GRAPHICS_OUTPUT_BLT_PIXEL      *BltBuffer, OPTIONAL
+  IN  EFI_GRAPHICS_OUTPUT_BLT_PIXEL      *BltBuffer  OPTIONAL,
   IN  EFI_GRAPHICS_OUTPUT_BLT_OPERATION  BltOperation,
   IN  UINTN                              SourceX,
   IN  UINTN                              SourceY,
@@ -345,7 +337,6 @@ BiosVideoGraphicsOutputVbeBlt (
   IN  UINTN                              Delta
   );
 
-
 /**
   Graphics Output protocol instance to block transfer for VGA device.
 
@@ -377,7 +368,7 @@ EFI_STATUS
 EFIAPI
 BiosVideoGraphicsOutputVgaBlt (
   IN  EFI_GRAPHICS_OUTPUT_PROTOCOL       *This,
-  IN  EFI_GRAPHICS_OUTPUT_BLT_PIXEL      *BltBuffer, OPTIONAL
+  IN  EFI_GRAPHICS_OUTPUT_BLT_PIXEL      *BltBuffer  OPTIONAL,
   IN  EFI_GRAPHICS_OUTPUT_BLT_OPERATION  BltOperation,
   IN  UINTN                              SourceX,
   IN  UINTN                              SourceY,
@@ -419,50 +410,50 @@ BiosVideoVgaMiniPortSetMode (
 VOID
 EFIAPI
 BiosVideoNotifyExitBootServices (
-  IN  EFI_EVENT Event,
-  IN  VOID      *Context
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
   );
 
 //
 // Standard VGA Definitions
 //
-#define VGA_HORIZONTAL_RESOLUTION                         640
-#define VGA_VERTICAL_RESOLUTION                           480
-#define VGA_NUMBER_OF_BIT_PLANES                          4
-#define VGA_PIXELS_PER_BYTE                               8
-#define VGA_BYTES_PER_SCAN_LINE                           (VGA_HORIZONTAL_RESOLUTION / VGA_PIXELS_PER_BYTE)
-#define VGA_BYTES_PER_BIT_PLANE                           (VGA_VERTICAL_RESOLUTION * VGA_BYTES_PER_SCAN_LINE)
+#define VGA_HORIZONTAL_RESOLUTION  640
+#define VGA_VERTICAL_RESOLUTION    480
+#define VGA_NUMBER_OF_BIT_PLANES   4
+#define VGA_PIXELS_PER_BYTE        8
+#define VGA_BYTES_PER_SCAN_LINE    (VGA_HORIZONTAL_RESOLUTION / VGA_PIXELS_PER_BYTE)
+#define VGA_BYTES_PER_BIT_PLANE    (VGA_VERTICAL_RESOLUTION * VGA_BYTES_PER_SCAN_LINE)
 
-#define VGA_GRAPHICS_CONTROLLER_ADDRESS_REGISTER          0x3ce
-#define VGA_GRAPHICS_CONTROLLER_DATA_REGISTER             0x3cf
+#define VGA_GRAPHICS_CONTROLLER_ADDRESS_REGISTER  0x3ce
+#define VGA_GRAPHICS_CONTROLLER_DATA_REGISTER     0x3cf
 
-#define VGA_GRAPHICS_CONTROLLER_SET_RESET_REGISTER        0x00
+#define VGA_GRAPHICS_CONTROLLER_SET_RESET_REGISTER  0x00
 
-#define VGA_GRAPHICS_CONTROLLER_ENABLE_SET_RESET_REGISTER 0x01
+#define VGA_GRAPHICS_CONTROLLER_ENABLE_SET_RESET_REGISTER  0x01
 
-#define VGA_GRAPHICS_CONTROLLER_COLOR_COMPARE_REGISTER    0x02
+#define VGA_GRAPHICS_CONTROLLER_COLOR_COMPARE_REGISTER  0x02
 
-#define VGA_GRAPHICS_CONTROLLER_DATA_ROTATE_REGISTER      0x03
-#define VGA_GRAPHICS_CONTROLLER_FUNCTION_REPLACE          0x00
-#define VGA_GRAPHICS_CONTROLLER_FUNCTION_AND              0x08
-#define VGA_GRAPHICS_CONTROLLER_FUNCTION_OR               0x10
-#define VGA_GRAPHICS_CONTROLLER_FUNCTION_XOR              0x18
+#define VGA_GRAPHICS_CONTROLLER_DATA_ROTATE_REGISTER  0x03
+#define VGA_GRAPHICS_CONTROLLER_FUNCTION_REPLACE      0x00
+#define VGA_GRAPHICS_CONTROLLER_FUNCTION_AND          0x08
+#define VGA_GRAPHICS_CONTROLLER_FUNCTION_OR           0x10
+#define VGA_GRAPHICS_CONTROLLER_FUNCTION_XOR          0x18
 
 #define VGA_GRAPHICS_CONTROLLER_READ_MAP_SELECT_REGISTER  0x04
 
-#define VGA_GRAPHICS_CONTROLLER_MODE_REGISTER             0x05
-#define VGA_GRAPHICS_CONTROLLER_READ_MODE_0               0x00
-#define VGA_GRAPHICS_CONTROLLER_READ_MODE_1               0x08
-#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_0              0x00
-#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_1              0x01
-#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_2              0x02
-#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_3              0x03
+#define VGA_GRAPHICS_CONTROLLER_MODE_REGISTER  0x05
+#define VGA_GRAPHICS_CONTROLLER_READ_MODE_0    0x00
+#define VGA_GRAPHICS_CONTROLLER_READ_MODE_1    0x08
+#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_0   0x00
+#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_1   0x01
+#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_2   0x02
+#define VGA_GRAPHICS_CONTROLLER_WRITE_MODE_3   0x03
 
-#define VGA_GRAPHICS_CONTROLLER_MISCELLANEOUS_REGISTER    0x06
+#define VGA_GRAPHICS_CONTROLLER_MISCELLANEOUS_REGISTER  0x06
 
 #define VGA_GRAPHICS_CONTROLLER_COLOR_DONT_CARE_REGISTER  0x07
 
-#define VGA_GRAPHICS_CONTROLLER_BIT_MASK_REGISTER         0x08
+#define VGA_GRAPHICS_CONTROLLER_BIT_MASK_REGISTER  0x08
 
 /**
   Install child handles if the Handle supports MBR format.
@@ -500,9 +491,9 @@ BiosVideoChildHandleInstall (
 **/
 EFI_STATUS
 BiosVideoChildHandleUninstall (
-  EFI_DRIVER_BINDING_PROTOCOL    *This,
-  EFI_HANDLE                     Controller,
-  EFI_HANDLE                     Handle
+  EFI_DRIVER_BINDING_PROTOCOL  *This,
+  EFI_HANDLE                   Controller,
+  EFI_HANDLE                   Handle
   );
 
 /**
@@ -529,4 +520,5 @@ BOOLEAN
 HasChildHandle (
   IN EFI_HANDLE  Controller
   );
+
 #endif
