@@ -1,14 +1,8 @@
 /** @file
   Provides interface to advanced shell functionality for parsing both handle and protocol database.
 
-  Copyright (c) 2010 - 2013, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2010 - 2018, Intel Corporation. All rights reserved.<BR>
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -17,6 +11,27 @@
 
 #include <Uefi.h>
 
+/**
+  Function to add a new GUID/Name mapping.
+
+  This cannot overwrite an existing mapping.
+
+  @param[in] Guid       The Guid
+  @param[in] TheName    The Guid's name
+  @param[in] Lang       RFC4646 language code list or NULL
+
+  @retval EFI_SUCCESS           The operation was sucessful
+  @retval EFI_ACCESS_DENIED     There was a duplicate
+  @retval EFI_OUT_OF_RESOURCES  A memory allocation failed
+**/
+EFI_STATUS
+EFIAPI
+AddNewGuidNameMapping (
+  IN CONST EFI_GUID  *Guid,
+  IN CONST CHAR16    *TheName,
+  IN CONST CHAR8     *Lang OPTIONAL
+  );
+
 /**
   Function to get the name of a protocol or struct from it's GUID.
 
@@ -28,28 +43,30 @@
   @return                       The pointer to a string of the name.  The caller
                                 is responsible to free this memory.
 **/
-CHAR16*
+CHAR16 *
 EFIAPI
-GetStringNameFromGuid(
-  IN CONST EFI_GUID *Guid,
-  IN CONST CHAR8    *Lang OPTIONAL
+GetStringNameFromGuid (
+  IN CONST EFI_GUID  *Guid,
+  IN CONST CHAR8     *Lang OPTIONAL
   );
 
 /**
   Function to get the Guid for a protocol or struct based on it's string name.
 
+  Do not free or modify the returned GUID.
+
   @param[in] Name           The pointer to the string name.
   @param[in] Lang           The pointer to the language code (string).
-  @param[in] Guid           The pointer to the pointer to the Guid.
+  @param[out] Guid          The pointer to the pointer to the Guid.
 
   @retval EFI_SUCCESS       The operation was successful.
 **/
 EFI_STATUS
 EFIAPI
-GetGuidFromStringName(
-  IN CONST CHAR16 *Name,
-  IN CONST CHAR8  *Lang OPTIONAL,
-  IN EFI_GUID     **Guid
+GetGuidFromStringName (
+  IN CONST CHAR16  *Name,
+  IN CONST CHAR8   *Lang OPTIONAL,
+  OUT EFI_GUID     **Guid
   );
 
 /**
@@ -68,12 +85,12 @@ GetGuidFromStringName(
   @return                   The pointer to string.
   @retval NULL              An error was encountered.
 **/
-CHAR16*
+CHAR16 *
 EFIAPI
-GetProtocolInformationDump(
-  IN CONST EFI_HANDLE TheHandle,
-  IN CONST EFI_GUID   *Guid,
-  IN CONST BOOLEAN    Verbose
+GetProtocolInformationDump (
+  IN CONST EFI_HANDLE  TheHandle,
+  IN CONST EFI_GUID    *Guid,
+  IN CONST BOOLEAN     Verbose
   );
 
 /**
@@ -88,18 +105,18 @@ GetProtocolInformationDump(
   @retval NULL              The name could not be found.
   @return                   A pointer to the string name.  Do not de-allocate the memory.
 **/
-CONST CHAR16*
+CONST CHAR16 *
 EFIAPI
-GetStringNameFromHandle(
-  IN CONST EFI_HANDLE TheHandle,
-  IN CONST CHAR8      *Language
+GetStringNameFromHandle (
+  IN CONST EFI_HANDLE  TheHandle,
+  IN CONST CHAR8       *Language
   );
 
 /**
   Get best support language for this driver.
-  
-  First base on the user input language  to search, second base on the current 
-  platform used language to search, third get the first language from the 
+
+  First base on the user input language  to search, second base on the current
+  platform used language to search, third get the first language from the
   support language list. The caller need to free the buffer of the best language.
 
   @param[in] SupportedLanguages      The support languages for this driver.
@@ -116,19 +133,19 @@ GetBestLanguageForDriver (
   IN BOOLEAN      Iso639Language
   );
 
-#define HR_UNKNOWN                     0
-#define HR_IMAGE_HANDLE                BIT1
-#define HR_DRIVER_BINDING_HANDLE       BIT2 // has driver binding
-#define HR_DEVICE_DRIVER               BIT3 // device driver (hybrid?)
-#define HR_BUS_DRIVER                  BIT4 // a bus driver  (hybrid?)
-#define HR_DRIVER_CONFIGURATION_HANDLE BIT5
-#define HR_DRIVER_DIAGNOSTICS_HANDLE   BIT6
-#define HR_COMPONENT_NAME_HANDLE       BIT7
-#define HR_DEVICE_HANDLE               BIT8
-#define HR_PARENT_HANDLE               BIT9
-#define HR_CONTROLLER_HANDLE           BIT10
-#define HR_CHILD_HANDLE                BIT11
-#define HR_VALID_MASK                  (BIT1|BIT2|BIT3|BIT4|BIT5|BIT6|BIT7|BIT8|BIT9|BIT10|BIT11)
+#define HR_UNKNOWN                      0
+#define HR_IMAGE_HANDLE                 BIT1
+#define HR_DRIVER_BINDING_HANDLE        BIT2 // has driver binding
+#define HR_DEVICE_DRIVER                BIT3 // device driver (hybrid?)
+#define HR_BUS_DRIVER                   BIT4 // a bus driver  (hybrid?)
+#define HR_DRIVER_CONFIGURATION_HANDLE  BIT5
+#define HR_DRIVER_DIAGNOSTICS_HANDLE    BIT6
+#define HR_COMPONENT_NAME_HANDLE        BIT7
+#define HR_DEVICE_HANDLE                BIT8
+#define HR_PARENT_HANDLE                BIT9
+#define HR_CONTROLLER_HANDLE            BIT10
+#define HR_CHILD_HANDLE                 BIT11
+#define HR_VALID_MASK                   (BIT1|BIT2|BIT3|BIT4|BIT5|BIT6|BIT7|BIT8|BIT9|BIT10|BIT11)
 
 /**
   Gets all the related EFI_HANDLEs based on the mask supplied.
@@ -160,11 +177,11 @@ GetBestLanguageForDriver (
 EFI_STATUS
 EFIAPI
 ParseHandleDatabaseByRelationship (
-  IN CONST EFI_HANDLE       DriverBindingHandle OPTIONAL,
-  IN CONST EFI_HANDLE       ControllerHandle OPTIONAL,
-  IN CONST UINTN            Mask,
-  IN UINTN                  *MatchingHandleCount,
-  OUT EFI_HANDLE            **MatchingHandleBuffer OPTIONAL
+  IN CONST EFI_HANDLE  DriverBindingHandle OPTIONAL,
+  IN CONST EFI_HANDLE  ControllerHandle OPTIONAL,
+  IN CONST UINTN       Mask,
+  IN UINTN             *MatchingHandleCount,
+  OUT EFI_HANDLE       **MatchingHandleBuffer OPTIONAL
   );
 
 /**
@@ -196,11 +213,11 @@ ParseHandleDatabaseByRelationship (
 EFI_STATUS
 EFIAPI
 ParseHandleDatabaseByRelationshipWithType (
-  IN CONST EFI_HANDLE DriverBindingHandle OPTIONAL,
-  IN CONST EFI_HANDLE ControllerHandle OPTIONAL,
-  IN UINTN            *HandleCount,
-  OUT EFI_HANDLE      **HandleBuffer,
-  OUT UINTN           **HandleType
+  IN CONST EFI_HANDLE  DriverBindingHandle OPTIONAL,
+  IN CONST EFI_HANDLE  ControllerHandle OPTIONAL,
+  IN UINTN             *HandleCount,
+  OUT EFI_HANDLE       **HandleBuffer,
+  OUT UINTN            **HandleType
   );
 
 /**
@@ -273,17 +290,17 @@ ParseHandleDatabaseByRelationshipWithType (
 **/
 EFI_STATUS
 EFIAPI
-ParseHandleDatabaseForChildDevices(
-  IN CONST EFI_HANDLE       DriverHandle,
-  IN UINTN                  *MatchingHandleCount,
-  OUT EFI_HANDLE            **MatchingHandleBuffer OPTIONAL
+ParseHandleDatabaseForChildDevices (
+  IN CONST EFI_HANDLE  DriverHandle,
+  IN UINTN             *MatchingHandleCount,
+  OUT EFI_HANDLE       **MatchingHandleBuffer OPTIONAL
   );
 
 /**
   Gets handles for any child controllers of the passed in controller.
 
   @param[in] ControllerHandle       The handle of the "parent controller".
-  @param[in] MatchingHandleCount    The pointer to the number of handles in
+  @param[out] MatchingHandleCount   The pointer to the number of handles in
                                     MatchingHandleBuffer on return.
   @param[out] MatchingHandleBuffer  The buffer containing handles on a successful
                                     return.
@@ -292,13 +309,12 @@ ParseHandleDatabaseForChildDevices(
 **/
 EFI_STATUS
 EFIAPI
-ParseHandleDatabaseForChildControllers(
-  IN CONST EFI_HANDLE       ControllerHandle,
-  IN UINTN                  *MatchingHandleCount,
-  OUT EFI_HANDLE            **MatchingHandleBuffer OPTIONAL
+ParseHandleDatabaseForChildControllers (
+  IN CONST EFI_HANDLE  ControllerHandle,
+  OUT UINTN            *MatchingHandleCount,
+  OUT EFI_HANDLE       **MatchingHandleBuffer OPTIONAL
   );
 
-
 /**
   Function to retrieve the human-friendly index of a given handle.  If the handle
   does not have a index one will be automatically assigned.  The index value is valid
@@ -312,8 +328,8 @@ ParseHandleDatabaseForChildControllers(
 **/
 UINTN
 EFIAPI
-ConvertHandleToHandleIndex(
-  IN CONST EFI_HANDLE TheHandle
+ConvertHandleToHandleIndex (
+  IN CONST EFI_HANDLE  TheHandle
   );
 
 /**
@@ -327,38 +343,60 @@ ConvertHandleToHandleIndex(
 **/
 EFI_HANDLE
 EFIAPI
-ConvertHandleIndexToHandle(
-  IN CONST UINTN TheIndex
+ConvertHandleIndexToHandle (
+  IN CONST UINTN  TheIndex
   );
 
 /**
   Function to get all handles that support a given protocol or all handles.
 
+  The caller is responsible to free this memory.
+
   @param[in] ProtocolGuid The guid of the protocol to get handles for.  If NULL
                           then the function will return all handles.
 
   @retval NULL            A memory allocation failed.
   @return                 A NULL terminated list of handles.
 **/
-EFI_HANDLE*
+EFI_HANDLE *
 EFIAPI
 GetHandleListByProtocol (
-  IN CONST EFI_GUID *ProtocolGuid OPTIONAL
+  IN CONST EFI_GUID  *ProtocolGuid OPTIONAL
   );
 
 /**
   Function to get all handles that support some protocols.
 
+  The caller is responsible to free this memory.
+
   @param[in] ProtocolGuids  A NULL terminated list of protocol GUIDs.
 
   @retval NULL              A memory allocation failed.
   @retval NULL              ProtocolGuids was NULL.
   @return                   A NULL terminated list of EFI_HANDLEs.
 **/
-EFI_HANDLE*
+EFI_HANDLE *
 EFIAPI
 GetHandleListByProtocolList (
-  IN CONST EFI_GUID **ProtocolGuids
+  IN CONST EFI_GUID  **ProtocolGuids
+  );
+
+/**
+  Return all supported GUIDs.
+
+  @param[out]      Guids  The buffer to return all supported GUIDs.
+  @param[in, out]  Count  On input, the count of GUIDs the buffer can hold,
+                         On output, the count of GUIDs to return.
+
+  @retval EFI_INVALID_PARAMETER Count is NULL.
+  @retval EFI_BUFFER_TOO_SMALL  Buffer is not enough to hold all GUIDs.
+  @retval EFI_SUCCESS           GUIDs are returned successfully.
+**/
+EFI_STATUS
+EFIAPI
+GetAllMappingGuids (
+  OUT EFI_GUID  *Guids,
+  IN OUT UINTN  *Count
   );
 
 #endif // __HANDLE_PARSING_LIB__
