@@ -1,14 +1,8 @@
 /** @file
   Header file for ACPI parser
 
-  Copyright (c) 2016 - 2018, ARM Limited. All rights reserved.
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2016 - 2020, Arm Limited. All rights reserved.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 **/
 
 #ifndef ACPIPARSER_H_
@@ -56,9 +50,9 @@ IncrementWarningCount (
 BOOLEAN
 EFIAPI
 VerifyChecksum (
-  IN BOOLEAN Log,
-  IN UINT8*  Ptr,
-  IN UINT32  Length
+  IN BOOLEAN  Log,
+  IN UINT8    *Ptr,
+  IN UINT32   Length
   );
 
 /**
@@ -70,8 +64,8 @@ VerifyChecksum (
 VOID
 EFIAPI
 DumpRaw (
-  IN UINT8* Ptr,
-  IN UINT32 Length
+  IN UINT8   *Ptr,
+  IN UINT32  Length
   );
 
 /**
@@ -83,8 +77,8 @@ DumpRaw (
 VOID
 EFIAPI
 DumpUint8 (
-  IN CONST CHAR16* Format,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -96,8 +90,8 @@ DumpUint8 (
 VOID
 EFIAPI
 DumpUint16 (
-  IN CONST CHAR16* Format,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -109,8 +103,8 @@ DumpUint16 (
 VOID
 EFIAPI
 DumpUint32 (
-  IN CONST CHAR16* Format,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -122,8 +116,8 @@ DumpUint32 (
 VOID
 EFIAPI
 DumpUint64 (
-  IN CONST CHAR16* Format,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -138,8 +132,8 @@ DumpUint64 (
 VOID
 EFIAPI
 Dump3Chars (
-  IN CONST CHAR16* Format OPTIONAL,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -154,8 +148,8 @@ Dump3Chars (
 VOID
 EFIAPI
 Dump4Chars (
-  IN CONST CHAR16* Format OPTIONAL,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -170,8 +164,8 @@ Dump4Chars (
 VOID
 EFIAPI
 Dump6Chars (
-  IN CONST CHAR16* Format OPTIONAL,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -186,8 +180,24 @@ Dump6Chars (
 VOID
 EFIAPI
 Dump8Chars (
-  IN CONST CHAR16* Format OPTIONAL,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN UINT8         *Ptr
+  );
+
+/**
+  This function traces 12 characters which can be optionally
+  formated using the format string if specified.
+
+  If no format string is specified the Format must be NULL.
+
+  @param [in] Format  Optional format string for tracing the data.
+  @param [in] Ptr     Pointer to the start of the buffer.
+**/
+VOID
+EFIAPI
+Dump12Chars (
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN       UINT8   *Ptr
   );
 
 /**
@@ -205,8 +215,8 @@ Dump8Chars (
 VOID
 EFIAPI
 PrintFieldName (
-  IN UINT32         Indent,
-  IN CONST CHAR16*  FieldName
+  IN UINT32        Indent,
+  IN CONST CHAR16  *FieldName
   );
 
 /**
@@ -216,7 +226,7 @@ PrintFieldName (
                       the 'Format' member of ACPI_PARSER.
   @param [in] Ptr     Pointer to the start of the buffer.
 **/
-typedef VOID (EFIAPI *FNPTR_PRINT_FORMATTER)(CONST CHAR16* Format, UINT8* Ptr);
+typedef VOID (EFIAPI *FNPTR_PRINT_FORMATTER)(CONST CHAR16 *Format, UINT8 *Ptr);
 
 /**
   This function pointer is the template for validating an ACPI table field.
@@ -226,7 +236,7 @@ typedef VOID (EFIAPI *FNPTR_PRINT_FORMATTER)(CONST CHAR16* Format, UINT8* Ptr);
                       the 'Context' member of the ACPI_PARSER.
                       e.g. this could be a pointer to the ACPI table header.
 **/
-typedef VOID (EFIAPI *FNPTR_FIELD_VALIDATOR)(UINT8* Ptr, VOID* Context);
+typedef VOID (EFIAPI *FNPTR_FIELD_VALIDATOR)(UINT8 *Ptr, VOID *Context);
 
 /**
   The ACPI_PARSER structure describes the fields of an ACPI table and
@@ -248,46 +258,47 @@ typedef VOID (EFIAPI *FNPTR_FIELD_VALIDATOR)(UINT8* Ptr, VOID* Context);
   representing the field data.
 **/
 typedef struct AcpiParser {
-
   /// String describing the ACPI table field
   /// (Field column from ACPI table spec)
-  CONST CHAR16*         NameStr;
+  CONST CHAR16             *NameStr;
 
   /// The length of the field.
   /// (Byte Length column from ACPI table spec)
-  UINT32                Length;
+  UINT32                   Length;
 
   /// The offset of the field from the start of the table.
   /// (Byte Offset column from ACPI table spec)
-  UINT32                Offset;
+  UINT32                   Offset;
 
   /// Optional Print() style format string for tracing the data. If not
   /// used this must be set to NULL.
-  CONST CHAR16*         Format;
+  CONST CHAR16             *Format;
 
   /// Optional pointer to a print formatter function which
   /// is typically used to trace complex field information.
   /// If not used this must be set to NULL.
   /// The Format string is passed to the PrintFormatter function
   /// but may be ignored by the implementation code.
-  FNPTR_PRINT_FORMATTER PrintFormatter;
+  FNPTR_PRINT_FORMATTER    PrintFormatter;
 
   /// Optional pointer which may be set to request the parser to update
-  /// a pointer to the field data. If unused this must be set to NULL.
-  VOID**                ItemPtr;
+  /// a pointer to the field data. This value is set after the FieldValidator
+  /// has been called and therefore should not be used by the FieldValidator.
+  /// If unused this must be set to NULL.
+  VOID                     **ItemPtr;
 
   /// Optional pointer to a field validator function.
   /// The function should directly report any appropriate error or warning
   /// and invoke the appropriate counter update function.
   /// If not used this parameter must be set to NULL.
-  FNPTR_FIELD_VALIDATOR FieldValidator;
+  FNPTR_FIELD_VALIDATOR    FieldValidator;
 
   /// Optional pointer to context specific information,
   /// which the Field Validator function can use to determine
   /// additional information about the ACPI table and make
   /// decisions about the field being validated.
   /// e.g. this could be a pointer to the ACPI table header
-  VOID*                 Context;
+  VOID                     *Context;
 } ACPI_PARSER;
 
 /**
@@ -296,23 +307,23 @@ typedef struct AcpiParser {
 **/
 typedef struct AcpiDescriptionHeaderInfo {
   /// ACPI table signature
-  UINT32* Signature;
+  UINT32    *Signature;
   /// Length of the ACPI table
-  UINT32* Length;
+  UINT32    *Length;
   /// Revision
-  UINT8*  Revision;
+  UINT8     *Revision;
   /// Checksum
-  UINT8*  Checksum;
+  UINT8     *Checksum;
   /// OEM Id - length is 6 bytes
-  UINT8*  OemId;
+  UINT8     *OemId;
   /// OEM table Id
-  UINT64* OemTableId;
+  UINT64    *OemTableId;
   /// OEM revision Id
-  UINT32* OemRevision;
+  UINT32    *OemRevision;
   /// Creator Id
-  UINT32* CreatorId;
+  UINT32    *CreatorId;
   /// Creator revision
-  UINT32* CreatorRevision;
+  UINT32    *CreatorRevision;
 } ACPI_DESCRIPTION_HEADER_INFO;
 
 /**
@@ -346,10 +357,10 @@ EFIAPI
 ParseAcpi (
   IN BOOLEAN            Trace,
   IN UINT32             Indent,
-  IN CONST CHAR8*       AsciiName OPTIONAL,
-  IN UINT8*             Ptr,
+  IN CONST CHAR8        *AsciiName OPTIONAL,
+  IN UINT8              *Ptr,
   IN UINT32             Length,
-  IN CONST ACPI_PARSER* Parser,
+  IN CONST ACPI_PARSER  *Parser,
   IN UINT32             ParserItems
   );
 
@@ -359,7 +370,7 @@ ParseAcpi (
   @param [in] Parser The name of the ACPI_PARSER array describing the
               ACPI table fields.
 **/
-#define PARSER_PARAMS(Parser) Parser, sizeof (Parser) / sizeof (Parser[0])
+#define PARSER_PARAMS(Parser)  Parser, sizeof (Parser) / sizeof (Parser[0])
 
 /**
   This is a helper macro for describing the ACPI header fields.
@@ -386,37 +397,21 @@ ParseAcpi (
   { L"Creator Revision", 4, 32, L"0x%X", NULL,    \
     (VOID**)&(Info)->CreatorRevision, NULL, NULL }
 
-/**
-  Length of the ACPI GAS structure.
-
-  NOTE: This might normally be defined as
-        sizeof (EFI_ACPI_6_2_GENERIC_ADDRESS_STRUCTURE).
-        However, we deliberately minimise any reference to the EDK2 ACPI
-        headers in an attempt to provide cross checking.
-**/
-#define GAS_LENGTH                     12
-
-/**
-  Length of the ACPI Header structure.
-
-  NOTE: This might normally be defined as
-        sizeof (EFI_ACPI_DESCRIPTION_HEADER).
-        However, we deliberately minimise any reference to the EDK2 ACPI
-        headers in an attempt to provide cross checking.
-**/
-#define ACPI_DESCRIPTION_HEADER_LENGTH  36
-
 /**
   This function indents and traces the GAS structure as described by the GasParser.
 
   @param [in] Ptr     Pointer to the start of the buffer.
   @param [in] Indent  Number of spaces to indent the output.
+  @param [in] Length  Length of the GAS structure buffer.
+
+  @retval Number of bytes parsed.
 **/
-VOID
+UINT32
 EFIAPI
 DumpGasStruct (
-  IN UINT8*        Ptr,
-  IN UINT32        Indent
+  IN UINT8   *Ptr,
+  IN UINT32  Indent,
+  IN UINT32  Length
   );
 
 /**
@@ -428,8 +423,8 @@ DumpGasStruct (
 VOID
 EFIAPI
 DumpGas (
-  IN CONST CHAR16* Format OPTIONAL,
-  IN UINT8*        Ptr
+  IN CONST CHAR16  *Format OPTIONAL,
+  IN UINT8         *Ptr
   );
 
 /**
@@ -442,7 +437,7 @@ DumpGas (
 UINT32
 EFIAPI
 DumpAcpiHeader (
-  IN UINT8* Ptr
+  IN UINT8  *Ptr
   );
 
 /**
@@ -461,10 +456,31 @@ DumpAcpiHeader (
 UINT32
 EFIAPI
 ParseAcpiHeader (
-  IN  UINT8*         Ptr,
-  OUT CONST UINT32** Signature,
-  OUT CONST UINT32** Length,
-  OUT CONST UINT8**  Revision
+  IN  UINT8         *Ptr,
+  OUT CONST UINT32  **Signature,
+  OUT CONST UINT32  **Length,
+  OUT CONST UINT8   **Revision
+  );
+
+/**
+  This function parses the ACPI AEST table.
+  When trace is enabled this function parses the AEST table and
+  traces the ACPI table fields.
+
+  This function also performs validation of the ACPI table fields.
+
+  @param [in] Trace              If TRUE, trace the ACPI fields.
+  @param [in] Ptr                Pointer to the start of the buffer.
+  @param [in] AcpiTableLength    Length of the ACPI table.
+  @param [in] AcpiTableRevision  Revision of the ACPI table.
+**/
+VOID
+EFIAPI
+ParseAcpiAest (
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -482,10 +498,10 @@ ParseAcpiHeader (
 VOID
 EFIAPI
 ParseAcpiBgrt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -503,10 +519,10 @@ ParseAcpiBgrt (
 VOID
 EFIAPI
 ParseAcpiDbg2 (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -524,10 +540,31 @@ ParseAcpiDbg2 (
 VOID
 EFIAPI
 ParseAcpiDsdt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
+  );
+
+/**
+  This function parses the ACPI FACS table.
+  When trace is enabled this function parses the FACS table and
+  traces the ACPI table fields.
+
+  This function also performs validation of the ACPI table fields.
+
+  @param [in] Trace              If TRUE, trace the ACPI fields.
+  @param [in] Ptr                Pointer to the start of the buffer.
+  @param [in] AcpiTableLength    Length of the ACPI table.
+  @param [in] AcpiTableRevision  Revision of the ACPI table.
+**/
+VOID
+EFIAPI
+ParseAcpiFacs (
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -545,10 +582,10 @@ ParseAcpiDsdt (
 VOID
 EFIAPI
 ParseAcpiFadt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -570,10 +607,36 @@ ParseAcpiFadt (
 VOID
 EFIAPI
 ParseAcpiGtdt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
+  );
+
+/**
+  This function parses the ACPI HMAT table.
+  When trace is enabled this function parses the HMAT table and
+  traces the ACPI table fields.
+
+  This function parses the following HMAT structures:
+    - Memory Proximity Domain Attributes Structure (Type 0)
+    - System Locality Latency and Bandwidth Info Structure (Type 1)
+    - Memory Side Cache Info structure (Type 2)
+
+  This function also performs validation of the ACPI table fields.
+
+  @param [in] Trace              If TRUE, trace the ACPI fields.
+  @param [in] Ptr                Pointer to the start of the buffer.
+  @param [in] AcpiTableLength    Length of the ACPI table.
+  @param [in] AcpiTableRevision  Revision of the ACPI table.
+**/
+VOID
+EFIAPI
+ParseAcpiHmat (
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -599,10 +662,10 @@ ParseAcpiGtdt (
 VOID
 EFIAPI
 ParseAcpiIort (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -628,10 +691,10 @@ ParseAcpiIort (
 VOID
 EFIAPI
 ParseAcpiMadt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -649,10 +712,53 @@ ParseAcpiMadt (
 VOID
 EFIAPI
 ParseAcpiMcfg (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
+  );
+
+/**
+  This function parses the ACPI PCCT table including its sub-structures
+  of type 0 through 4.
+  When trace is enabled this function parses the PCCT table and
+  traces the ACPI table fields.
+
+  This function also performs validation of the ACPI table fields.
+
+  @param [in] Trace              If TRUE, trace the ACPI fields.
+  @param [in] Ptr                Pointer to the start of the buffer.
+  @param [in] AcpiTableLength    Length of the ACPI table.
+  @param [in] AcpiTableRevision  Revision of the ACPI table.
+**/
+VOID
+EFIAPI
+ParseAcpiPcct (
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
+  );
+
+/**
+  This function parses the ACPI PPTT table.
+  When trace is enabled this function parses the PPTT table and
+  traces the ACPI table fields.
+
+  This function also performs validation of the ACPI table fields.
+
+  @param [in] Trace              If TRUE, trace the ACPI fields.
+  @param [in] Ptr                Pointer to the start of the buffer.
+  @param [in] AcpiTableLength    Length of the ACPI table.
+  @param [in] AcpiTableRevision  Revision of the ACPI table.
+**/
+VOID
+EFIAPI
+ParseAcpiPptt (
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -672,10 +778,10 @@ ParseAcpiMcfg (
 VOID
 EFIAPI
 ParseAcpiRsdp (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -696,10 +802,10 @@ ParseAcpiRsdp (
 VOID
 EFIAPI
 ParseAcpiSlit (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -717,10 +823,10 @@ ParseAcpiSlit (
 VOID
 EFIAPI
 ParseAcpiSpcr (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -744,10 +850,10 @@ ParseAcpiSpcr (
 VOID
 EFIAPI
 ParseAcpiSrat (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -765,10 +871,10 @@ ParseAcpiSrat (
 VOID
 EFIAPI
 ParseAcpiSsdt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 /**
@@ -785,10 +891,10 @@ ParseAcpiSsdt (
 VOID
 EFIAPI
 ParseAcpiXsdt (
-  IN BOOLEAN Trace,
-  IN UINT8*  Ptr,
-  IN UINT32  AcpiTableLength,
-  IN UINT8   AcpiTableRevision
+  IN BOOLEAN  Trace,
+  IN UINT8    *Ptr,
+  IN UINT32   AcpiTableLength,
+  IN UINT8    AcpiTableRevision
   );
 
 #endif // ACPIPARSER_H_
