@@ -2,25 +2,21 @@
   Build a table, each item is (key, info) pair.
   and give a interface of query a string out of a table.
 
-  Copyright (c) 2005 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2005 - 2019, Intel Corporation. All rights reserved.<BR>
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
 #ifndef _SMBIOS_QUERY_TABLE_H_
 #define _SMBIOS_QUERY_TABLE_H_
 
-#define QUERY_TABLE_UNFOUND 0xFF
+#include <IndustryStandard/SmBios.h>
+
+#define QUERY_TABLE_UNFOUND  0xFF
 
 typedef struct TABLE_ITEM {
-  UINT16  Key;
-  CHAR16  *Info;
+  UINT16    Key;
+  CHAR16    *Info;
 } TABLE_ITEM;
 
 //
@@ -63,11 +59,11 @@ typedef struct TABLE_ITEM {
 **/
 UINT8
 QueryTable (
-  IN  TABLE_ITEM    *Table,
-  IN  UINTN         Number,
-  IN  UINT8         Key,
-  IN  OUT CHAR16    *Info,
-  IN  UINTN         InfoLen
+  IN  TABLE_ITEM  *Table,
+  IN  UINTN       Number,
+  IN  UINT8       Key,
+  IN  OUT CHAR16  *Info,
+  IN  UINTN       InfoLen
   );
 
 /**
@@ -78,8 +74,8 @@ QueryTable (
 **/
 VOID
 DisplayStructureTypeInfo (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -90,8 +86,8 @@ DisplayStructureTypeInfo (
 **/
 VOID
 DisplaySystemWakeupType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -102,8 +98,8 @@ DisplaySystemWakeupType (
 **/
 VOID
 DisplayBaseBoardFeatureFlags (
-  IN UINT8 FeatureFlags,
-  IN UINT8 Option
+  IN UINT8  FeatureFlags,
+  IN UINT8  Option
   );
 
 /**
@@ -113,9 +109,9 @@ DisplayBaseBoardFeatureFlags (
   @param[in] Option         The optional information.
 **/
 VOID
-DisplayBaseBoardBoardType(
-  IN UINT8 Type,
-  IN UINT8 Option
+DisplayBaseBoardBoardType (
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -126,8 +122,8 @@ DisplayBaseBoardBoardType(
 **/
 VOID
 DisplaySystemEnclosureType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -138,8 +134,8 @@ DisplaySystemEnclosureType (
 **/
 VOID
 DisplaySystemEnclosureStatus (
-  IN UINT8 Status,
-  IN UINT8 Option
+  IN UINT8  Status,
+  IN UINT8  Option
   );
 
 /**
@@ -150,8 +146,8 @@ DisplaySystemEnclosureStatus (
 **/
 VOID
 DisplaySESecurityStatus (
-  IN UINT8 Status,
-  IN UINT8 Option
+  IN UINT8  Status,
+  IN UINT8  Option
   )
 ;
 
@@ -163,8 +159,8 @@ DisplaySESecurityStatus (
 **/
 VOID
 DisplayProcessorType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -175,8 +171,8 @@ DisplayProcessorType (
 **/
 VOID
 DisplayProcessorUpgrade (
-  IN UINT8 Upgrade,
-  IN UINT8 Option
+  IN UINT8  Upgrade,
+  IN UINT8  Option
   );
 
 /**
@@ -187,8 +183,8 @@ DisplayProcessorUpgrade (
 **/
 VOID
 DisplayProcessorCharacteristics (
-  IN UINT16 Type,
-  IN UINT8 Option
+  IN UINT16  Type,
+  IN UINT8   Option
   );
 
 /**
@@ -199,8 +195,8 @@ DisplayProcessorCharacteristics (
 **/
 VOID
 DisplayMcErrorDetectMethod (
-  IN UINT8 Method,
-  IN UINT8 Option
+  IN UINT8  Method,
+  IN UINT8  Option
   );
 
 /**
@@ -211,8 +207,8 @@ DisplayMcErrorDetectMethod (
 **/
 VOID
 DisplayMcErrorCorrectCapability (
-  IN UINT8 Capability,
-  IN UINT8 Option
+  IN UINT8  Capability,
+  IN UINT8  Option
   );
 
 /**
@@ -223,8 +219,8 @@ DisplayMcErrorCorrectCapability (
 **/
 VOID
 DisplayMcInterleaveSupport (
-  IN UINT8 Support,
-  IN UINT8 Option
+  IN UINT8  Support,
+  IN UINT8  Option
   );
 
 /**
@@ -247,8 +243,8 @@ DisplayMcMemorySpeeds (
 **/
 VOID
 DisplayMemoryModuleVoltage (
-  IN UINT8 Voltage,
-  IN UINT8 Option
+  IN UINT8  Voltage,
+  IN UINT8  Option
   );
 
 /**
@@ -271,8 +267,8 @@ DisplayMmMemoryType (
 **/
 VOID
 DisplayMmErrorStatus (
-  IN UINT8 Status,
-  IN UINT8 Option
+  IN UINT8  Status,
+  IN UINT8  Option
   );
 
 /**
@@ -295,8 +291,8 @@ DisplayCacheSRAMType (
 **/
 VOID
 DisplayCacheErrCorrectingType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -307,8 +303,8 @@ DisplayCacheErrCorrectingType (
 **/
 VOID
 DisplayCacheSystemCacheType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -319,8 +315,8 @@ DisplayCacheSystemCacheType (
 **/
 VOID
 DisplayCacheAssociativity (
-  IN UINT8 Associativity,
-  IN UINT8 Option
+  IN UINT8  Associativity,
+  IN UINT8  Option
   );
 
 /**
@@ -331,8 +327,8 @@ DisplayCacheAssociativity (
 **/
 VOID
 DisplayPortConnectorType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -343,8 +339,8 @@ DisplayPortConnectorType (
 **/
 VOID
 DisplayPortType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -355,8 +351,8 @@ DisplayPortType (
 **/
 VOID
 DisplaySystemSlotType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -367,8 +363,8 @@ DisplaySystemSlotType (
 **/
 VOID
 DisplaySystemSlotDataBusWidth (
-  IN UINT8 Width,
-  IN UINT8 Option
+  IN UINT8  Width,
+  IN UINT8  Option
   );
 
 /**
@@ -379,8 +375,8 @@ DisplaySystemSlotDataBusWidth (
 **/
 VOID
 DisplaySystemSlotCurrentUsage (
-  IN UINT8 Usage,
-  IN UINT8 Option
+  IN UINT8  Usage,
+  IN UINT8  Option
   );
 
 /**
@@ -391,8 +387,8 @@ DisplaySystemSlotCurrentUsage (
 **/
 VOID
 DisplaySystemSlotLength (
-  IN UINT8 Length,
-  IN UINT8 Option
+  IN UINT8  Length,
+  IN UINT8  Option
   );
 
 /**
@@ -403,8 +399,8 @@ DisplaySystemSlotLength (
 **/
 VOID
 DisplaySlotCharacteristics1 (
-  IN UINT8 Chara1,
-  IN UINT8 Option
+  IN UINT8  Chara1,
+  IN UINT8  Option
   );
 
 /**
@@ -415,8 +411,8 @@ DisplaySlotCharacteristics1 (
 **/
 VOID
 DisplaySlotCharacteristics2 (
-  IN UINT8 Chara2,
-  IN UINT8 Option
+  IN UINT8  Chara2,
+  IN UINT8  Option
   );
 
 /**
@@ -427,8 +423,8 @@ DisplaySlotCharacteristics2 (
 **/
 VOID
 DisplayOnboardDeviceTypes (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -439,8 +435,8 @@ DisplayOnboardDeviceTypes (
 **/
 VOID
 DisplaySELTypes (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -451,8 +447,8 @@ DisplaySELTypes (
 **/
 VOID
 DisplaySELVarDataFormatType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -499,8 +495,8 @@ DisplaySELSysManagementTypes (
 **/
 VOID
 DisplayPMALocation (
-  IN UINT8 Location,
-  IN UINT8 Option
+  IN UINT8  Location,
+  IN UINT8  Option
   );
 
 /**
@@ -511,8 +507,8 @@ DisplayPMALocation (
 **/
 VOID
 DisplayPMAUse (
-  IN UINT8 Use,
-  IN UINT8 Option
+  IN UINT8  Use,
+  IN UINT8  Option
   );
 
 /**
@@ -523,8 +519,8 @@ DisplayPMAUse (
 **/
 VOID
 DisplayPMAErrorCorrectionTypes (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -535,8 +531,8 @@ DisplayPMAErrorCorrectionTypes (
 **/
 VOID
 DisplayMemoryDeviceFormFactor (
-  IN UINT8 FormFactor,
-  IN UINT8 Option
+  IN UINT8  FormFactor,
+  IN UINT8  Option
   );
 
 /**
@@ -547,8 +543,8 @@ DisplayMemoryDeviceFormFactor (
 **/
 VOID
 DisplayMemoryDeviceType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -595,8 +591,8 @@ DisplayMemoryDeviceMemoryOperatingModeCapability (
 **/
 VOID
 DisplayMemoryErrorType (
-  IN UINT8 ErrorType,
-  IN UINT8 Option
+  IN UINT8  ErrorType,
+  IN UINT8  Option
   );
 
 /**
@@ -607,8 +603,8 @@ DisplayMemoryErrorType (
 **/
 VOID
 DisplayMemoryErrorGranularity (
-  IN UINT8 Granularity,
-  IN UINT8 Option
+  IN UINT8  Granularity,
+  IN UINT8  Option
   );
 
 /**
@@ -619,8 +615,8 @@ DisplayMemoryErrorGranularity (
 **/
 VOID
 DisplayMemoryErrorOperation (
-  IN UINT8 Operation,
-  IN UINT8 Option
+  IN UINT8  Operation,
+  IN UINT8  Option
   );
 
 /**
@@ -631,8 +627,8 @@ DisplayMemoryErrorOperation (
 **/
 VOID
 DisplayPointingDeviceType (
-  IN UINT8 Type,
-  IN UINT8 Option
+  IN UINT8  Type,
+  IN UINT8  Option
   );
 
 /**
@@ -643,8 +639,8 @@ DisplayPointingDeviceType (
 **/
 VOID
 DisplayPointingDeviceInterface (
-  IN UINT8   Interface,
-  IN UINT8   Option
+  IN UINT8  Interface,
+  IN UINT8  Option
   );
 
 /**
@@ -655,8 +651,8 @@ DisplayPointingDeviceInterface (
 **/
 VOID
 DisplayPBDeviceChemistry (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -667,8 +663,8 @@ DisplayPBDeviceChemistry (
 **/
 VOID
 DisplayVPLocation (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -679,8 +675,8 @@ DisplayVPLocation (
 **/
 VOID
 DisplayVPStatus (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -691,8 +687,8 @@ DisplayVPStatus (
 **/
 VOID
 DisplayCoolingDeviceStatus (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -703,8 +699,8 @@ DisplayCoolingDeviceStatus (
 **/
 VOID
 DisplayCoolingDeviceType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -715,8 +711,8 @@ DisplayCoolingDeviceType (
 **/
 VOID
 DisplayTemperatureProbeStatus (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -727,8 +723,8 @@ DisplayTemperatureProbeStatus (
 **/
 VOID
 DisplayTemperatureProbeLoc (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -739,8 +735,8 @@ DisplayTemperatureProbeLoc (
 **/
 VOID
 DisplayECPStatus (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -751,8 +747,8 @@ DisplayECPStatus (
 **/
 VOID
 DisplayECPLoc (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -763,8 +759,8 @@ DisplayECPLoc (
 **/
 VOID
 DisplayMDType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -775,8 +771,8 @@ DisplayMDType (
 **/
 VOID
 DisplayMDAddressType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -787,8 +783,8 @@ DisplayMDAddressType (
 **/
 VOID
 DisplayMemoryChannelType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -799,8 +795,8 @@ DisplayMemoryChannelType (
 **/
 VOID
 DisplayIPMIDIBMCInterfaceType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 /**
@@ -811,8 +807,8 @@ DisplayIPMIDIBMCInterfaceType (
 **/
 VOID
 DisplayMCHostInterfaceType (
-  IN UINT8 Key,
-  IN UINT8 Option
+  IN UINT8  Key,
+  IN UINT8  Option
   );
 
 #endif
