@@ -2,13 +2,7 @@
   CPU exception handler library implementation for PEIM module.
 
 Copyright (c) 2016 - 2018, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials are licensed and made available under
-the terms and conditions of the BSD License that accompanies this distribution.
-The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php.
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -19,11 +13,11 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 #include <Library/MemoryAllocationLib.h>
 #include <Library/PcdLib.h>
 
-CONST UINTN    mDoFarReturnFlag  = 0;
+CONST UINTN  mDoFarReturnFlag = 0;
 
 typedef struct {
-  UINT8                   ExceptionStubHeader[HOOKAFTER_STUB_SIZE];
-  EXCEPTION_HANDLER_DATA  *ExceptionHandlerData;
+  UINT8                     ExceptionStubHeader[HOOKAFTER_STUB_SIZE];
+  EXCEPTION_HANDLER_DATA    *ExceptionHandlerData;
 } EXCEPTION0_STUB_HEADER;
 
 /**
@@ -40,9 +34,9 @@ GetExceptionHandlerData (
   VOID
   )
 {
-  IA32_DESCRIPTOR                  IdtDescriptor;
-  IA32_IDT_GATE_DESCRIPTOR         *IdtTable;
-  EXCEPTION0_STUB_HEADER           *Exception0StubHeader;
+  IA32_DESCRIPTOR           IdtDescriptor;
+  IA32_IDT_GATE_DESCRIPTOR  *IdtTable;
+  EXCEPTION0_STUB_HEADER    *Exception0StubHeader;
 
   AsmReadIdtr (&IdtDescriptor);
   IdtTable = (IA32_IDT_GATE_DESCRIPTOR *)IdtDescriptor.Base;
@@ -62,12 +56,13 @@ GetExceptionHandlerData (
 **/
 VOID
 SetExceptionHandlerData (
-  IN EXCEPTION_HANDLER_DATA        *ExceptionHandlerData
+  IN EXCEPTION_HANDLER_DATA  *ExceptionHandlerData
   )
 {
-  EXCEPTION0_STUB_HEADER           *Exception0StubHeader;
-  IA32_DESCRIPTOR                  IdtDescriptor;
-  IA32_IDT_GATE_DESCRIPTOR         *IdtTable;
+  EXCEPTION0_STUB_HEADER    *Exception0StubHeader;
+  IA32_DESCRIPTOR           IdtDescriptor;
+  IA32_IDT_GATE_DESCRIPTOR  *IdtTable;
+
   //
   // Duplicate the exception #0 stub header in pool and cache the ExceptionHandlerData just after the stub header.
   // So AP can get the ExceptionHandlerData by reading the IDT[0].
@@ -95,8 +90,8 @@ SetExceptionHandlerData (
 VOID
 EFIAPI
 CommonExceptionHandler (
-  IN EFI_EXCEPTION_TYPE   ExceptionType,
-  IN EFI_SYSTEM_CONTEXT   SystemContext
+  IN EFI_EXCEPTION_TYPE  ExceptionType,
+  IN EFI_SYSTEM_CONTEXT  SystemContext
   )
 {
   EXCEPTION_HANDLER_DATA  *ExceptionHandlerData;
@@ -126,12 +121,12 @@ CommonExceptionHandler (
 EFI_STATUS
 EFIAPI
 InitializeCpuExceptionHandlers (
-  IN EFI_VECTOR_HANDOFF_INFO       *VectorInfo OPTIONAL
+  IN EFI_VECTOR_HANDOFF_INFO  *VectorInfo OPTIONAL
   )
 {
-  EFI_STATUS                       Status;
-  EXCEPTION_HANDLER_DATA           *ExceptionHandlerData;
-  RESERVED_VECTORS_DATA            *ReservedVectors;
+  EFI_STATUS              Status;
+  EXCEPTION_HANDLER_DATA  *ExceptionHandlerData;
+  RESERVED_VECTORS_DATA   *ReservedVectors;
 
   ReservedVectors = AllocatePool (sizeof (RESERVED_VECTORS_DATA) * CPU_EXCEPTION_NUM);
   ASSERT (ReservedVectors != NULL);
@@ -172,7 +167,7 @@ InitializeCpuExceptionHandlers (
 EFI_STATUS
 EFIAPI
 InitializeCpuInterruptHandlers (
-  IN EFI_VECTOR_HANDOFF_INFO       *VectorInfo OPTIONAL
+  IN EFI_VECTOR_HANDOFF_INFO  *VectorInfo OPTIONAL
   )
 {
   return EFI_UNSUPPORTED;
@@ -204,8 +199,8 @@ InitializeCpuInterruptHandlers (
 EFI_STATUS
 EFIAPI
 RegisterCpuInterruptHandler (
-  IN EFI_EXCEPTION_TYPE            InterruptType,
-  IN EFI_CPU_INTERRUPT_HANDLER     InterruptHandler
+  IN EFI_EXCEPTION_TYPE         InterruptType,
+  IN EFI_CPU_INTERRUPT_HANDLER  InterruptHandler
   )
 {
   return EFI_UNSUPPORTED;
@@ -236,11 +231,11 @@ RegisterCpuInterruptHandler (
 EFI_STATUS
 EFIAPI
 InitializeCpuExceptionHandlersEx (
-  IN EFI_VECTOR_HANDOFF_INFO            *VectorInfo OPTIONAL,
-  IN CPU_EXCEPTION_INIT_DATA            *InitData OPTIONAL
+  IN EFI_VECTOR_HANDOFF_INFO  *VectorInfo OPTIONAL,
+  IN CPU_EXCEPTION_INIT_DATA  *InitData OPTIONAL
   )
 {
-  EFI_STATUS                        Status;
+  EFI_STATUS  Status;
 
   //
   // To avoid repeat initialization of default handlers, the caller should pass
@@ -249,7 +244,7 @@ InitializeCpuExceptionHandlersEx (
   // version instead; or this method must be implemented as a simple wrapper of
   // non-ex version of it, if this version has to be called.
   //
-  if (InitData == NULL || InitData->Ia32.InitDefaultHandlers) {
+  if ((InitData == NULL) || InitData->Ia32.InitDefaultHandlers) {
     Status = InitializeCpuExceptionHandlers (VectorInfo);
   } else {
     Status = EFI_SUCCESS;
@@ -259,10 +254,10 @@ InitializeCpuExceptionHandlersEx (
     //
     // Initializing stack switch is only necessary for Stack Guard functionality.
     //
-    if (PcdGetBool (PcdCpuStackGuard) && InitData != NULL) {
-      Status = ArchSetupExcpetionStack (InitData);
+    if (PcdGetBool (PcdCpuStackGuard) && (InitData != NULL)) {
+      Status = ArchSetupExceptionStack (InitData);
     }
   }
 
-  return  Status;
+  return Status;
 }
