@@ -1,7 +1,7 @@
 /** @file
   Common header file for MP Initialize Library.
 
-  Copyright (c) 2016 - 2020, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2016 - 2021, Intel Corporation. All rights reserved.<BR>
   Copyright (c) 2020, AMD Inc. All rights reserved.<BR>
 
   SPDX-License-Identifier: BSD-2-Clause-Patent
@@ -15,6 +15,7 @@
 
 #include <Register/Intel/Cpuid.h>
 #include <Register/Amd/Cpuid.h>
+#include <Register/Amd/Ghcb.h>
 #include <Register/Intel/Msr.h>
 #include <Register/Intel/LocalApic.h>
 #include <Register/Intel/Microcode.h>
@@ -32,10 +33,15 @@
 #include <Library/MtrrLib.h>
 #include <Library/HobLib.h>
 #include <Library/PcdLib.h>
+#include <Library/MicrocodeLib.h>
+#include <ConfidentialComputingGuestAttr.h>
+
+#include <Register/Amd/Fam17Msr.h>
+#include <Register/Amd/Ghcb.h>
 
 #include <Guid/MicrocodePatchHob.h>
 
-#define WAKEUP_AP_SIGNAL SIGNATURE_32 ('S', 'T', 'A', 'P')
+#define WAKEUP_AP_SIGNAL  SIGNATURE_32 ('S', 'T', 'A', 'P')
 
 #define CPU_INIT_MP_LIB_HOB_GUID \
   { \
@@ -45,14 +51,14 @@
 //
 //  The MP data for switch BSP
 //
-#define CPU_SWITCH_STATE_IDLE   0
-#define CPU_SWITCH_STATE_STORED 1
-#define CPU_SWITCH_STATE_LOADED 2
+#define CPU_SWITCH_STATE_IDLE    0
+#define CPU_SWITCH_STATE_STORED  1
+#define CPU_SWITCH_STATE_LOADED  2
 
 //
 // Default maximum number of entries to store the microcode patches information
 //
-#define DEFAULT_MAX_MICROCODE_PATCH_NUM 8
+#define DEFAULT_MAX_MICROCODE_PATCH_NUM  8
 
 //
 // Data structure for microcode patch information
@@ -66,10 +72,10 @@ typedef struct {
 // CPU exchange information for switch BSP
 //
 typedef struct {
-  UINT8             State;        // offset 0
-  UINTN             StackPointer; // offset 4 / 8
-  IA32_DESCRIPTOR   Gdtr;         // offset 8 / 16
-  IA32_DESCRIPTOR   Idtr;         // offset 14 / 26
+  UINT8              State;        // offset 0
+  UINTN              StackPointer; // offset 4 / 8
+  IA32_DESCRIPTOR    Gdtr;         // offset 8 / 16
+  IA32_DESCRIPTOR    Idtr;         // offset 14 / 26
 } CPU_EXCHANGE_ROLE_INFO;
 
 //
@@ -110,40 +116,42 @@ typedef enum {
 // CPU volatile registers around INIT-SIPI-SIPI
 //
 typedef struct {
-  UINTN                          Cr0;
-  UINTN                          Cr3;
-  UINTN                          Cr4;
-  UINTN                          Dr0;
-  UINTN                          Dr1;
-  UINTN                          Dr2;
-  UINTN                          Dr3;
-  UINTN                          Dr6;
-  UINTN                          Dr7;
-  IA32_DESCRIPTOR                Gdtr;
-  IA32_DESCRIPTOR                Idtr;
-  UINT16                         Tr;
+  UINTN              Cr0;
+  UINTN              Cr3;
+  UINTN              Cr4;
+  UINTN              Dr0;
+  UINTN              Dr1;
+  UINTN              Dr2;
+  UINTN              Dr3;
+  UINTN              Dr6;
+  UINTN              Dr7;
+  IA32_DESCRIPTOR    Gdtr;
+  IA32_DESCRIPTOR    Idtr;
+  UINT16             Tr;
 } CPU_VOLATILE_REGISTERS;
 
 //
 // AP related data
 //
 typedef struct {
-  SPIN_LOCK                      ApLock;
-  volatile UINT32                *StartupApSignal;
-  volatile UINTN                 ApFunction;
-  volatile UINTN                 ApFunctionArgument;
-  BOOLEAN                        CpuHealthy;
-  volatile CPU_STATE             State;
-  CPU_VOLATILE_REGISTERS         VolatileRegisters;
-  BOOLEAN                        Waiting;
-  BOOLEAN                        *Finished;
-  UINT64                         ExpectedTime;
-  UINT64                         CurrentTime;
-  UINT64                         TotalTime;
-  EFI_EVENT                      WaitEvent;
-  UINT32                         ProcessorSignature;
-  UINT8                          PlatformId;
-  UINT64                         MicrocodeEntryAddr;
+  SPIN_LOCK                 ApLock;
+  volatile UINT32           *StartupApSignal;
+  volatile UINTN            ApFunction;
+  volatile UINTN            ApFunctionArgument;
+  BOOLEAN                   CpuHealthy;
+  volatile CPU_STATE        State;
+  CPU_VOLATILE_REGISTERS    VolatileRegisters;
+  BOOLEAN                   Waiting;
+  BOOLEAN                   *Finished;
+  UINT64                    ExpectedTime;
+  UINT64                    CurrentTime;
+  UINT64                    TotalTime;
+  EFI_EVENT                 WaitEvent;
+  UINT32                    ProcessorSignature;
+  UINT8                     PlatformId;
+  UINT64                    MicrocodeEntryAddr;
+  UINT32                    MicrocodeRevision;
+  SEV_ES_SAVE_AREA          *SevEsSaveArea;
 } CPU_AP_DATA;
 
 //
@@ -154,10 +162,10 @@ typedef struct {
 //
 #pragma pack (1)
 typedef struct {
-  UINT32                         InitialApicId;
-  UINT32                         ApicId;
-  UINT32                         Health;
-  UINT64                         ApTopOfStack;
+  UINT32    InitialApicId;
+  UINT32    ApicId;
+  UINT32    Health;
+  UINT64    ApTopOfStack;
 } CPU_INFO_IN_HOB;
 #pragma pack ()
 
@@ -167,15 +175,20 @@ typedef struct {
 // It is natural aligned by design.
 //
 typedef struct {
-  UINT8             *RendezvousFunnelAddress;
-  UINTN             ModeEntryOffset;
-  UINTN             RendezvousFunnelSize;
-  UINT8             *RelocateApLoopFuncAddress;
-  UINTN             RelocateApLoopFuncSize;
-  UINTN             ModeTransitionOffset;
+  UINT8    *RendezvousFunnelAddress;
+  UINTN    ModeEntryOffset;
+  UINTN    RendezvousFunnelSize;
+  UINT8    *RelocateApLoopFuncAddress;
+  UINTN    RelocateApLoopFuncSize;
+  UINTN    ModeTransitionOffset;
+  UINTN    SwitchToRealSize;
+  UINTN    SwitchToRealOffset;
+  UINTN    SwitchToRealNoNxOffset;
+  UINTN    SwitchToRealPM16ModeOffset;
+  UINTN    SwitchToRealPM16ModeSize;
 } MP_ASSEMBLY_ADDRESS_MAP;
 
-typedef struct _CPU_MP_DATA  CPU_MP_DATA;
+typedef struct _CPU_MP_DATA CPU_MP_DATA;
 
 #pragma pack(1)
 
@@ -185,32 +198,35 @@ typedef struct _CPU_MP_DATA  CPU_MP_DATA;
 // into this structure are used in assembly code in this module
 //
 typedef struct {
-  UINTN                 Lock;
-  UINTN                 StackStart;
-  UINTN                 StackSize;
-  UINTN                 CFunction;
-  IA32_DESCRIPTOR       GdtrProfile;
-  IA32_DESCRIPTOR       IdtrProfile;
-  UINTN                 BufferStart;
-  UINTN                 ModeOffset;
-  UINTN                 ApIndex;
-  UINTN                 CodeSegment;
-  UINTN                 DataSegment;
-  UINTN                 EnableExecuteDisable;
-  UINTN                 Cr3;
-  UINTN                 InitFlag;
-  CPU_INFO_IN_HOB       *CpuInfo;
-  UINTN                 NumApsExecuting;
-  CPU_MP_DATA           *CpuMpData;
-  UINTN                 InitializeFloatingPointUnitsAddress;
-  UINT32                ModeTransitionMemory;
-  UINT16                ModeTransitionSegment;
-  UINT32                ModeHighMemory;
-  UINT16                ModeHighSegment;
+  UINTN              StackStart;
+  UINTN              StackSize;
+  UINTN              CFunction;
+  IA32_DESCRIPTOR    GdtrProfile;
+  IA32_DESCRIPTOR    IdtrProfile;
+  UINTN              BufferStart;
+  UINTN              ModeOffset;
+  UINTN              ApIndex;
+  UINTN              CodeSegment;
+  UINTN              DataSegment;
+  UINTN              EnableExecuteDisable;
+  UINTN              Cr3;
+  UINTN              InitFlag;
+  CPU_INFO_IN_HOB    *CpuInfo;
+  UINTN              NumApsExecuting;
+  CPU_MP_DATA        *CpuMpData;
+  UINTN              InitializeFloatingPointUnitsAddress;
+  UINT32             ModeTransitionMemory;
+  UINT16             ModeTransitionSegment;
+  UINT32             ModeHighMemory;
+  UINT16             ModeHighSegment;
   //
   // Enable5LevelPaging indicates whether 5-level paging is enabled in long mode.
   //
-  BOOLEAN               Enable5LevelPaging;
+  BOOLEAN            Enable5LevelPaging;
+  BOOLEAN            SevEsIsEnabled;
+  BOOLEAN            SevSnpIsEnabled;
+  UINTN              GhcbBase;
+  BOOLEAN            ExtTopoAvail;
 } MP_CPU_EXCHANGE_INFO;
 
 #pragma pack()
@@ -219,54 +235,55 @@ typedef struct {
 // CPU MP Data save in memory
 //
 struct _CPU_MP_DATA {
-  UINT64                         CpuInfoInHob;
-  UINT32                         CpuCount;
-  UINT32                         BspNumber;
+  UINT64                           CpuInfoInHob;
+  UINT32                           CpuCount;
+  UINT32                           BspNumber;
   //
   // The above fields data will be passed from PEI to DXE
   // Please make sure the fields offset same in the different
   // architecture.
   //
-  SPIN_LOCK                      MpLock;
-  UINTN                          Buffer;
-  UINTN                          CpuApStackSize;
-  MP_ASSEMBLY_ADDRESS_MAP        AddressMap;
-  UINTN                          WakeupBuffer;
-  UINTN                          WakeupBufferHigh;
-  UINTN                          BackupBuffer;
-  UINTN                          BackupBufferSize;
+  SPIN_LOCK                        MpLock;
+  UINTN                            Buffer;
+  UINTN                            CpuApStackSize;
+  MP_ASSEMBLY_ADDRESS_MAP          AddressMap;
+  UINTN                            WakeupBuffer;
+  UINTN                            WakeupBufferHigh;
+  UINTN                            BackupBuffer;
+  UINTN                            BackupBufferSize;
 
-  volatile UINT32                FinishedCount;
-  UINT32                         RunningCount;
-  BOOLEAN                        SingleThread;
-  EFI_AP_PROCEDURE               Procedure;
-  VOID                           *ProcArguments;
-  BOOLEAN                        *Finished;
-  UINT64                         ExpectedTime;
-  UINT64                         CurrentTime;
-  UINT64                         TotalTime;
-  EFI_EVENT                      WaitEvent;
-  UINTN                          **FailedCpuList;
+  volatile UINT32                  FinishedCount;
+  UINT32                           RunningCount;
+  BOOLEAN                          SingleThread;
+  EFI_AP_PROCEDURE                 Procedure;
+  VOID                             *ProcArguments;
+  BOOLEAN                          *Finished;
+  UINT64                           ExpectedTime;
+  UINT64                           CurrentTime;
+  UINT64                           TotalTime;
+  EFI_EVENT                        WaitEvent;
+  UINTN                            **FailedCpuList;
 
-  AP_INIT_STATE                  InitFlag;
-  BOOLEAN                        SwitchBspFlag;
-  UINTN                          NewBspNumber;
-  CPU_EXCHANGE_ROLE_INFO         BSPInfo;
-  CPU_EXCHANGE_ROLE_INFO         APInfo;
-  MTRR_SETTINGS                  MtrrTable;
-  UINT8                          ApLoopMode;
-  UINT8                          ApTargetCState;
-  UINT16                         PmCodeSegment;
-  CPU_AP_DATA                    *CpuData;
-  volatile MP_CPU_EXCHANGE_INFO  *MpCpuExchangeInfo;
+  AP_INIT_STATE                    InitFlag;
+  BOOLEAN                          SwitchBspFlag;
+  UINTN                            NewBspNumber;
+  CPU_EXCHANGE_ROLE_INFO           BSPInfo;
+  CPU_EXCHANGE_ROLE_INFO           APInfo;
+  MTRR_SETTINGS                    MtrrTable;
+  UINT8                            ApLoopMode;
+  UINT8                            ApTargetCState;
+  UINT16                           PmCodeSegment;
+  UINT16                           Pm16CodeSegment;
+  CPU_AP_DATA                      *CpuData;
+  volatile MP_CPU_EXCHANGE_INFO    *MpCpuExchangeInfo;
 
-  UINT32                         CurrentTimerCount;
-  UINTN                          DivideValue;
-  UINT8                          Vector;
-  BOOLEAN                        PeriodicMode;
-  BOOLEAN                        TimerInterruptState;
-  UINT64                         MicrocodePatchAddress;
-  UINT64                         MicrocodePatchRegionSize;
+  UINT32                           CurrentTimerCount;
+  UINTN                            DivideValue;
+  UINT8                            Vector;
+  BOOLEAN                          PeriodicMode;
+  BOOLEAN                          TimerInterruptState;
+  UINT64                           MicrocodePatchAddress;
+  UINT64                           MicrocodePatchRegionSize;
 
   //
   // Whether need to use Init-Sipi-Sipi to wake up the APs.
@@ -275,10 +292,54 @@ struct _CPU_MP_DATA {
   // will be hardcode change to HLT mode by PiSmmCpuDxeSmm
   // driver.
   //
-  BOOLEAN                        WakeUpByInitSipiSipi;
+  BOOLEAN        WakeUpByInitSipiSipi;
+
+  BOOLEAN        SevEsIsEnabled;
+  BOOLEAN        SevSnpIsEnabled;
+  BOOLEAN        UseSevEsAPMethod;
+  UINTN          SevEsAPBuffer;
+  UINTN          SevEsAPResetStackStart;
+  CPU_MP_DATA    *NewCpuMpData;
+
+  UINT64         GhcbBase;
 };
 
-extern EFI_GUID mCpuInitMpLibHobGuid;
+#define AP_SAFE_STACK_SIZE   128
+#define AP_RESET_STACK_SIZE  AP_SAFE_STACK_SIZE
+
+#pragma pack(1)
+
+typedef struct {
+  UINT8     InsnBuffer[8];
+  UINT16    Rip;
+  UINT16    Segment;
+} SEV_ES_AP_JMP_FAR;
+
+#pragma pack()
+
+/**
+  Assembly code to move an AP from long mode to real mode.
+
+  Move an AP from long mode to real mode in preparation to invoking
+  the reset vector.  This is used for SEV-ES guests where a hypervisor
+  is not allowed to set the CS and RIP to point to the reset vector.
+
+  @param[in]  BufferStart  The reset vector target.
+  @param[in]  Code16       16-bit protected mode code segment value.
+  @param[in]  Code32       32-bit protected mode code segment value.
+  @param[in]  StackStart   The start of a stack to be used for transitioning
+                           from long mode to real mode.
+**/
+typedef
+  VOID
+(EFIAPI AP_RESET)(
+  IN UINTN    BufferStart,
+  IN UINT16   Code16,
+  IN UINT16   Code32,
+  IN UINTN    StackStart
+  );
+
+extern EFI_GUID  mCpuInitMpLibHobGuid;
 
 /**
   Assembly code to place AP into safe loop mode.
@@ -295,13 +356,16 @@ extern EFI_GUID mCpuInitMpLibHobGuid;
   @param[in] PmCodeSegment   Protected mode code segment value.
 **/
 typedef
-VOID
-(EFIAPI * ASM_RELOCATE_AP_LOOP) (
+  VOID
+(EFIAPI *ASM_RELOCATE_AP_LOOP)(
   IN BOOLEAN                 MwaitSupport,
   IN UINTN                   ApTargetCState,
   IN UINTN                   PmCodeSegment,
   IN UINTN                   TopOfApStack,
-  IN UINTN                   NumberToFinish
+  IN UINTN                   NumberToFinish,
+  IN UINTN                   Pm16CodeSegment,
+  IN UINTN                   SevEsAPJumpTable,
+  IN UINTN                   WakeupBuffer
   );
 
 /**
@@ -313,7 +377,7 @@ VOID
 VOID
 EFIAPI
 AsmGetAddressMap (
-  OUT MP_ASSEMBLY_ADDRESS_MAP    *AddressMap
+  OUT MP_ASSEMBLY_ADDRESS_MAP  *AddressMap
   );
 
 /**
@@ -328,8 +392,8 @@ AsmGetAddressMap (
 VOID
 EFIAPI
 AsmExchangeRole (
-  IN CPU_EXCHANGE_ROLE_INFO    *MyInfo,
-  IN CPU_EXCHANGE_ROLE_INFO    *OthersInfo
+  IN CPU_EXCHANGE_ROLE_INFO  *MyInfo,
+  IN CPU_EXCHANGE_ROLE_INFO  *OthersInfo
   );
 
 /**
@@ -349,10 +413,9 @@ GetCpuMpData (
 **/
 VOID
 SaveCpuMpData (
-  IN CPU_MP_DATA   *CpuMpData
+  IN CPU_MP_DATA  *CpuMpData
   );
 
-
 /**
   Get available system memory below 1MB by specified size.
 
@@ -363,7 +426,7 @@ SaveCpuMpData (
 **/
 UINTN
 GetWakeupBuffer (
-  IN UINTN                WakeupBufferSize
+  IN UINTN  WakeupBufferSize
   );
 
 /**
@@ -380,7 +443,20 @@ GetWakeupBuffer (
 **/
 UINTN
 GetModeTransitionBuffer (
-  IN UINTN                BufferSize
+  IN UINTN  BufferSize
+  );
+
+/**
+  Return the address of the SEV-ES AP jump table.
+
+  This buffer is required in order for an SEV-ES guest to transition from
+  UEFI into an OS.
+
+  @return         Return SEV-ES AP jump table buffer
+**/
+UINTN
+GetSevEsAPMemory (
+  VOID
   );
 
 /**
@@ -396,12 +472,12 @@ GetModeTransitionBuffer (
 **/
 VOID
 WakeUpAP (
-  IN CPU_MP_DATA               *CpuMpData,
-  IN BOOLEAN                   Broadcast,
-  IN UINTN                     ProcessorNumber,
-  IN EFI_AP_PROCEDURE          Procedure,              OPTIONAL
-  IN VOID                      *ProcedureArgument,     OPTIONAL
-  IN BOOLEAN                   WakeUpDisabledAps       OPTIONAL
+  IN CPU_MP_DATA       *CpuMpData,
+  IN BOOLEAN           Broadcast,
+  IN UINTN             ProcessorNumber,
+  IN EFI_AP_PROCEDURE  Procedure               OPTIONAL,
+  IN VOID              *ProcedureArgument      OPTIONAL,
+  IN BOOLEAN           WakeUpDisabledAps       OPTIONAL
   );
 
 /**
@@ -411,7 +487,7 @@ WakeUpAP (
 **/
 VOID
 InitMpGlobalData (
-  IN CPU_MP_DATA               *CpuMpData
+  IN CPU_MP_DATA  *CpuMpData
   );
 
 /**
@@ -448,13 +524,13 @@ InitMpGlobalData (
 **/
 EFI_STATUS
 StartupAllCPUsWorker (
-  IN  EFI_AP_PROCEDURE          Procedure,
-  IN  BOOLEAN                   SingleThread,
-  IN  BOOLEAN                   ExcludeBsp,
-  IN  EFI_EVENT                 WaitEvent               OPTIONAL,
-  IN  UINTN                     TimeoutInMicroseconds,
-  IN  VOID                      *ProcedureArgument      OPTIONAL,
-  OUT UINTN                     **FailedCpuList         OPTIONAL
+  IN  EFI_AP_PROCEDURE  Procedure,
+  IN  BOOLEAN           SingleThread,
+  IN  BOOLEAN           ExcludeBsp,
+  IN  EFI_EVENT         WaitEvent               OPTIONAL,
+  IN  UINTN             TimeoutInMicroseconds,
+  IN  VOID              *ProcedureArgument      OPTIONAL,
+  OUT UINTN             **FailedCpuList         OPTIONAL
   );
 
 /**
@@ -482,12 +558,12 @@ StartupAllCPUsWorker (
 **/
 EFI_STATUS
 StartupThisAPWorker (
-  IN  EFI_AP_PROCEDURE          Procedure,
-  IN  UINTN                     ProcessorNumber,
-  IN  EFI_EVENT                 WaitEvent               OPTIONAL,
-  IN  UINTN                     TimeoutInMicroseconds,
-  IN  VOID                      *ProcedureArgument      OPTIONAL,
-  OUT BOOLEAN                   *Finished               OPTIONAL
+  IN  EFI_AP_PROCEDURE  Procedure,
+  IN  UINTN             ProcessorNumber,
+  IN  EFI_EVENT         WaitEvent               OPTIONAL,
+  IN  UINTN             TimeoutInMicroseconds,
+  IN  VOID              *ProcedureArgument      OPTIONAL,
+  OUT BOOLEAN           *Finished               OPTIONAL
   );
 
 /**
@@ -503,8 +579,8 @@ StartupThisAPWorker (
 **/
 EFI_STATUS
 SwitchBSPWorker (
-  IN UINTN                     ProcessorNumber,
-  IN BOOLEAN                   EnableOldBSP
+  IN UINTN    ProcessorNumber,
+  IN BOOLEAN  EnableOldBSP
   );
 
 /**
@@ -523,9 +599,9 @@ SwitchBSPWorker (
 **/
 EFI_STATUS
 EnableDisableApWorker (
-  IN  UINTN                     ProcessorNumber,
-  IN  BOOLEAN                   EnableAP,
-  IN  UINT32                    *HealthFlag OPTIONAL
+  IN  UINTN    ProcessorNumber,
+  IN  BOOLEAN  EnableAP,
+  IN  UINT32   *HealthFlag OPTIONAL
   );
 
 /**
@@ -551,7 +627,7 @@ GetCpuMpDataFromGuidedHob (
 **/
 EFI_STATUS
 CheckThisAP (
-  IN UINTN        ProcessorNumber
+  IN UINTN  ProcessorNumber
   );
 
 /**
@@ -588,8 +664,8 @@ CheckAndUpdateApsStatus (
 **/
 VOID
 MicrocodeDetect (
-  IN CPU_MP_DATA             *CpuMpData,
-  IN UINTN                   ProcessorNumber
+  IN CPU_MP_DATA  *CpuMpData,
+  IN UINTN        ProcessorNumber
   );
 
 /**
@@ -599,7 +675,7 @@ MicrocodeDetect (
 **/
 VOID
 ShadowMicrocodeUpdatePatch (
-  IN OUT CPU_MP_DATA             *CpuMpData
+  IN OUT CPU_MP_DATA  *CpuMpData
   );
 
 /**
@@ -619,8 +695,8 @@ ShadowMicrocodeUpdatePatch (
 **/
 BOOLEAN
 GetMicrocodePatchInfoFromHob (
-  UINT64                         *Address,
-  UINT64                         *RegionSize
+  UINT64  *Address,
+  UINT64  *RegionSize
   );
 
 /**
@@ -654,8 +730,8 @@ EnableDebugAgent (
 **/
 EFI_STATUS
 GetProcessorNumber (
-  IN CPU_MP_DATA               *CpuMpData,
-  OUT UINTN                    *ProcessorNumber
+  IN CPU_MP_DATA  *CpuMpData,
+  OUT UINTN       *ProcessorNumber
   );
 
 /**
@@ -671,8 +747,100 @@ GetProcessorNumber (
 **/
 EFI_STATUS
 PlatformShadowMicrocode (
-  IN OUT CPU_MP_DATA             *CpuMpData
+  IN OUT CPU_MP_DATA  *CpuMpData
+  );
+
+/**
+  Allocate the SEV-ES AP jump table buffer.
+
+  @param[in, out]  CpuMpData  The pointer to CPU MP Data structure.
+**/
+VOID
+AllocateSevEsAPMemory (
+  IN OUT CPU_MP_DATA  *CpuMpData
+  );
+
+/**
+  Program the SEV-ES AP jump table buffer.
+
+  @param[in]  SipiVector  The SIPI vector used for the AP Reset
+**/
+VOID
+SetSevEsJumpTable (
+  IN UINTN  SipiVector
+  );
+
+/**
+  The function puts the AP in halt loop.
+
+  @param[in]  CpuMpData  The pointer to CPU MP Data structure.
+**/
+VOID
+SevEsPlaceApHlt (
+  CPU_MP_DATA  *CpuMpData
+  );
+
+/**
+ Check if the specified confidential computing attribute is active.
+
+ @retval TRUE   The specified Attr is active.
+ @retval FALSE  The specified Attr is not active.
+**/
+BOOLEAN
+EFIAPI
+ConfidentialComputingGuestHas (
+  CONFIDENTIAL_COMPUTING_GUEST_ATTR  Attr
+  );
+
+/**
+  The function fills the exchange data for the AP.
+
+  @param[in]   ExchangeInfo  The pointer to CPU Exchange Data structure
+**/
+VOID
+FillExchangeInfoDataSevEs (
+  IN volatile MP_CPU_EXCHANGE_INFO  *ExchangeInfo
+  );
+
+/**
+  Issue RMPADJUST to adjust the VMSA attribute of an SEV-SNP page.
+
+  @param[in]  PageAddress
+  @param[in]  VmsaPage
+
+  @return  RMPADJUST return value
+**/
+UINT32
+SevSnpRmpAdjust (
+  IN  EFI_PHYSICAL_ADDRESS  PageAddress,
+  IN  BOOLEAN               VmsaPage
+  );
+
+/**
+  Create an SEV-SNP AP save area (VMSA) for use in running the vCPU.
+
+  @param[in]  CpuMpData        Pointer to CPU MP Data
+  @param[in]  CpuData          Pointer to CPU AP Data
+  @param[in]  ApicId           APIC ID of the vCPU
+**/
+VOID
+SevSnpCreateSaveArea (
+  IN CPU_MP_DATA  *CpuMpData,
+  IN CPU_AP_DATA  *CpuData,
+  UINT32          ApicId
+  );
+
+/**
+  Create SEV-SNP APs.
+
+  @param[in]  CpuMpData        Pointer to CPU MP Data
+  @param[in]  ProcessorNumber  The handle number of specified processor
+                               (-1 for all APs)
+**/
+VOID
+SevSnpCreateAP (
+  IN CPU_MP_DATA  *CpuMpData,
+  IN INTN         ProcessorNumber
   );
 
 #endif
-
