@@ -1,21 +1,53 @@
 /** @file
 Page table manipulation functions for IA-32 processors
 
-Copyright (c) 2009 - 2017, Intel Corporation. All rights reserved.<BR>
+Copyright (c) 2009 - 2019, Intel Corporation. All rights reserved.<BR>
 Copyright (c) 2017, AMD Incorporated. All rights reserved.<BR>
 
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
 #include "PiSmmCpuDxeSmm.h"
 
+/**
+  Disable CET.
+**/
+VOID
+EFIAPI
+DisableCet (
+  VOID
+  );
+
+/**
+  Enable CET.
+**/
+VOID
+EFIAPI
+EnableCet (
+  VOID
+  );
+
+/**
+  Get page table base address and the depth of the page table.
+
+  @param[out] Base        Page table base address.
+  @param[out] FiveLevels  TRUE means 5 level paging. FALSE means 4 level paging.
+**/
+VOID
+GetPageTable (
+  OUT UINTN    *Base,
+  OUT BOOLEAN  *FiveLevels OPTIONAL
+  )
+{
+  *Base = ((mInternalCr3 == 0) ?
+           (AsmReadCr3 () & PAGING_4K_ADDRESS_MASK_64) :
+           mInternalCr3);
+  if (FiveLevels != NULL) {
+    *FiveLevels = FALSE;
+  }
+}
+
 /**
   Create PageTable for SMM use.
 
@@ -27,9 +59,9 @@ SmmInitPageTable (
   VOID
   )
 {
-  UINTN                             PageFaultHandlerHookAddress;
-  IA32_IDT_GATE_DESCRIPTOR          *IdtEntry;
-  EFI_STATUS                        Status;
+  UINTN                     PageFaultHandlerHookAddress;
+  IA32_IDT_GATE_DESCRIPTOR  *IdtEntry;
+  EFI_STATUS                Status;
 
   //
   // Initialize spin lock
@@ -40,18 +72,19 @@ SmmInitPageTable (
 
   if (FeaturePcdGet (PcdCpuSmmProfileEnable) ||
       HEAP_GUARD_NONSTOP_MODE ||
-      NULL_DETECTION_NONSTOP_MODE) {
+      NULL_DETECTION_NONSTOP_MODE)
+  {
     //
     // Set own Page Fault entry instead of the default one, because SMM Profile
     // feature depends on IRET instruction to do Single Step
     //
     PageFaultHandlerHookAddress = (UINTN)PageFaultIdtHandlerSmmProfile;
-    IdtEntry  = (IA32_IDT_GATE_DESCRIPTOR *) gcSmiIdtr.Base;
-    IdtEntry += EXCEPT_IA32_PAGE_FAULT;
-    IdtEntry->Bits.OffsetLow      = (UINT16)PageFaultHandlerHookAddress;
-    IdtEntry->Bits.Reserved_0     = 0;
-    IdtEntry->Bits.GateType       = IA32_IDT_GATE_TYPE_INTERRUPT_32;
-    IdtEntry->Bits.OffsetHigh     = (UINT16)(PageFaultHandlerHookAddress >> 16);
+    IdtEntry                    = (IA32_IDT_GATE_DESCRIPTOR *)gcSmiIdtr.Base;
+    IdtEntry                   += EXCEPT_IA32_PAGE_FAULT;
+    IdtEntry->Bits.OffsetLow    = (UINT16)PageFaultHandlerHookAddress;
+    IdtEntry->Bits.Reserved_0   = 0;
+    IdtEntry->Bits.GateType     = IA32_IDT_GATE_TYPE_INTERRUPT_32;
+    IdtEntry->Bits.OffsetHigh   = (UINT16)(PageFaultHandlerHookAddress >> 16);
   } else {
     //
     // Register SMM Page Fault Handler
@@ -66,6 +99,7 @@ SmmInitPageTable (
   if (FeaturePcdGet (PcdCpuSmmStackGuard)) {
     InitializeIDTSmmStackGuard ();
   }
+
   return Gen4GPageTable (TRUE);
 }
 
@@ -92,13 +126,13 @@ SmiDefaultPFHandler (
 VOID
 EFIAPI
 SmiPFHandler (
-  IN EFI_EXCEPTION_TYPE   InterruptType,
-  IN EFI_SYSTEM_CONTEXT   SystemContext
+  IN EFI_EXCEPTION_TYPE  InterruptType,
+  IN EFI_SYSTEM_CONTEXT  SystemContext
   )
 {
-  UINTN             PFAddress;
-  UINTN             GuardPageAddress;
-  UINTN             CpuIndex;
+  UINTN  PFAddress;
+  UINTN  GuardPageAddress;
+  UINTN  CpuIndex;
 
   ASSERT (InterruptType == EXCEPT_IA32_PAGE_FAULT);
 
@@ -111,25 +145,27 @@ SmiPFHandler (
   // or SMM page protection violation.
   //
   if ((PFAddress >= mCpuHotPlugData.SmrrBase) &&
-      (PFAddress < (mCpuHotPlugData.SmrrBase + mCpuHotPlugData.SmrrSize))) {
+      (PFAddress < (mCpuHotPlugData.SmrrBase + mCpuHotPlugData.SmrrSize)))
+  {
     DumpCpuContext (InterruptType, SystemContext);
-    CpuIndex = GetCpuIndex ();
+    CpuIndex         = GetCpuIndex ();
     GuardPageAddress = (mSmmStackArrayBase + EFI_PAGE_SIZE + CpuIndex * mSmmStackSize);
     if ((FeaturePcdGet (PcdCpuSmmStackGuard)) &&
         (PFAddress >= GuardPageAddress) &&
-        (PFAddress < (GuardPageAddress + EFI_PAGE_SIZE))) {
+        (PFAddress < (GuardPageAddress + EFI_PAGE_SIZE)))
+    {
       DEBUG ((DEBUG_ERROR, "SMM stack overflow!\n"));
     } else {
       if ((SystemContext.SystemContextIa32->ExceptionData & IA32_PF_EC_ID) != 0) {
         DEBUG ((DEBUG_ERROR, "SMM exception at execution (0x%x)\n", PFAddress));
         DEBUG_CODE (
           DumpModuleInfoByIp (*(UINTN *)(UINTN)SystemContext.SystemContextIa32->Esp);
-        );
+          );
       } else {
         DEBUG ((DEBUG_ERROR, "SMM exception at access (0x%x)\n", PFAddress));
         DEBUG_CODE (
           DumpModuleInfoByIp ((UINTN)SystemContext.SystemContextIa32->Eip);
-        );
+          );
       }
 
       if (HEAP_GUARD_NONSTOP_MODE) {
@@ -137,33 +173,38 @@ SmiPFHandler (
         goto Exit;
       }
     }
+
     CpuDeadLoop ();
+    goto Exit;
   }
 
   //
   // If a page fault occurs in non-SMRAM range.
   //
   if ((PFAddress < mCpuHotPlugData.SmrrBase) ||
-      (PFAddress >= mCpuHotPlugData.SmrrBase + mCpuHotPlugData.SmrrSize)) {
+      (PFAddress >= mCpuHotPlugData.SmrrBase + mCpuHotPlugData.SmrrSize))
+  {
     if ((SystemContext.SystemContextIa32->ExceptionData & IA32_PF_EC_ID) != 0) {
       DumpCpuContext (InterruptType, SystemContext);
       DEBUG ((DEBUG_ERROR, "Code executed on IP(0x%x) out of SMM range after SMM is locked!\n", PFAddress));
       DEBUG_CODE (
         DumpModuleInfoByIp (*(UINTN *)(UINTN)SystemContext.SystemContextIa32->Esp);
-      );
+        );
       CpuDeadLoop ();
+      goto Exit;
     }
 
     //
     // If NULL pointer was just accessed
     //
-    if ((PcdGet8 (PcdNullPointerDetectionPropertyMask) & BIT1) != 0 &&
-        (PFAddress < EFI_PAGE_SIZE)) {
+    if (((PcdGet8 (PcdNullPointerDetectionPropertyMask) & BIT1) != 0) &&
+        (PFAddress < EFI_PAGE_SIZE))
+    {
       DumpCpuContext (InterruptType, SystemContext);
       DEBUG ((DEBUG_ERROR, "!!! NULL pointer access !!!\n"));
       DEBUG_CODE (
         DumpModuleInfoByIp ((UINTN)SystemContext.SystemContextIa32->Eip);
-      );
+        );
 
       if (NULL_DETECTION_NONSTOP_MODE) {
         GuardPagePFHandler (SystemContext.SystemContextIa32->ExceptionData);
@@ -171,6 +212,7 @@ SmiPFHandler (
       }
 
       CpuDeadLoop ();
+      goto Exit;
     }
 
     if (IsSmmCommBufferForbiddenAddress (PFAddress)) {
@@ -178,8 +220,9 @@ SmiPFHandler (
       DEBUG ((DEBUG_ERROR, "Access SMM communication forbidden address (0x%x)!\n", PFAddress));
       DEBUG_CODE (
         DumpModuleInfoByIp ((UINTN)SystemContext.SystemContextIa32->Eip);
-      );
+        );
       CpuDeadLoop ();
+      goto Exit;
     }
   }
 
@@ -205,13 +248,15 @@ SetPageTableAttributes (
   VOID
   )
 {
-  UINTN                 Index2;
-  UINTN                 Index3;
-  UINT64                *L1PageTable;
-  UINT64                *L2PageTable;
-  UINT64                *L3PageTable;
-  BOOLEAN               IsSplitted;
-  BOOLEAN               PageTableSplitted;
+  UINTN    Index2;
+  UINTN    Index3;
+  UINT64   *L1PageTable;
+  UINT64   *L2PageTable;
+  UINT64   *L3PageTable;
+  UINTN    PageTableBase;
+  BOOLEAN  IsSplitted;
+  BOOLEAN  PageTableSplitted;
+  BOOLEAN  CetEnabled;
 
   //
   // Don't mark page table to read-only if heap guard is enabled.
@@ -221,7 +266,7 @@ SetPageTableAttributes (
   //
   if ((PcdGet8 (PcdHeapGuardPropertyMask) & (BIT3 | BIT2)) != 0) {
     DEBUG ((DEBUG_INFO, "Don't mark page table to read-only as heap guard is enabled\n"));
-    return ;
+    return;
   }
 
   //
@@ -229,7 +274,7 @@ SetPageTableAttributes (
   //
   if (FeaturePcdGet (PcdCpuSmmProfileEnable)) {
     DEBUG ((DEBUG_INFO, "Don't mark page table to read-only as SMM profile is enabled\n"));
-    return ;
+    return;
   }
 
   DEBUG ((DEBUG_INFO, "SetPageTableAttributes\n"));
@@ -238,15 +283,24 @@ SetPageTableAttributes (
   // Disable write protection, because we need mark page table to be write protected.
   // We need *write* page table memory, to mark itself to be *read only*.
   //
-  AsmWriteCr0 (AsmReadCr0() & ~CR0_WP);
+  CetEnabled = ((AsmReadCr4 () & CR4_CET_ENABLE) != 0) ? TRUE : FALSE;
+  if (CetEnabled) {
+    //
+    // CET must be disabled if WP is disabled.
+    //
+    DisableCet ();
+  }
+
+  AsmWriteCr0 (AsmReadCr0 () & ~CR0_WP);
 
   do {
     DEBUG ((DEBUG_INFO, "Start...\n"));
     PageTableSplitted = FALSE;
 
-    L3PageTable = (UINT64 *)GetPageTableBase ();
+    GetPageTable (&PageTableBase, NULL);
+    L3PageTable = (UINT64 *)PageTableBase;
 
-    SmmSetMemoryAttributesEx ((EFI_PHYSICAL_ADDRESS)(UINTN)L3PageTable, SIZE_4KB, EFI_MEMORY_RO, &IsSplitted);
+    SmmSetMemoryAttributesEx ((EFI_PHYSICAL_ADDRESS)PageTableBase, SIZE_4KB, EFI_MEMORY_RO, &IsSplitted);
     PageTableSplitted = (PageTableSplitted || IsSplitted);
 
     for (Index3 = 0; Index3 < 4; Index3++) {
@@ -258,15 +312,17 @@ SetPageTableAttributes (
       SmmSetMemoryAttributesEx ((EFI_PHYSICAL_ADDRESS)(UINTN)L2PageTable, SIZE_4KB, EFI_MEMORY_RO, &IsSplitted);
       PageTableSplitted = (PageTableSplitted || IsSplitted);
 
-      for (Index2 = 0; Index2 < SIZE_4KB/sizeof(UINT64); Index2++) {
+      for (Index2 = 0; Index2 < SIZE_4KB/sizeof (UINT64); Index2++) {
         if ((L2PageTable[Index2] & IA32_PG_PS) != 0) {
           // 2M
           continue;
         }
+
         L1PageTable = (UINT64 *)(UINTN)(L2PageTable[Index2] & ~mAddressEncMask & PAGING_4K_ADDRESS_MASK_64);
         if (L1PageTable == NULL) {
           continue;
         }
+
         SmmSetMemoryAttributesEx ((EFI_PHYSICAL_ADDRESS)(UINTN)L1PageTable, SIZE_4KB, EFI_MEMORY_RO, &IsSplitted);
         PageTableSplitted = (PageTableSplitted || IsSplitted);
       }
@@ -276,7 +332,53 @@ SetPageTableAttributes (
   //
   // Enable write protection, after page table updated.
   //
-  AsmWriteCr0 (AsmReadCr0() | CR0_WP);
+  AsmWriteCr0 (AsmReadCr0 () | CR0_WP);
+  if (CetEnabled) {
+    //
+    // re-enable CET.
+    //
+    EnableCet ();
+  }
 
-  return ;
+  return;
+}
+
+/**
+  This function returns with no action for 32 bit.
+
+  @param[out]  *Cr2  Pointer to variable to hold CR2 register value.
+**/
+VOID
+SaveCr2 (
+  OUT UINTN  *Cr2
+  )
+{
+  return;
+}
+
+/**
+  This function returns with no action for 32 bit.
+
+  @param[in]  Cr2  Value to write into CR2 register.
+**/
+VOID
+RestoreCr2 (
+  IN UINTN  Cr2
+  )
+{
+  return;
+}
+
+/**
+  Return whether access to non-SMRAM is restricted.
+
+  @retval TRUE  Access to non-SMRAM is restricted.
+  @retval FALSE Access to non-SMRAM is not restricted.
+**/
+BOOLEAN
+IsRestrictedMemoryAccess (
+  VOID
+  )
+{
+  return TRUE;
 }
